@@ -45,6 +45,8 @@ class MhwCpInterface;
 #define MHW_MI_ENCODER_4K_WATCHDOG_THRESHOLD_IN_MS      100
 #define MHW_MI_ENCODER_FHD_WATCHDOG_THRESHOLD_IN_MS     50
 #define MHW_MI_DECODER_720P_WATCHDOG_THRESHOLD_IN_MS    10
+#define MHW_MI_DECODER_4K_WATCHDOG_THRESHOLD_IN_MS      20
+#define MHW_MI_DECODER_8K_WATCHDOG_THRESHOLD_IN_MS      60
 #define MHW_MI_DECODER_16K_WATCHDOG_THRESHOLD_IN_MS     180
 #define MHW_MI_DECODER_16Kx16K_WATCHDOG_THRESHOLD_IN_MS 256
 #define MHW_MI_WATCHDOG_COUNTS_PER_MILLISECOND         (19200123 / 1000)   // Time stamp counts per millisecond
@@ -177,6 +179,7 @@ typedef struct _MHW_PIPE_CONTROL_PARAMS
     uint32_t                bInvalidateTextureCache        : 1;
     uint32_t                bGenericMediaStateClear        : 1;
     uint32_t                bIndirectStatePointersDisable  : 1;
+    uint32_t                bUnTypedDataPortCacheFlush     : 1;
     uint32_t                bHdcPipelineFlush              : 1;
     uint32_t                bKernelFenceEnabled            : 1;
     uint32_t                bPPCFlush                      : 1;
