@@ -104,13 +104,8 @@
 typedef enum _MOS_USER_FEATURE_VALUE_ID
 {
     __MOS_USER_FEATURE_KEY_INVALID_ID = 0,
-    __MEDIA_USER_FEATURE_VALUE_MEDIA_RESET_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MEDIA_RESET_TH_ID,
     __MEDIA_USER_FEATURE_VALUE_MEDIA_RESET_COUNT_ID,
-    __MEDIA_USER_FEATURE_VALUE_SOFT_RESET_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_SIM_IN_USE_ID,
-    __MEDIA_USER_FEATURE_VALUE_FORCE_VDBOX_ID,
-    __MEDIA_USER_FEATURE_VALUE_LINUX_PERFORMANCETAG_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_FE_BE_TIMING,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_OUTPUT_FILE,
@@ -124,7 +119,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_REGISTER_6,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_REGISTER_7,
     __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_REGISTER_8,
-    __MEDIA_USER_FEATURE_VALUE_DISABLE_KMD_WATCHDOG_ID,
     __MEDIA_USER_FEATURE_VALUE_SINGLE_TASK_PHASE_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_DECODE_SINGLE_TASK_PHASE_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_AUX_TABLE_16K_GRANULAR_ID,
@@ -133,7 +127,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_MFE_FIRST_BUFFER_SUBMIT_ID,
     __MEDIA_USER_FEATURE_VALUE_RC_PANIC_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_SLICE_SHUTDOWN_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_FORCE_YFYS_ID,
     __MEDIA_USER_FEATURE_VALUE_DECODE_LOCK_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_HW_WALKER_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_HUC_FIRMWARE_LOAD_FAILED_ID,
@@ -265,7 +258,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_MMC_DEC_RT_COMPRESSMODE_ID,
     __MEDIA_USER_FEATURE_VALUE_MMC_ENC_RECON_COMPRESSIBLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MMC_ENC_RECON_COMPRESSMODE_ID,
-    __MEDIA_USER_FEATURE_VALUE_SSEU_SETTING_OVERRIDE_ID,
     __MEDIA_USER_FEATURE_VALUE_SLICE_SHUTDOWN_DEFAULT_STATE_ID,
     __MEDIA_USER_FEATURE_VALUE_SLICE_SHUTDOWN_REQUEST_STATE_ID,
     __MEDIA_USER_FEATURE_VALUE_SLICE_SHUTDOWN_RESOLUTION_THRESHOLD_ID,
@@ -297,13 +289,8 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_AV1DFLVROWSTORECACHE_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_AV1CDEFROWSTORECACHE_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENABLE_AVP_SCALABILITY_DECODE_ID,
-#if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
-    __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_BUFFER_ENABLE_ID,
-#endif  // MOS_COMMAND_BUFFER_DUMP_SUPPORTED
-#if MOS_COMMAND_RESINFO_DUMP_SUPPORTED
-    __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_INFO_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_INFO_PATH_ID,
-#endif  // MOS_COMMAND_RESINFO_DUMP_SUPPORTED
+    __MEDIA_USER_FEATURE_VALUE_AV1_DECODE_ON_SIMULATION_ID,
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     __MEDIA_USER_FEATURE_VALUE_ENCODE_HUC_STATUS2_VALUE,
     __MEDIA_USER_FEATURE_VALUE_GROUP_ID_ID,
@@ -323,7 +310,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_ENCODE_L3_CACHE_SQCREG1_OVERRIDE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_L3_CACHE_SQCREG4_OVERRIDE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_L3_LRA_1_REG1_OVERRIDE_ID,
-    __MEDIA_USER_FEATURE_VALUE_NULL_HW_ACCELERATION_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VDBOX_ID_USED,
     __MEDIA_USER_FEATURE_VALUE_VDENC_IN_USE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_CSC_METHOD_ID,
@@ -338,7 +324,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_BSDMPCROWSTORECACHE_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_MPRROWSTORECACHE_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VDENCROWSTORECACHE_DISABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_SIM_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_IS_CODEC_ROW_STORE_CACHE_ENABLED_ID,
     __MEDIA_USER_FEATURE_VALUE_BREAK_IN_CODECHAL_CREATE_ID,
     __MEDIA_USER_FEATURE_VALUE_MEDIASOLO_ENABLE_ID,
@@ -411,6 +396,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __VPHAL_RT_COMPRESSIBLE_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
     __VPHAL_ENABLE_1K_1DLUT_ID,
+    __VPHAL_ENABLE_CPU_GENERATE_3DLUT_ID,
 #endif
 #if (_DEBUG || _RELEASE_INTERNAL)
     __VPHAL_ENABLE_COMPUTE_CONTEXT_ID,
@@ -418,8 +404,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MOS_USER_FEATURE_KEY_XML_AUTOGEN_ID,
     __MOS_USER_FEATURE_KEY_XML_FILEPATH_ID,
     __MOS_USER_FEATURE_KEY_XML_DUMP_GROUPS_ID,
-    __MEDIA_USER_FEATURE_VALUE_FORCE_VEBOX_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_VEBOX_SCALABILITY_MODE_ID,
     __MEDIA_USER_FEATURE_VALUE_VEBOX_SPLIT_RATIO_ID,
     __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_MODE_SWITCH_THRESHOLD1_ID,
     __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_MODE_SWITCH_THRESHOLD2_ID,
@@ -434,13 +418,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_RDOQ_PERF_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVC_TCBRC_QUALITY_BOOST_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_WATCHDOG_TIMER_THRESHOLD,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_DECODE_VIRTUAL_ENGINE_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_DECODE_VE_CTXSCHEDULING_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_LINUX_FRAME_SPLIT_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_ENCODE_VIRTUAL_ENGINE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENABLE_ENCODE_VE_CTXSCHEDULING_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_VE_DEBUG_OVERRIDE_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_HCP_SCALABILITY_DECODE_ID,
     __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_ALWAYS_FRAME_SPLIT_ID,
     __MEDIA_USER_FEATURE_VALUE_SCALABILITY_OVERRIDE_SPLIT_WIDTH_IN_MINCB,
     __MEDIA_USER_FEATURE_VALUE_SCALABILITY_FE_SEPARATE_SUBMISSION_IN_USE_ID,
@@ -453,32 +431,8 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VPP_APOGEIOS_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_EXTERNAL_COPY_SYNC_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_UMD_OCA_ID,
-    __MEDIA_USER_FEATURE_VALUE_COUNT_FOR_OCA_BUFFER_LEAKED_ID,
-    __MEDIA_USER_FEATURE_VALUE_COUNT_FOR_OCA_1ST_LEVEL_BB_END_MISSED_ID,
-    __MEDIA_USER_FEATURE_VALUE_COUNT_FOR_ADDITIONAL_OCA_BUFFER_ALLOCATED_ID,
-    __MEDIA_USER_FEATURE_VALUE_OCA_STATUS_ID,
-    __MEDIA_USER_FEATURE_VALUE_OCA_ERROR_HINT_ID,
-    __MEDIA_USER_FEATURE_VALUE_IS_INDIRECT_STATE_HEAP_INVALID_ID,
     __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_START_COUNTER_ID,
     __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_END_COUNTER_ID,
-#if (_DEBUG || _RELEASE_INTERNAL)
-    __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_MODE_ID,
-    __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_FREQ_ID,
-    __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_HINT_ID,
-    __MEDIA_USER_FEATURE_VALUE_OS_API_FAIL_SIMULATE_TYPE_ID,
-    __MEDIA_USER_FEATURE_VALUE_OS_API_FAIL_SIMULATE_MODE_ID,
-    __MEDIA_USER_FEATURE_VALUE_OS_API_FAIL_SIMULATE_FREQ_ID,
-    __MEDIA_USER_FEATURE_VALUE_OS_API_FAIL_SIMULATE_HINT_ID,
-    __MEDIA_USER_FEATURE_VALUE_MEDIA_TILE_ENCODING_1_DEFAULT_ID,
-    __MEDIA_USER_FEATURE_VALUE_TILE_ENCODING_1_INTERNAL_USED_ID,
-    __MEDIA_USER_FEATURE_VALUE_TILE_ENCODING_3_INTERNAL_USED_ID,
-#endif
-#if (_DEBUG || _RELEASE_INTERNAL)
-        __MEDIA_USER_FEATURE_VALUE_ENABLE_GUC_SUBMISSION_ID,
-#endif
-    __MEDIA_USER_FEATURE_VALUE_PERF_UTILITY_TOOL_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_PERF_OUTPUT_DIRECTORY_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_HEVCD_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_AVCD_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_VP8D_ENABLE_ID,
@@ -487,10 +441,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_JPEGD_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_RA_MODE_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_LOCAL_MEMORY_LEVEL_SWITCH_ID,
-    __MEDIA_USER_FEATURE_VALUE_NULLHW_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_PLATFORM_ID,
-    __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_STEPPING_ID,
-    __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_DEVICE_ID,
     __MEDIA_USER_FEATURE_VALUE_DISABLE_TLB_PREFETCH_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
     __MEDIA_USER_FEATURE_VALUE_FORCE_DECODE_RESOURCE_LOCKABLE_ID,
@@ -501,6 +451,24 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_SKIP_FRAME_IN_USE_ID,
     __MEDIA_USER_FEATURE_VALUE_HUC_LOAD_STATUS_ID,
     __MEDIA_USER_FEATURE_VALUE_HUC_REPORT_CRITICAL_ERROR_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1_DECODE_DRIVER_S2L_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VDENC_TILEREPLAY_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VDENC_RGB_ENCODING_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VDENC_CAPTURE_MODE_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_LOAD_KERNEL_INPUT_ID,
+    __MEDIA_USER_FEATURE_VALUE_VDENC_ULTRA_MODE_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VME_BREAK12_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VDENC_FORCE_DELTA_QP_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VME_BRC_LTR_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VDENC_FORCE_SCALABILITY_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VME_DISABLE_PANIC_MODE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VME_NUM_MEDIA_HWWALKER_INUSE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HEVC_VME_ENABLE_RENDER_CONTEXT_ID,
+    __MEDIA_USER_FEATURE_VALUE_MFE_FAST_SUBMIT_ID,
+    __MEDIA_USER_FEATURE_VALUE_MFE_MULTISTREAM_SCHEDULER_ID,
+    __MEDIA_USER_FEATURE_VALUE_LOCKABLE_RESOURCE_ID,
+    __MEDIA_USER_FEATURE_VALUE_MMC_ENC_POST_CDEF_RECON_COMPRESSIBLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_MMC_ENC_POST_CDEF_RECON_COMPRESSMODE_ID,
 
     __MOS_USER_FEATURE_KEY_MAX_ID,
 } MOS_USER_FEATURE_VALUE_ID;
