@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2012-2017, Intel Corporation
+* Copyright (c) 2012-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -124,7 +124,7 @@ public:
     //! \return   MOS_STATUS
     //!           MOS_STATUS_SUCCESS if success, else fail reason
     //!
-    MOS_STATUS ContextBufferInit(
+    virtual MOS_STATUS ContextBufferInit(
             uint8_t *ctxBuffer,
             bool setToKey);
 
@@ -186,15 +186,6 @@ public:
     //!
     virtual MOS_STATUS DetermineDecodePhase();
 
-    //!
-    //! \brief  Sets cenc decoder batch buffer
-    //! \param    [in] cmdBuffer
-    //!           Pointer of command buffer.
-    //! \return   MOS_STATUS
-    //!           MOS_STATUS_SUCCESS if success, else fail reason
-    //!
-    virtual MOS_STATUS SetCencBatchBuffer( PMOS_COMMAND_BUFFER cmdBuffer) override;
-
     // Parameters passed by application
     uint16_t                  m_usFrameWidthAlignedMinBlk;   //!< Picture Width aligned to minBlock
     uint16_t                  m_usFrameHeightAlignedMinBlk;  //!< Picture Height aligned to minBlock
@@ -202,13 +193,13 @@ public:
     uint8_t                   m_chromaFormatinProfile;       //!< Chroma format with current profilce
     uint32_t                  m_dataSize;                    //!< Data size
     uint32_t                  m_dataOffset;                  //!< Date offset
-    PCODEC_VP9_PIC_PARAMS     m_vp9PicParams;                //!< Pointer to VP9 picture parameter
-    PCODEC_VP9_SEGMENT_PARAMS m_vp9SegmentParams;            //!< Pointer to VP9 segment parameter
-    PCODEC_VP9_SLICE_PARAMS   m_vp9SliceParams;              //!< Pointer to VP9 slice parameter
+    PCODEC_VP9_PIC_PARAMS     m_vp9PicParams = nullptr;                //!< Pointer to VP9 picture parameter
+    PCODEC_VP9_SEGMENT_PARAMS m_vp9SegmentParams = nullptr;            //!< Pointer to VP9 segment parameter
+    PCODEC_VP9_SLICE_PARAMS   m_vp9SliceParams = nullptr;              //!< Pointer to VP9 slice parameter
     MOS_SURFACE               m_destSurface;                 //!< MOS_SURFACE of render surface
-    PMOS_RESOURCE             m_presLastRefSurface;          //!< Pointer to last reference surface
-    PMOS_RESOURCE             m_presGoldenRefSurface;        //!< Pointer to golden reference surface
-    PMOS_RESOURCE             m_presAltRefSurface;           //!< Pointer to alternate reference surface
+    PMOS_RESOURCE             m_presLastRefSurface = nullptr;          //!< Pointer to last reference surface
+    PMOS_RESOURCE             m_presGoldenRefSurface = nullptr;        //!< Pointer to golden reference surface
+    PMOS_RESOURCE             m_presAltRefSurface = nullptr;           //!< Pointer to alternate reference surface
     MOS_SURFACE               m_lastRefSurface;              //!< MOS_SURFACE of last reference surface
     MOS_SURFACE               m_goldenRefSurface;            //!< MOS_SURFACE of golden reference surface
     MOS_SURFACE               m_altRefSurface;               //!< MOS_SURFACE of alternate reference surface
