@@ -497,6 +497,15 @@ protected:
         PVPHAL_RENDERING_DATA_COMPOSITE pRenderingData,
         bool*                           pbColorfill);
 
+    //!
+    //! \brief    Adjust Params Based On Fc Limit
+    //! \param    [in,out] PCVPHAL_RENDER_PARAMS
+    //!           Pointer to pcRenderParam parameters.
+    //! \return   bool
+    //!
+    bool AdjustParamsBasedOnFcLimit(
+        PCVPHAL_RENDER_PARAMS pcRenderParam);
+
     //!
     //! \brief    Set Sampler AVS parameters
     //! \param    [in] pRenderingData
@@ -704,6 +713,34 @@ protected:
         int32_t*                            pSamplerIndex,
         PMHW_SAMPLER_TYPE                   pSamplerType);
 
+    //!
+    //! \brief    Update SamplerStateParams associated with a surface state for composite
+    //! \param    [in] pSamplerStateParams
+    //!           Pointer to SamplerStateParams
+    //! \param    [in] pEntry
+    //!           Pointer to Surface state
+    //! \param    [in] pRenderData
+    //!           Pointer to RenderData
+    //! \param    [in] uLayerNum
+    //!           Layer total number
+    //! \param    [in] SamplerFilterMode
+    //!           SamplerFilterMode to be set
+    //! \param    [out] pSamplerIndex
+    //!           Pointer to Sampler Index
+    //! \param    [out] pSurface
+    //!           point to Surface
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise MOS_STATUS_UNKNOWN
+    //!
+    virtual MOS_STATUS SetSamplerFilterMode(
+        PMHW_SAMPLER_STATE_PARAM       &pSamplerStateParams,
+        PRENDERHAL_SURFACE_STATE_ENTRY  pEntry,
+        PVPHAL_RENDERING_DATA_COMPOSITE pRenderData,
+        uint32_t                        uLayerNum,
+        MHW_SAMPLER_FILTER_MODE         SamplerFilterMode,
+        int32_t                        *pSamplerIndex,
+        PVPHAL_SURFACE                  pSource);
+
     //!
     //! \brief    Check whether the 3Dsampler use for Y plane
     //! \param    [in] SamplerID
@@ -852,6 +889,16 @@ protected:
         int32_t         iSources,
         bool            isTargetY);
 
+    //!
+    //! \brief    Decompress the Surface
+    //! \details  Decompress the interlaced Surface which is in the RC compression mode
+    //! \param    [in,out] pSource
+    //!           Pointer to Source Surface
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS DecompressInterlacedSurf(PVPHAL_SURFACE pSource);
+
 private:
     //!
     //! \brief    Prepare phases for composite and determine intermediate colorspace
@@ -1027,16 +1074,6 @@ private:
         PVPHAL_SURFACE                  pSource,
         PRENDERHAL_SURFACE_STATE_PARAMS pSurfaceParams);
 
-    //!
-    //! \brief    Decompress the Surface
-    //! \details  Decompress the interlaced Surface which is in the RC compression mode
-    //! \param    [in,out] pSource
-    //!           Pointer to Source Surface
-    //! \return   MOS_STATUS
-    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
-    //!
-    MOS_STATUS DecompressInterlacedSurfInRCMode(PVPHAL_SURFACE pSource);
-
     //!
     //! \brief    Allocate Composite BatchBuffer
     //! \details  Allocate Composite BatchBuffer, search from existing BBs for a match. If
