@@ -28,6 +28,7 @@
 //!
 #include "vphal_render_vebox_base.h"
 #include "vphal_render_sfc_g11_base.h"
+#include "vp_hal_ddi_utils.h"
 
 #if __VPHAL_SFC_SUPPORTED
 
@@ -100,14 +101,15 @@ void VphalSfcStateG11::GetInputWidthHeightAlignUnit(
     MOS_FORMAT              inputFormat,
     MOS_FORMAT              outputFormat,
     uint16_t                &widthAlignUnit,
-    uint16_t                &heightAlignUnit)
+    uint16_t                &heightAlignUnit,
+    bool                    isInterlacedScaling)
 {
     MOS_UNUSED(outputFormat);
     widthAlignUnit  = 1;
     heightAlignUnit = 1;
 
     // Apply alignment restriction to Region of the input frame.
-    switch (VpHal_GetSurfaceColorPack(inputFormat))
+    switch (VpHalDDIUtils::GetSurfaceColorPack(inputFormat))
     {
         case VPHAL_COLORPACK_420:
             widthAlignUnit  = 2;
