@@ -25,8 +25,8 @@
 //!
 #include "codechal_decoder.h"
 #include "codechal_decode_scalability_g12.h"
-#include "media_user_settings_mgr_g12.h"
 #include "mos_os_virtualengine_next.h"
+#include "mos_os_cp_interface_specific.h"
 
 //==<Functions>=======================================================
 //!
@@ -59,7 +59,7 @@ static MOS_STATUS CodecHalDecodeScalability_CalculateScdryCmdBufIndex_G12(
     {
         *pdwBufIdxPlus1 = pScalabilityState->u8RtCurPipe + 1;
         if(pScalabilityStateBase->pHwInterface->GetOsInterface()->phasedSubmission
-        && !pScalabilityStateBase->pHwInterface->GetOsInterface()->bGucSubmission)
+        && !pScalabilityStateBase->pHwInterface->GetOsInterface()->bParallelSubmission)
         {
             /*  3 tiles 2 pipe for example:
                 cur phase               cur pip
@@ -253,7 +253,7 @@ MOS_STATUS CodecHalDecodeScalability_GetCmdBufferToUse_G12(
 
     if (!CodecHalDecodeScalabilityIsFESeparateSubmission(pScalabilityState) ||
         CodecHalDecodeScalabilityIsBEPhaseG12(pScalabilityState) ||
-        pScalabilityStateBase->pHwInterface->GetOsInterface()->bGucSubmission)
+        pScalabilityStateBase->pHwInterface->GetOsInterface()->bParallelSubmission)
     {
         pScalabilityState->bUseSecdryCmdBuffer = true;
         CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_GetVESecondaryCmdBuffer_G12(pScalabilityState, pScdryCmdBuf));
@@ -699,7 +699,7 @@ MOS_STATUS CodecHalDecodeScalability_FEBESync_G12(
     //FE& BE0 Sync. to refine (ucNumVdbox > )for GT3
     if (HcpDecPhase == CODECHAL_HCP_DECODE_PHASE_BE0
         && pScalabilityState->pHwInterface->GetMfxInterface()->GetNumVdbox() > 2
-        && !pOsInterface->bGucSubmission)
+        && !pOsInterface->bParallelSubmission)
     {
         if (pScalabilityState->bFESeparateSubmission)
         {
@@ -894,6 +894,7 @@ MOS_STATUS CodecHalDecodeScalability_ReadCSEngineIDReg_G12(
         pDecodeStatusBuf->m_csEngineIdOffset + sizeof(uint32_t)* ucPhaseIndex +
         sizeof(uint32_t) * 2;
 
+    MOS_ZeroMemory(&StoreRegParams, sizeof(StoreRegParams));
     StoreRegParams.presStoreBuffer = &pDecodeStatusBuf->m_statusBuffer;
     StoreRegParams.dwOffset = dwOffset;
     StoreRegParams.dwRegister = pMmioRegisters->csEngineIdOffset;
@@ -1018,7 +1019,7 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
         pScalabilityState->bFESeparateSubmission = false;
     }
 
-    if(osInterface->bGucSubmission)
+    if(osInterface->bParallelSubmission)
     {
         pScalabilityState->bFESeparateSubmission = false;
     }
@@ -1064,7 +1065,7 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     VEInitParms.ucMaxNumPipesInUse = CodecHalDecodeMaxNumPipesInUseG12(vdboxNum);
     VEInitParms.ucNumOfSdryCmdBufSets = CODECHAL_SCALABILITY_DECODE_SECONDARY_CMDBUFSET_NUM;
     VEInitParms.ucMaxNumOfSdryCmdBufInOneFrame = pScalabilityState->bFESeparateSubmission ? VEInitParms.ucMaxNumPipesInUse : (VEInitParms.ucMaxNumPipesInUse + 1);
-    CODECHAL_DECODE_CHK_STATUS(Mos_VirtualEngineInterface_Initialize(osInterface, &VEInitParms));
+    CODECHAL_DECODE_CHK_STATUS(osInterface->pfnVirtualEngineInterfaceInitialize(osInterface, &VEInitParms));
     pScalabilityState->pVEInterface = pVEInterface = osInterface->pVEInterf;
 
     if (pVEInterface->pfnVEGetHintParams)
@@ -1460,7 +1461,7 @@ MOS_STATUS CodecHalDecodeScalability_AllocateResources_VariableSizes_G12(
     // for multi-pipe scalability mode
     if (pScalabilityState->ucNumVdbox > 2)
     {
-        if (pScalabilityState->bFESeparateSubmission && pOsInterface->bGucSubmission)
+        if (pScalabilityState->bFESeparateSubmission && pOsInterface->bParallelSubmission)
         {
             for (int i = 1; i < CODECHAL_HCP_STREAMOUT_BUFFER_MAX_NUM; i++)
             {
@@ -1980,7 +1981,7 @@ void CodecHalDecodeScalability_DecPhaseToSubmissionType_G12(
                 pCmdBuffer->iSubmissionType |= ((pScalabilityState->u8RtCurPipe - 1) << SUBMISSION_TYPE_MULTI_PIPE_SLAVE_INDEX_SHIFT);
             }
 
-            if (!(pScalabilityState->pHwInterface->GetOsInterface()->bGucSubmission)
+            if (!(pScalabilityState->pHwInterface->GetOsInterface()->bParallelSubmission)
             && (pScalabilityState->u8RtCurPhase == pScalabilityState->u8RtPhaseNum - 1))
             {
                 if (pScalabilityState->u8RtCurPipe == pScalabilityState->u8RtPipeInLastPhase - 1)
