@@ -20,8 +20,8 @@
 * OTHER DEALINGS IN THE SOFTWARE.
 */
 //!
-//! \file     codechal_encode_hevc_mbenc_g12.cpp
-//! \brief    HEVC dual-pipe encoder mbenc kernels for GEN12.
+//! \file     codechal_encode_hevc_brc_g12.cpp
+//! \brief    HEVC dual-pipe encoder brc kernels for GEN12.
 //!
 
 #include "codechal_encode_hevc_mbenc_g12.h"
@@ -148,7 +148,21 @@ MOS_STATUS CodecHalHevcBrcG12::FreeBrcResources()
         CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->DestroyProgram(m_cmProgramBrcLCUQP));
         m_cmProgramBrcLCUQP = nullptr;
     }
-
+    if (m_threadSpaceBrcInitReset)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->DestroyThreadSpace(m_threadSpaceBrcInitReset));
+        m_threadSpaceBrcInitReset = nullptr;
+    }
+    if (m_threadSpaceBrcUpdate)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->DestroyThreadSpace(m_threadSpaceBrcUpdate));
+        m_threadSpaceBrcUpdate = nullptr;
+    }
+    if (m_threadSpaceBrcLCUQP)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->DestroyThreadSpace(m_threadSpaceBrcLCUQP));
+        m_threadSpaceBrcLCUQP = nullptr;
+    }
     return eStatus;
 }
 
@@ -218,26 +232,26 @@ MOS_STATUS CodecHalHevcBrcG12::SetupKernelArgsBrcInit()
     return eStatus;
 }
 
-MOS_STATUS CodecHalHevcBrcG12::SetupThreadSpace(CmKernel *cmKernel, CmThreadSpace * threadSpace)
+MOS_STATUS CodecHalHevcBrcG12::SetupThreadSpace(CmKernel *cmKernel, CmThreadSpace *& threadSpace)
 {
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(cmKernel->SetThreadCount(1));
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->CreateThreadSpace(1, 1, threadSpace));
 
+    CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->CreateThreadSpace(1, 1, threadSpace));
     CODECHAL_ENCODE_CHK_STATUS_RETURN(cmKernel->AssociateThreadSpace(threadSpace));
     return eStatus;
 }
 
-MOS_STATUS CodecHalHevcBrcG12::SetupBrcLcuqpThreadSpace(CmKernel *cmKernel, CmThreadSpace * threadSpace)
+MOS_STATUS CodecHalHevcBrcG12::SetupBrcLcuqpThreadSpace(CmKernel *cmKernel, CmThreadSpace *& threadSpace)
 {
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
     uint32_t xThread = (encoderBrc->m_downscaledWidthInMb4x * SCALE_FACTOR_4x + 15) >> 4;
     uint32_t yThread = (encoderBrc->m_downscaledHeightInMb4x * SCALE_FACTOR_4x + 7) >> 3;
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(cmKernel->SetThreadCount(xThread * yThread));
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->CreateThreadSpace(xThread, yThread, threadSpace));
 
+    CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->CreateThreadSpace(xThread, yThread, threadSpace));
     CODECHAL_ENCODE_CHK_STATUS_RETURN(cmKernel->AssociateThreadSpace(threadSpace));
 
     return eStatus;
@@ -267,7 +281,6 @@ MOS_STATUS CodecHalHevcBrcG12::EncodeBrcInitResetKernel()
 {
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
     // Setup curbe for BrcInitReset kernel
-    CODECHAL_HEVC_BRC_KRNIDX brcKrnIdx = encoderBrc->m_brcInit ? CODECHAL_HEVC_BRC_INIT : CODECHAL_HEVC_BRC_RESET;
     if (encoderBrc->m_brcInit)
     {
         m_cmKrnBrc = m_cmKrnBrcInit;
@@ -277,10 +290,20 @@ MOS_STATUS CodecHalHevcBrcG12::EncodeBrcInitResetKernel()
         m_cmKrnBrc = m_cmKrnBrcReset;
     }
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupThreadSpace(m_cmKrnBrc, m_threadSpaceBrcInit));
+    /* Only one CM kernel is used to switch between brcInit and brcReset, same rule for threadSpace.
+       Destroy old one and create a new threadSpace when only brcReset is triggered. */
+    if (encoderBrc->m_brcReset && m_threadSpaceBrcInitReset)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->DestroyThreadSpace(m_threadSpaceBrcInitReset));
+        m_threadSpaceBrcInitReset = nullptr;
+    }
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(BrcInitResetCurbe(
-        brcKrnIdx));
+    if (!m_threadSpaceBrcInitReset)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupThreadSpace(m_cmKrnBrc, m_threadSpaceBrcInitReset));
+    }
+
+    CODECHAL_ENCODE_CHK_STATUS_RETURN(BrcInitResetCurbe());
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupSurfacesBrcInit());
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupKernelArgsBrcInit());
@@ -306,7 +329,7 @@ MOS_STATUS CodecHalHevcBrcG12::EncodeBrcInitResetKernel()
     return eStatus;
 }
 
-MOS_STATUS CodecHalHevcBrcG12::BrcInitResetCurbe(CODECHAL_HEVC_BRC_KRNIDX  brcKrnIdx)
+MOS_STATUS CodecHalHevcBrcG12::BrcInitResetCurbe()
 {
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
 
@@ -530,7 +553,15 @@ MOS_STATUS CodecHalHevcBrcG12::BrcInitResetCurbe(CODECHAL_HEVC_BRC_KRNIDX  brcKr
     encoderBrc->curbe.DW24_DeviationThreshold6_Iframe = (uint32_t)(50 * pow(0.66, bpsRatio));
     encoderBrc->curbe.DW24_DeviationThreshold7_Iframe = (uint32_t)(50 * pow(0.9, bpsRatio));
 
-    encoderBrc->curbe.DW26_RandomAccess = !encoderBrc->m_lowDelay;
+    if (encoderBrc->m_hevcSeqParams->HierarchicalFlag && !encoderBrc->m_hevcSeqParams->LowDelayMode &&
+        (encoderBrc->m_hevcSeqParams->GopRefDist == 4 || encoderBrc->m_hevcSeqParams->GopRefDist == 8))
+    {
+        encoderBrc->curbe.DW26_RandomAccess = true;
+    }
+    else
+    {
+        encoderBrc->curbe.DW26_RandomAccess = false;
+    }
 
     if (encoderBrc->m_brcInit)
     {
@@ -543,8 +574,7 @@ MOS_STATUS CodecHalHevcBrcG12::BrcInitResetCurbe(CODECHAL_HEVC_BRC_KRNIDX  brcKr
     return eStatus;
 }
 
-MOS_STATUS CodecHalHevcBrcG12::BrcUpdateCurbe(
-    CODECHAL_HEVC_BRC_KRNIDX    brcKrnIdx)
+MOS_STATUS CodecHalHevcBrcG12::BrcUpdateCurbe()
 {
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
 
@@ -660,10 +690,12 @@ MOS_STATUS CodecHalHevcBrcG12::EncodeBrcFrameUpdateKernel()
     encoderBrc->GetOsInterface()->pfnSetPerfTag(encoderBrc->GetOsInterface(), perfTag.Value);
     encoderBrc->GetOsInterface()->pfnIncPerfBufferID(encoderBrc->GetOsInterface());
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupThreadSpace(m_cmKrnBrcUpdate, m_threadSpaceBrcUpdate));
+    if (!m_threadSpaceBrcUpdate)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupThreadSpace(m_cmKrnBrcUpdate, m_threadSpaceBrcUpdate));
+    }
 
-    CODECHAL_HEVC_BRC_KRNIDX brcKrnIdx = CODECHAL_HEVC_BRC_FRAME_UPDATE;
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(BrcUpdateCurbe(brcKrnIdx));
+    CODECHAL_ENCODE_CHK_STATUS_RETURN(BrcUpdateCurbe());
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupSurfacesBrcUpdate());
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupKernelArgsBrcUpdate());
     CODECHAL_DEBUG_TOOL(
@@ -803,8 +835,7 @@ MOS_STATUS CodecHalHevcBrcG12::EncodeBrcLcuUpdateKernel()
     encoderBrc->GetOsInterface()->pfnSetPerfTag(encoderBrc->GetOsInterface(), perfTag.Value);
     encoderBrc->GetOsInterface()->pfnIncPerfBufferID(encoderBrc->GetOsInterface());
 
-    CODECHAL_HEVC_BRC_KRNIDX brcKrnIdx = CODECHAL_HEVC_BRC_LCU_UPDATE;
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(BrcUpdateCurbe(brcKrnIdx));
+    CODECHAL_ENCODE_CHK_STATUS_RETURN(BrcUpdateCurbe());
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupSurfacesBrcLcuQp());
 
     if (encoderBrc->m_hevcPicParams->NumROI)
@@ -814,7 +845,16 @@ MOS_STATUS CodecHalHevcBrcG12::EncodeBrcLcuUpdateKernel()
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupKernelArgsBrcLcuQp());
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupBrcLcuqpThreadSpace(m_cmKrnBrcLCUQP, m_threadSpaceBrcLCUQP));
+    if (encoderBrc->m_resolutionChanged && m_threadSpaceBrcLCUQP)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmDev->DestroyThreadSpace(m_threadSpaceBrcLCUQP));
+        m_threadSpaceBrcLCUQP = nullptr;
+    }
+
+    if (!m_threadSpaceBrcLCUQP)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(SetupBrcLcuqpThreadSpace(m_cmKrnBrcLCUQP, m_threadSpaceBrcLCUQP));
+    }
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(encoderBrc->m_cmTask->AddKernel(m_cmKrnBrcLCUQP));
 
