@@ -1022,12 +1022,6 @@ VAStatus DdiMediaDecode::CreateBuffer(
             buf->format     = Media_Format_CPU;
             break;
         case VASubsetsParameterBufferType:
-            //maximum entry point supported should not be more than 440
-            if(numElements > 440)
-            {
-                va = VA_STATUS_ERROR_INVALID_PARAMETER;
-                goto CleanUpandReturn;
-            }
             buf->pData      = (uint8_t*)MOS_AllocAndZeroMemory(size * numElements);
             buf->format     = Media_Format_CPU;
             break;
