@@ -87,6 +87,12 @@ VAStatus DdiDecodeJPEG::ParseSliceParams(
     int32_t startIdx = m_numScans;
     for (j = 0; j < numSlices; j++)
     {
+        if (j + startIdx >= jpegNumComponent ||
+            slcParam[j].num_components > jpegNumComponent)
+        {
+            return VA_STATUS_ERROR_INVALID_PARAMETER;
+        }
+
         for (i = 0; i < slcParam[j].num_components; i++)
         {
             jpegSliceParam->ScanHeader[j + startIdx].ComponentSelector[i] = slcParam[j].components[i].component_selector;
@@ -620,7 +626,9 @@ VAStatus DdiDecodeJPEG::SetDecodeParams()
     if((m_ddiDecodeCtx->RTtbl.pCurrentRT->format == Media_Format_NV12)
         &&(jpegPicParam->m_chromaType == jpegYUV444))
     {
+        UnRegisterRTSurfaces(&(m_ddiDecodeCtx->RTtbl), m_ddiDecodeCtx->RTtbl.pCurrentRT);
         m_ddiDecodeCtx->RTtbl.pCurrentRT = DdiMedia_ReplaceSurfaceWithNewFormat(m_ddiDecodeCtx->RTtbl.pCurrentRT, Media_Format_444P);
+        RegisterRTSurfaces(&(m_ddiDecodeCtx->RTtbl), m_ddiDecodeCtx->RTtbl.pCurrentRT);
     }
     if(m_ddiDecodeCtx->RTtbl.pCurrentRT != nullptr)
     {
