@@ -34,7 +34,7 @@
 template<class _Fun, class... _Types>
 void MOS_DEVULT_FuncCall(_Fun fun, _Types&&... ags)
 {
-    if (MosUtilities::m_mosUltFlag && fun)
+    if (MosUtilities::m_mosUltFlag && (*MosUtilities::m_mosUltFlag) && fun)
     {
         fun(std::forward<_Types>(ags)...);
     }
