@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -31,7 +31,7 @@
 #include "linux_media_skuwa.h"
 #include "mos_utilities.h"
 #include "mos_os_specific.h"
-#include "media_user_setting.h"
+#include "media_user_setting_specific.h"
 
 static constexpr uint32_t singleVeboxSubSliceNumMax = 24;
 
@@ -522,6 +522,8 @@ static bool InitAdlsMediaSku(struct GfxDeviceInfo *devInfo,
 
     MEDIA_WR_SKU(skuTable, FtrAV1VLDLSTDecoding, 1);
 
+    MEDIA_WR_SKU(skuTable, FtrHeight8AlignVE3DLUTDualPipe, 1);
+
     //Disable VP8 for ADLS
     MEDIA_WR_SKU(skuTable, FtrIntelVP8VLDDecoding, 0);
 
@@ -529,6 +531,19 @@ static bool InitAdlsMediaSku(struct GfxDeviceInfo *devInfo,
     MEDIA_WR_SKU(skuTable, FtrDecodeHEVC422VTScalaDisable, 1);
     MEDIA_WR_SKU(skuTable, FtrE2ECompression, 1);
 
+    //RPL-S
+    if (drvInfo->devId == 0xA780 || 
+        drvInfo->devId == 0xA781 || 
+        drvInfo->devId == 0xA782 || 
+        drvInfo->devId == 0xA783 || 
+        drvInfo->devId == 0xA788 || 
+        drvInfo->devId == 0xA789 || 
+        drvInfo->devId == 0xA78A || 
+        drvInfo->devId == 0xA78B)
+    {
+        MEDIA_WR_SKU(skuTable, FtrGucSubmission, 1);
+    }
+
     return true;
 }
 
@@ -547,6 +562,7 @@ static bool InitAdlsMediaWa(struct GfxDeviceInfo* devInfo,
     //ADL-S need enable MMC for all stepping
     MEDIA_WR_WA(waTable, WaDisableCodecMmc, 0);
     MEDIA_WR_WA(waTable, WaDisableVPMmc, 0);
+    MEDIA_WR_WA(waTable, WaDisableClearCCS, 1);
 
     return true;
 }
@@ -597,6 +613,8 @@ static bool InitAdlpMediaWa(struct GfxDeviceInfo *devInfo,
 
     //ADL-P not need this
     MEDIA_WR_WA(waTable, Wa_1409820462, 0);
+    MEDIA_WR_WA(waTable, WaDisableClearCCS, 1);
+
     return true;
 }
 
@@ -627,7 +645,8 @@ static bool InitAdlnMediaSku(struct GfxDeviceInfo *devInfo,
     {
         MEDIA_WR_SKU(skuTable, FtrGT0_5, 1);
     }
-
+    
+    MEDIA_WR_SKU(skuTable, FtrHeight8AlignVE3DLUTDualPipe, 1);
     MEDIA_WR_SKU(skuTable, FtrAV1VLDLSTDecoding, 1);
     MEDIA_WR_SKU(skuTable, FtrGucSubmission, 1);
     MEDIA_WR_SKU(skuTable, FtrDecodeHEVC422VTScalaDisable, 1);
@@ -651,6 +670,7 @@ static bool InitAdlnMediaWa(struct GfxDeviceInfo *devInfo,
     //ADL-N need enable MMC for all stepping
     MEDIA_WR_WA(waTable, WaDisableCodecMmc, 0);
     MEDIA_WR_WA(waTable, WaDisableVPMmc, 0);
+    MEDIA_WR_WA(waTable, WaDisableClearCCS, 1);
 
     return true;
 }
