@@ -37,38 +37,36 @@
 #include "codechal_decode_hybrid_vp9.h"
 #endif
 
-extern template class MediaInterfacesFactory<MhwInterfaces>;
-extern template class MediaInterfacesFactory<MmdDevice>;
-extern template class MediaInterfacesFactory<CodechalDevice>;
-extern template class MediaInterfacesFactory<CMHalDevice>;
-extern template class MediaInterfacesFactory<MosUtilDevice>;
-extern template class MediaInterfacesFactory<VphalDevice>;
-extern template class MediaInterfacesFactory<RenderHalDevice>;
-extern template class MediaInterfacesFactory<Nv12ToP010Device>;
-extern template class MediaInterfacesFactory<DecodeHistogramDevice>;
+extern template class MediaFactory<uint32_t, MhwInterfaces>;
+extern template class MediaFactory<uint32_t, MmdDevice>;
+extern template class MediaFactory<uint32_t, CodechalDevice>;
+extern template class MediaFactory<uint32_t, CMHalDevice>;
+extern template class MediaFactory<uint32_t, VphalDevice>;
+extern template class MediaFactory<uint32_t, RenderHalDevice>;
+extern template class MediaFactory<uint32_t, Nv12ToP010Device>;
+extern template class MediaFactory<uint32_t, DecodeHistogramDevice>;
 
 static bool sklRegisteredVphal =
-    MediaInterfacesFactory<VphalDevice>::
-    RegisterHal<VphalInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
+    MediaFactory<uint32_t, VphalDevice>::
+    Register<VphalInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
 
 MOS_STATUS VphalInterfacesG9Skl::Initialize(
     PMOS_INTERFACE  osInterface,
-    PMOS_CONTEXT    osDriverContext,
     bool            bInitVphalState,
-    MOS_STATUS      *eStatus)
+    MOS_STATUS      *eStatus,
+    bool            clearViewMode)
 {
-    m_vphalState = MOS_New(
+    m_vpBase = MOS_New(
         VphalState,
         osInterface,
-        osDriverContext,
         eStatus);
 
     return *eStatus;
 }
 
 static bool sklRegisteredMhw =
-    MediaInterfacesFactory<MhwInterfaces>::
-    RegisterHal<MhwInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
+    MediaFactory<uint32_t, MhwInterfaces>::
+    Register<MhwInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
 
 #define PLATFORM_INTEL_SKL 7
 #define GENX_SKL           5
@@ -98,7 +96,7 @@ MOS_STATUS MhwInterfacesG9Skl::Initialize(
 
     // MHW_CP and MHW_MI must always be created
     MOS_STATUS status;
-    m_cpInterface = Create_MhwCpInterface(osInterface);
+    m_cpInterface = osInterface->pfnCreateMhwCpInterface(osInterface);
     m_miInterface = MOS_New(Mi, m_cpInterface, osInterface);
 
     if (params.Flags.m_render)
@@ -141,10 +139,10 @@ MOS_STATUS MhwInterfacesG9Skl::Initialize(
 
     return MOS_STATUS_SUCCESS;
 }
-#ifdef _MMC_SUPPORTED
+#if defined(_MMC_SUPPORTED) && defined(ENABLE_KERNELS) && !defined(_FULL_OPEN_SOURCE)
 static bool sklRegisteredMmd =
-    MediaInterfacesFactory<MmdDevice>::
-    RegisterHal<MmdDeviceG9Skl>((uint32_t)IGFX_SKYLAKE);
+    MediaFactory<uint32_t, MmdDevice>::
+    Register<MmdDeviceG9Skl>((uint32_t)IGFX_SKYLAKE);
 
 MOS_STATUS MmdDeviceG9Skl::Initialize(
     PMOS_INTERFACE osInterface,
@@ -198,8 +196,8 @@ MOS_STATUS MmdDeviceG9Skl::Initialize(
 }
 #endif
 static bool sklRegisteredNv12ToP010 =
-    MediaInterfacesFactory<Nv12ToP010Device>::
-    RegisterHal<Nv12ToP010DeviceG9Skl>((uint32_t)IGFX_SKYLAKE);
+    MediaFactory<uint32_t, Nv12ToP010Device>::
+    Register<Nv12ToP010DeviceG9Skl>((uint32_t)IGFX_SKYLAKE);
 
 MOS_STATUS Nv12ToP010DeviceG9Skl::Initialize(
     PMOS_INTERFACE            osInterface)
@@ -216,8 +214,8 @@ MOS_STATUS Nv12ToP010DeviceG9Skl::Initialize(
 }
 
 static bool sklRegisteredCodecHal =
-    MediaInterfacesFactory<CodechalDevice>::
-    RegisterHal<CodechalInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
+    MediaFactory<uint32_t, CodechalDevice>::
+    Register<CodechalInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
 
 MOS_STATUS CodechalInterfacesG9Skl::Initialize(
     void *standardInfo,
@@ -467,6 +465,23 @@ MOS_STATUS CodechalInterfacesG9Skl::Initialize(
             }
         }
         else
+#endif
+#ifdef _VP8_ENCODE_SUPPORTED
+        if (info->Mode == CODECHAL_ENCODE_MODE_VP8)
+        {
+            // Setup encode interface functions
+            encoder = MOS_New(Encode::Vp8, hwInterface, debugInterface, info);
+            if (encoder == nullptr)
+            {
+                CODECHAL_PUBLIC_ASSERTMESSAGE("VP8 Encode allocation failed!");
+                return MOS_STATUS_INVALID_PARAMETER;
+            }
+            else
+            {
+                m_codechalDevice = encoder;
+            }
+        }
+        else
 #endif
         {
             CODECHAL_PUBLIC_ASSERTMESSAGE("Unsupported encode function requested.");
@@ -493,8 +508,8 @@ MOS_STATUS CodechalInterfacesG9Skl::Initialize(
 }
 
 static bool sklRegisteredCMHal =
-    MediaInterfacesFactory<CMHalDevice>::
-    RegisterHal<CMHalInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
+    MediaFactory<uint32_t, CMHalDevice>::
+    Register<CMHalInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
 
 MOS_STATUS CMHalInterfacesG9Skl::Initialize(CM_HAL_STATE *pCmState)
 {
@@ -539,43 +554,9 @@ MOS_STATUS CMHalInterfacesG9Skl::Initialize(CM_HAL_STATE *pCmState)
     return MOS_STATUS_SUCCESS;
 }
 
-static bool sklRegisteredMosUtil =
-    MediaInterfacesFactory<MosUtilDevice>::
-    RegisterHal<MosUtilDeviceG9Skl>((uint32_t)IGFX_SKYLAKE);
-
-MOS_STATUS MosUtilDeviceG9Skl::Initialize()
-{
-#define MOSUTIL_FAILURE()                                   \
-{                                                           \
-    if (device != nullptr)                                  \
-    {                                                       \
-        delete device;                                      \
-    }                                                       \
-    return MOS_STATUS_NO_SPACE;                             \
-}
-
-    MosUtil *device = nullptr;
-
-    device = MOS_New(MosUtil);
-    
-    if (device == nullptr)
-    {
-        MOSUTIL_FAILURE();
-    }
-
-    if (device->Initialize() != MOS_STATUS_SUCCESS)
-    {
-        MOSUTIL_FAILURE();
-    }
-
-    m_mosUtilDevice = device;
-
-    return MOS_STATUS_SUCCESS;
-}
-
 static bool sklRegisteredRenderHal =
-    MediaInterfacesFactory<RenderHalDevice>::
-    RegisterHal<RenderHalInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
+    MediaFactory<uint32_t, RenderHalDevice>::
+    Register<RenderHalInterfacesG9Skl>((uint32_t)IGFX_SKYLAKE);
 
 MOS_STATUS RenderHalInterfacesG9Skl::Initialize()
 {
@@ -589,8 +570,8 @@ MOS_STATUS RenderHalInterfacesG9Skl::Initialize()
 }
 
 static bool sklRegisteredDecodeHistogram =
-MediaInterfacesFactory<DecodeHistogramDevice>::
-RegisterHal<DecodeHistogramDeviceG9Skl>((uint32_t)IGFX_SKYLAKE);
+MediaFactory<uint32_t, DecodeHistogramDevice>::
+Register<DecodeHistogramDeviceG9Skl>((uint32_t)IGFX_SKYLAKE);
 
 MOS_STATUS DecodeHistogramDeviceG9Skl::Initialize(
     CodechalHwInterface       *hwInterface,
