@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -52,19 +52,19 @@ MOS_STATUS Av1VdencPipelineXe_M_Base::Init(void *settings)
 
     Av1BrcInitPkt* brcInitpkt = MOS_New(Av1BrcInitPkt, this, task, m_hwInterface);
     RegisterPacket(Av1HucBrcInit, brcInitpkt);
-    brcInitpkt->Init();
+    ENCODE_CHK_STATUS_RETURN(brcInitpkt->Init());
 
     Av1BrcUpdatePkt* brcUpdatepkt = MOS_New(Av1BrcUpdatePkt, this, task, m_hwInterface);
     RegisterPacket(Av1HucBrcUpdate, brcUpdatepkt);
-    brcUpdatepkt->Init();
+    ENCODE_CHK_STATUS_RETURN(brcUpdatepkt->Init());
 
     Av1VdencPktXe_M_Base *av1Vdencpkt = MOS_New(Av1VdencPktXe_M_Base, this, task, m_hwInterface);
     RegisterPacket(Av1VdencPacket, av1Vdencpkt);
-    av1Vdencpkt->Init();
+    ENCODE_CHK_STATUS_RETURN(av1Vdencpkt->Init());
 
     Av1BackAnnotationPkt *av1BackAnnotationpkt = MOS_New(Av1BackAnnotationPkt, this, task, m_hwInterface);
     RegisterPacket(Av1BackAnnotation, av1BackAnnotationpkt);
-    av1BackAnnotationpkt->Init();
+    ENCODE_CHK_STATUS_RETURN(av1BackAnnotationpkt->Init());
 
     return MOS_STATUS_SUCCESS;
 }
@@ -79,14 +79,13 @@ MOS_STATUS Av1VdencPipelineXe_M_Base::Prepare(void *params)
     PCODEC_AV1_ENCODE_SEQUENCE_PARAMS av1SeqParams = static_cast<PCODEC_AV1_ENCODE_SEQUENCE_PARAMS>(encodeParams->pSeqParams);
     ENCODE_CHK_NULL_RETURN(av1SeqParams);
 
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Prepare(params));
-
-    PCODEC_AV1_ENCODE_PICTURE_PARAMS picParams = static_cast<PCODEC_AV1_ENCODE_PICTURE_PARAMS>(encodeParams->pPicParams);
-    ENCODE_CHK_NULL_RETURN(picParams);
-
-    auto feature = dynamic_cast<Av1BasicFeature*>(m_featureManager->GetFeature(Av1FeatureIDs::basicFeature));
+    auto feature = dynamic_cast<Av1BasicFeature *>(m_featureManager->GetFeature(Av1FeatureIDs::basicFeature));
     ENCODE_CHK_NULL_RETURN(feature);
 
+    feature->m_dualEncEnable = m_dualEncEnable;
+
+    ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Prepare(params));
+
     uint16_t numTileRows = 0;
     uint16_t numTileColumns = 0;
     RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileRowColumns,
@@ -95,22 +94,10 @@ MOS_STATUS Av1VdencPipelineXe_M_Base::Prepare(void *params)
     ENCODE_CHK_STATUS_RETURN(SwitchContext(feature->m_outputChromaFormat, numTileRows, numTileColumns));
 
     EncoderStatusParameters inputParameters = {};
-    MOS_ZeroMemory(&inputParameters, sizeof(EncoderStatusParameters));
 
-    inputParameters.statusReportFeedbackNumber = picParams->StatusReportFeedbackNumber;
-    inputParameters.codecFunction              = encodeParams->ExecCodecFunction;
-    inputParameters.currRefList                = feature->m_ref.GetCurrRefList();
-    inputParameters.picWidthInMb               = feature->m_picWidthInMb;
-    inputParameters.frameFieldHeightInMb       = feature->m_frameFieldHeightInMb;
-    inputParameters.currOriginalPic            = feature->m_currOriginalPic;
-    inputParameters.pictureCodingType          = feature->m_pictureCodingType;
-    inputParameters.numUsedVdbox               = m_numVdbox;
-    inputParameters.hwWalker                   = false;
-    inputParameters.maxNumSlicesAllowed        = 0;
+    ENCODE_CHK_STATUS_RETURN(FillStatusReportParameters(&inputParameters, encodeParams));
 
-    inputParameters.numberTilesInFrame         = numTileRows * numTileColumns;
-
-    m_statusReport->Init(&inputParameters);
+    ENCODE_CHK_STATUS_RETURN(m_statusReport->Init(&inputParameters));
 
     return MOS_STATUS_SUCCESS;
 }
@@ -130,7 +117,7 @@ MOS_STATUS Av1VdencPipelineXe_M_Base::Execute()
 MOS_STATUS Av1VdencPipelineXe_M_Base::GetStatusReport(void *status, uint16_t numStatus)
 {
     ENCODE_FUNC_CALL();
-    m_statusReport->GetReport(numStatus, status);
+    ENCODE_CHK_STATUS_RETURN(m_statusReport->GetReport(numStatus, status));
 
     return MOS_STATUS_SUCCESS;
 }
@@ -144,53 +131,6 @@ MOS_STATUS Av1VdencPipelineXe_M_Base::Destroy()
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS Av1VdencPipelineXe_M_Base::Initialize(void *settings)
-{
-    ENCODE_FUNC_CALL();
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Initialize(settings));
-    ENCODE_CHK_STATUS_RETURN(InitMmcState());
-
-    CODECHAL_DEBUG_TOOL
-    (
-        if (m_debugInterface != nullptr)
-        {
-            MOS_Delete(m_debugInterface);
-        }
-        m_debugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_debugInterface);
-        ENCODE_CHK_STATUS_RETURN(
-            m_debugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopy));
-
-        if (m_statusReportDebugInterface != nullptr)
-        {
-            MOS_Delete(m_statusReportDebugInterface);
-        }
-        m_statusReportDebugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_statusReportDebugInterface);
-        ENCODE_CHK_STATUS_RETURN(
-            m_statusReportDebugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopy));
-    );
-
-
-    ENCODE_CHK_STATUS_RETURN(GetSystemVdboxNumber());
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS Av1VdencPipelineXe_M_Base::Uninitialize()
-{
-    ENCODE_FUNC_CALL();
-
-    if (m_mmcState != nullptr)
-    {
-        MOS_Delete(m_mmcState);
-    }
-
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Uninitialize());
-
-    return MOS_STATUS_SUCCESS;
-}
-
 MOS_STATUS Av1VdencPipelineXe_M_Base::ResetParams()
 {
     ENCODE_FUNC_CALL();
