@@ -42,7 +42,7 @@ public:
     //!         Pointer to CodechalDebugInterface
     //!
     HevcVdencPipelineXe_Xpm_Base(
-        CodechalHwInterface    *hwInterface,
+        CodechalHwInterfaceNext    *hwInterface,
         CodechalDebugInterface *debugInterface);
 
     virtual ~HevcVdencPipelineXe_Xpm_Base() {}
@@ -71,7 +71,7 @@ protected:
     virtual MOS_STATUS CreateFeatureManager() override;
 
     static const uint32_t       m_brcHistoryBufSize = 2304;            //!< BRC history buffer size
-MEDIA_CLASS_DEFINE_END(HevcVdencPipelineXe_Xpm_Base)
+MEDIA_CLASS_DEFINE_END(encode__HevcVdencPipelineXe_Xpm_Base)
 };
 
 }
