@@ -46,7 +46,7 @@ class VpPlatformInterfacesXe_Lpm_Plus : public VpPlatformInterface
 {
 public:
 
-    VpPlatformInterfacesXe_Lpm_Plus(PMOS_INTERFACE pOsInterface);
+    VpPlatformInterfacesXe_Lpm_Plus(PMOS_INTERFACE pOsInterface, bool clearViewMode = false);
 
     virtual ~VpPlatformInterfacesXe_Lpm_Plus()
     {}
@@ -59,7 +59,6 @@ public:
     virtual MOS_STATUS VeboxQueryStatLayout(
         VEBOX_STAT_QUERY_TYPE queryType,
         uint32_t* pQuery);
-    virtual VpKernelConfig &GetKernelConfig();
     virtual uint32_t        VeboxQueryStaticSurfaceSize()
     {
         return VP_VEBOX_STATISTICS_SIZE_XE_LPM_PLUS;
@@ -84,6 +83,16 @@ public:
         return true;
     }
 
+    virtual bool IsDecompForInterlacedSurfWaEnabled()
+    {
+        return true;
+    }
+
+    virtual bool IsLegacyEuCountInUse()
+    {
+        return true;
+    }
+
 protected:
     bool m_disableSfcDithering = false;
 
