@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -31,9 +31,10 @@
 namespace decode {
 
     DecodeStatusReport::DecodeStatusReport(
-        DecodeAllocator* allocator, bool enableRcs):
+        DecodeAllocator* allocator, bool enableRcs, PMOS_INTERFACE osInterface):
         m_enableRcs(enableRcs),
-        m_allocator(allocator)
+        m_allocator(allocator),
+        m_osInterface(osInterface)
     {
         m_sizeOfReport = sizeof(DecodeStatusReportData);
     }
@@ -107,15 +108,16 @@ namespace decode {
 
         if (inputParameters)
         {
-            m_statusReportData[submitIndex].codecStatus = CODECHAL_STATUS_UNAVAILABLE;
+            m_statusReportData[submitIndex].codecStatus        = CODECHAL_STATUS_UNAVAILABLE;
             m_statusReportData[submitIndex].statusReportNumber = inputParameters->statusReportFeedbackNumber;
-            m_statusReportData[submitIndex].currDecodedPic = inputParameters->currOriginalPic;
-            m_statusReportData[submitIndex].currDecodedPicRes = inputParameters->currDecodedPicRes;
+            m_statusReportData[submitIndex].currDecodedPic     = inputParameters->currOriginalPic;
+            m_statusReportData[submitIndex].currDecodedPicRes  = inputParameters->currDecodedPicRes;     
 #if (_DEBUG || _RELEASE_INTERNAL)
-            m_statusReportData[submitIndex].currSfcOutputPicRes = inputParameters->sfcOutputPicRes;
-            m_statusReportData[submitIndex].currHistogramOutBuf = inputParameters->histogramOutputBuf;
-            m_statusReportData[submitIndex].frameType = inputParameters->pictureCodingType;
-            m_statusReportData[submitIndex].currFgOutputPicRes = inputParameters->fgOutputPicRes;
+            m_statusReportData[submitIndex].currSfcOutputSurface = inputParameters->sfcOutputSurface;
+            m_statusReportData[submitIndex].currHistogramOutBuf  = inputParameters->histogramOutputBuf;
+            m_statusReportData[submitIndex].frameType            = inputParameters->pictureCodingType;
+            m_statusReportData[submitIndex].secondField          = inputParameters->isSecondField;
+            m_statusReportData[submitIndex].currFgOutputPicRes   = inputParameters->fgOutputPicRes;
 #endif
         }
 
@@ -233,9 +235,14 @@ namespace decode {
         DECODE_CHK_NULL(statusReportData);
         DECODE_CHK_NULL(decodeStatus);
 
-        if (!completed)
+        if(m_osInterface != nullptr && m_osInterface->pfnIsGPUHung(m_osInterface))
         {
-            statusReportData->codecStatus = CODECHAL_STATUS_ERROR;
+            statusReportData->codecStatus = CODECHAL_STATUS_INCOMPLETE;
+            DECODE_ASSERTMESSAGE("Gpu hang may have occured.");
+        }
+        else if (!completed)
+        {
+            statusReportData->codecStatus = CODECHAL_STATUS_RESET;
             DECODE_ASSERTMESSAGE("Media reset may have occured.");
         }
         else
