@@ -332,7 +332,7 @@ MOS_STATUS Vp9DecodePicPkt::SetRefMmcStatus(uint8_t surfaceID, PMOS_SURFACE pSur
     DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcState(pSurface, &mmcState));
     m_refsMmcEnable |= (mmcState == MOS_MEMCOMP_RC || mmcState == MOS_MEMCOMP_MC) ? (1 << (surfaceID - 2)) : 0;
     m_refsMmcType |= (mmcState == MOS_MEMCOMP_RC) ? (1 << (surfaceID - 2)) : 0;
-    if (mmcState == MOS_MEMCOMP_RC || mmcState == MOS_MEMCOMP_MC)
+    if (m_mmcState->IsMmcEnabled())
     {
         DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcFormat(pSurface, &m_mmcFormat));
     }
@@ -458,14 +458,7 @@ MHW_SETPAR_DECL_SRC(HCP_SURFACE_STATE, Vp9DecodePicPkt)
         }
     }
 
-    if (m_curHcpSurfStateId == CODECHAL_HCP_SRC_SURFACE_ID)
-    {
-        uvPlaneAlignment = dwUVPlaneAlignment ? dwUVPlaneAlignment : m_rawUVPlaneAlignment;
-    }
-    else
-    {
-        uvPlaneAlignment = dwUVPlaneAlignment ? dwUVPlaneAlignment : m_reconUVPlaneAlignment;
-    }
+    uvPlaneAlignment = dwUVPlaneAlignment;
 
     params.yOffsetForUCbInPixel =
         MOS_ALIGN_CEIL((psSurface->UPlaneOffset.iSurfaceOffset - psSurface->dwOffset) / psSurface->dwPitch + psSurface->RenderOffset.YUV.U.YOffset, uvPlaneAlignment);
@@ -631,8 +624,7 @@ MHW_SETPAR_DECL_SRC(HCP_PIPE_BUF_ADDR_STATE, Vp9DecodePicPkt)
 
     DECODE_CHK_STATUS(FixHcpPipeBufAddrParams());
 
-    // Dump reference surface
-    CODECHAL_DEBUG_TOOL(DumpRefResources(params, m_vp9BasicFeature->m_resVp9MvTemporalBuffer[0]->size));
+    CODECHAL_DEBUG_TOOL(DumpResources(params, activeRefList.size(), m_vp9BasicFeature->m_resVp9MvTemporalBuffer[0]->size));
 
     return MOS_STATUS_SUCCESS;
 }
@@ -847,29 +839,28 @@ MOS_STATUS Vp9DecodePicPkt::CalculateCommandSize(uint32_t &commandBufferSize, ui
     return MOS_STATUS_SUCCESS;
 }
 
-// dump reference 
 #if USE_CODECHAL_DEBUG_TOOL
-MOS_STATUS Vp9DecodePicPkt::DumpRefResources(HCP_PIPE_BUF_ADDR_STATE_PAR &params, uint32_t size) const
+MOS_STATUS Vp9DecodePicPkt::DumpResources(HCP_PIPE_BUF_ADDR_STATE_PAR &params, uint32_t refSize, uint32_t mvSize) const
 {
     DECODE_FUNC_CALL();
 
     CodechalDebugInterface *debugInterface = m_pipeline->GetDebugInterface();
     DECODE_CHK_NULL(debugInterface);
-    for (uint16_t n = 0; n < CODECHAL_DECODE_VP9_MAX_NUM_REF_FRAME; n++)
+    for (uint16_t n = 0; n < refSize; n++)
     {
         if (params.presReferences[n])
         {
-            MOS_SURFACE dstSurface;
-            MOS_ZeroMemory(&dstSurface, sizeof(MOS_SURFACE));
-            dstSurface.OsResource = *(params.presReferences[n]);
+            MOS_SURFACE refSurface;
+            MOS_ZeroMemory(&refSurface, sizeof(MOS_SURFACE));
+            refSurface.OsResource = *(params.presReferences[n]);
             DECODE_CHK_STATUS(CodecUtilities::CodecHalGetResourceInfo(
                 m_osInterface,
-                &dstSurface));
+                &refSurface));
 
             debugInterface->m_refIndex = n;
             std::string refSurfName    = "RefSurf[" + std::to_string(static_cast<uint32_t>(debugInterface->m_refIndex)) + "]";
             DECODE_CHK_STATUS(debugInterface->DumpYUVSurface(
-                &dstSurface,
+                &refSurface,
                 CodechalDbgAttr::attrDecodeReferenceSurfaces,
                 refSurfName.c_str()));
         }
@@ -882,7 +873,7 @@ MOS_STATUS Vp9DecodePicPkt::DumpRefResources(HCP_PIPE_BUF_ADDR_STATE_PAR &params
             params.presColMvTempBuffer[0],
             CodechalDbgAttr::attrMvData,
             "DEC_Col_MV_",
-            size));
+            mvSize));
     };
 
     if (params.presCurMvTempBuffer)
@@ -892,7 +883,7 @@ MOS_STATUS Vp9DecodePicPkt::DumpRefResources(HCP_PIPE_BUF_ADDR_STATE_PAR &params
             params.presCurMvTempBuffer,
             CodechalDbgAttr::attrMvData,
             "DEC_Cur_MV_",
-            size));
+            mvSize));
     };
 
    return MOS_STATUS_SUCCESS;
