@@ -310,7 +310,7 @@ namespace encode
         const uint32_t segMapPitch  = MOS_ALIGN_CEIL(CurFrameWidth, m_segmentMapBlockSize) / m_segmentMapBlockSize;
         const uint32_t segMapHeight = MOS_ALIGN_CEIL(CurFrameHeight, m_segmentMapBlockSize) / m_segmentMapBlockSize;
 
-        const uint64_t minSegmentMapDataSize = segMapPitch * segMapHeight; // 1 byte per segment Id
+        const uint64_t minSegmentMapDataSize = (uint64_t)segMapPitch * (uint64_t)segMapHeight;  // 1 byte per segment Id
 
         if (m_segmentMapDataSize < minSegmentMapDataSize)
         {
@@ -513,7 +513,15 @@ namespace encode
             // for VP9 VDEnc this is bit used for programming of "segmentation_temporal_update"
             // for AV1 VDEnc this bit indicates negative of "segmentation_update_map"
             params.segmentationTemporal =  m_segmentParams.m_updateMap ? false : true;
-            params.vdencCmd2Par113      =  true;
+#if _MEDIA_RESERVED
+            params.vdencCmd2Par113 = true;
+#else
+            params.extSettings.emplace_back(
+                [this](uint32_t *data) {
+                    data[54] |= 1 << 15;
+                    return MOS_STATUS_SUCCESS;
+                });
+#endif  // _MEDIA_RESERVED
         }
 
         for (auto i = 0; i < av1MaxSegments; i++)
