@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -515,43 +515,66 @@ namespace encode
 
     MOS_STATUS Av1EncodeTile::TileSizeCheck(const PCODEC_AV1_ENCODE_PICTURE_PARAMS &av1PicParam)
     {
-        uint16_t sbCols = MOS_ROUNDUP_DIVIDE(av1PicParam->frame_width_minus1 + 1, av1SuperBlockWidth);
-        uint16_t sbRows = MOS_ROUNDUP_DIVIDE(av1PicParam->frame_height_minus1 + 1, av1SuperBlockHeight);
-        uint16_t tileAreaSb = sbCols * sbRows;
-
-        uint16_t maxTileWidthSb  = MOS_ROUNDUP_DIVIDE(av1MaxTileWidth, av1SuperBlockWidth);
-        uint16_t minLog2TileCols = TileLog2(maxTileWidthSb, sbCols);
-        uint16_t maxTileAreaSb   = MOS_ROUNDUP_DIVIDE(av1MaxTileWidth * av1MaxTileHeight, av1SuperBlockWidth * av1SuperBlockHeight);
-        uint16_t minLog2Tiles    = MOS_MAX(minLog2TileCols, TileLog2(maxTileAreaSb, tileAreaSb));
+        uint32_t maxTileAreaSb = MOS_ROUNDUP_DIVIDE(av1MaxTileArea, av1SuperBlockWidth * av1SuperBlockHeight);
+        uint32_t sbCols        = MOS_ROUNDUP_DIVIDE(av1PicParam->frame_width_minus1 + 1, av1SuperBlockWidth);
+        uint32_t sbRows        = MOS_ROUNDUP_DIVIDE(av1PicParam->frame_height_minus1 + 1, av1SuperBlockHeight);
 
+        //Tile Width sum equals image width, no pixel leak
         if (av1PicParam->width_in_sbs_minus_1[0] + 1 == 0)
         {
             return MOS_STATUS_INVALID_PARAMETER;
         }
+        uint32_t curTileWidthSb = av1PicParam->width_in_sbs_minus_1[0] + 1;
+        uint32_t widestTileSb   = av1PicParam->width_in_sbs_minus_1[0] + 1;
+        uint32_t tileWidthSbSum = 0;
 
-        uint16_t widestTileSb = av1PicParam->width_in_sbs_minus_1[0] + 1;
-        for (uint8_t i = 1; i < m_numTileColumns; i++)
+        if (m_basicFeature->m_dualEncEnable && m_numTileRows != 1)
         {
-            widestTileSb = MOS_MAX(widestTileSb, (av1PicParam->width_in_sbs_minus_1[i] + 1));
-        }
-
-        if (minLog2Tiles)
-        {
-            tileAreaSb >>= (minLog2Tiles + 1);
-        }
-
-        uint16_t maxTileHeightSb = MOS_MAX(1, tileAreaSb / widestTileSb);
-        for (uint8_t i = 0; i < m_numTileRows; i++)
-        {
-            if ((av1PicParam->height_in_sbs_minus_1[i] + 1) > maxTileHeightSb)
-            {
-                return MOS_STATUS_INVALID_PARAMETER;
-            }
+            ENCODE_ASSERTMESSAGE("dual encode cannot support multi rows submission yet.");
+            return MOS_STATUS_INVALID_PARAMETER;
         }
 
         for (uint8_t i = 0; i < m_numTileColumns; i++)
         {
-            if ((av1PicParam->width_in_sbs_minus_1[i] + 1) > maxTileWidthSb)
+            curTileWidthSb = av1PicParam->width_in_sbs_minus_1[i] + 1;
+            widestTileSb   = MOS_MAX(widestTileSb, curTileWidthSb);
+            tileWidthSbSum += curTileWidthSb;
+            if (m_basicFeature->m_dualEncEnable && curTileWidthSb == 2)
+            {
+                m_firstDummyIdx = i;
+            }
+        }
+        if (tileWidthSbSum != sbCols)
+        {
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
+        //Tile Height sum equals image height, no pixel leak
+        if (av1PicParam->height_in_sbs_minus_1[0] + 1 == 0)
+        {
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+        uint32_t curTileHeightSb = av1PicParam->height_in_sbs_minus_1[0] + 1;
+        uint32_t highestWidthSb  = av1PicParam->height_in_sbs_minus_1[0] + 1;
+        uint32_t tileHeightSbSum = 0;
+
+        for (uint8_t i = 0; i < m_numTileRows; i++)
+        {
+            curTileHeightSb = av1PicParam->height_in_sbs_minus_1[i] + 1;
+            highestWidthSb  = MOS_MAX(1, curTileHeightSb);
+            tileHeightSbSum += curTileHeightSb;
+        }
+        if (tileHeightSbSum != sbRows)
+        {
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
+        // Max tile check
+
+        for (uint8_t i = 0; i < m_numTileRows; i++)
+        {
+            curTileHeightSb = av1PicParam->height_in_sbs_minus_1[i] + 1;
+            if ((widestTileSb * curTileHeightSb) > maxTileAreaSb)
             {
                 return MOS_STATUS_INVALID_PARAMETER;
             }
@@ -818,7 +841,7 @@ namespace encode
             {
                 av1TileInfo->firstTileOfTileGroup = (tmpTileGroupParams->TileGroupStart == m_tileIdx);
                 av1TileInfo->lastTileOfTileGroup  = (tmpTileGroupParams->TileGroupEnd == m_tileIdx);
-                av1TileInfo->tileNum              = m_tileIdx - tmpTileGroupParams->TileGroupStart;
+                av1TileInfo->tgTileNum            = m_tileIdx - tmpTileGroupParams->TileGroupStart;
                 av1TileInfo->tileGroupId          = tileGrupCnt;
                 break;
             }
@@ -909,7 +932,7 @@ namespace encode
         params.lastTileOfFrame      = av1TileInfo.lastTileOfFrame;
         params.firstTileOfTileGroup = av1TileInfo.firstTileOfTileGroup;
         params.lastTileOfTileGroup  = av1TileInfo.lastTileOfTileGroup;
-        params.tileNum              = av1TileInfo.tileNum;
+        params.tgTileNum            = av1TileInfo.tgTileNum;
         params.tileGroupId          = av1TileInfo.tileGroupId;
 
         return eStatus;
@@ -920,7 +943,7 @@ namespace encode
         auto basicFeature = dynamic_cast<Av1BasicFeature *>(m_basicFeature);
         ENCODE_CHK_NULL_RETURN(basicFeature);
 
-        if (basicFeature->m_enableSWStitching)
+        if (basicFeature->m_enableSWStitching || basicFeature->m_dualEncEnable)
         {
             params.pakBaseObjectOffset = MOS_ALIGN_CEIL(m_tileData[m_tileIdx].bitstreamByteOffset * CODECHAL_CACHELINE_SIZE, MOS_PAGE_SIZE);
         }
@@ -976,7 +999,7 @@ namespace encode
             {
                 MOS_RESOURCE* buf = nullptr;
 
-                GetTileBasedStatisticsBuffer(m_prevStatisticsBufIndex, buf);
+                ENCODE_CHK_STATUS_RETURN(GetTileBasedStatisticsBuffer(m_prevStatisticsBufIndex, buf));
                 ENCODE_CHK_NULL_RETURN(buf);
 
                 //will be optimized to avoid perf degradation when async > 1
@@ -1059,4 +1082,14 @@ namespace encode
         return MOS_STATUS_SUCCESS;
     }
 
+MOS_STATUS Av1EncodeTile::GetTileStatusInfo(
+        Av1TileStatusInfo &av1TileStatsOffset,
+        Av1TileStatusInfo &av1StatsSize)
+    {
+        av1TileStatsOffset = m_av1TileStatsOffset;
+        av1StatsSize = m_av1StatsSize;
+        
+        return MOS_STATUS_SUCCESS;
+    }
+
     }  // namespace encode
