@@ -528,7 +528,7 @@ struct VdencStatistics
 struct Av1TileInfo
 {
     uint16_t tileId      = 0;
-    uint16_t tileNum     = 0;
+    uint16_t tgTileNum   = 0;
     uint16_t tileGroupId = 0;
 
     uint16_t tileColPositionInSb = 0;
@@ -623,6 +623,7 @@ public:
     MOS_STATUS GetTileGroupReportParams(uint32_t idx, const Av1ReportTileGroupParams *&reportTileData);
     MOS_STATUS ReadObuSize(const uint8_t *ObuOffset, uint32_t &size);
     MOS_STATUS GetTileInfo(Av1TileInfo *av1TileInfo) const;
+    MOS_STATUS GetDummyIdx(uint8_t &idx) { idx = m_firstDummyIdx; return MOS_STATUS_SUCCESS;}
 
 protected:
     //!
@@ -710,6 +711,8 @@ protected:
     static const uint32_t m_av1VdencStateSize = 1216;    // VDEnc Statistic: 48DWs (3CLs) of HMDC Frame Stats + 256 DWs (16CLs) of Histogram Stats = 1216 bytes
     std::vector<uint8_t>  m_tgHeaderBuf       = {};
 
+    uint8_t               m_firstDummyIdx     = 0;
+
 MEDIA_CLASS_DEFINE_END(encode__Av1EncodeTile)
 };
 
