@@ -30,6 +30,9 @@
 #include "encode_av1_brc.h"
 #include "encode_av1_vdenc_packet.h"
 #include "encode_av1_vdenc_lpla_enc.h"
+#if _MEDIA_RESERVED
+#include "encode_av1_scc.h"
+#endif
 
 namespace encode
 {
@@ -297,9 +300,16 @@ namespace encode
         constructedCmdBuf.pCmdBase = constructedCmdBuf.pCmdPtr = (uint32_t *)batchbufferAddr;
         constructedCmdBuf.iRemaining                           = MOS_ALIGN_CEIL(m_hwInterface->m_vdencReadBatchBufferSize, CODECHAL_PAGE_SIZE);
 
+        auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
+        ENCODE_CHK_NULL_RETURN(brcFeature);
+        auto slbData = brcFeature->GetSLBData();
+
         ENCODE_CHK_STATUS_RETURN(AddAllCmds_AVP_PAK_INSERT_OBJECT(&constructedCmdBuf));
         ENCODE_CHK_STATUS_RETURN(AddBBEnd(m_miItf, constructedCmdBuf));
 
+        slbData.pakInsertSlbSize = (uint16_t)constructedCmdBuf.iOffset;
+        RUN_FEATURE_INTERFACE_NO_RETURN(Av1Brc, Av1FeatureIDs::av1BrcFeature, SetSLBData, slbData);
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -319,6 +329,9 @@ namespace encode
             {
                 RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, SetCurrentTile, tileRow, tileCol, m_pipeline);
                 RUN_FEATURE_INTERFACE_NO_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, IsFirstTileInGroup, firstTileInGroup, tileGroupIdx);
+#if _MEDIA_RESERVED
+                RUN_FEATURE_INTERFACE_RETURN(Av1Scc, Av1FeatureIDs::av1Scc, UpdateIBCStatusForCurrentTile);
+#endif
                 if (firstTileInGroup)
                 {
                     SETPAR_AND_ADDCMD(AVP_PIC_STATE, m_avpItf, &cmdBuffer);
@@ -396,14 +409,14 @@ namespace encode
             uint32_t nalNum = 0;
             for (uint32_t i = 0; i < MAX_NUM_OBU_TYPES && m_basicFeature->m_nalUnitParams[i]->uiSize > 0; i++)
             {
-                nalNum = i;
+                nalNum++;
             }
 
             params.bsBuffer             = &m_basicFeature->m_bsBuffer;
             params.endOfHeaderInsertion = false;
 
             // Support multiple packed header buffer
-            for (uint32_t i = 0; i <= nalNum; i++)
+            for (uint32_t i = 0; i < nalNum; i++)
             {
                 uint32_t nalUnitSize   = m_basicFeature->m_nalUnitParams[i]->uiSize;
                 uint32_t nalUnitOffset = m_basicFeature->m_nalUnitParams[i]->uiOffset;
@@ -414,7 +427,7 @@ namespace encode
                 {
                     params.bitSize    = nalUnitSize * 8;
                     params.offset     = nalUnitOffset;
-                    params.lastHeader = !tgOBUValid && (i == nalNum);
+                    params.lastHeader = !tgOBUValid && (i+1 == nalNum);
 
                     m_avpItf->MHW_ADDCMD_F(AVP_PAK_INSERT_OBJECT)(cmdBuffer);
                     m_osInterface->pfnAddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
