@@ -35,7 +35,7 @@ namespace encode
     HEVCEncodeBRC::HEVCEncodeBRC(
         MediaFeatureManager *featureManager,
         EncodeAllocator *allocator,
-        CodechalHwInterface *hwInterface,
+        CodechalHwInterfaceNext *hwInterface,
         void *constSettings) :
         MediaFeature(constSettings, hwInterface ? hwInterface->GetOsInterface() : nullptr),
         m_hwInterface(hwInterface),
@@ -63,6 +63,13 @@ namespace encode
 
 #if (_DEBUG || _RELEASE_INTERNAL)
         MediaUserSetting::Value outValue;
+        ReadUserSettingForDebug(
+            m_userSettingPtr,
+            outValue,
+            "FAST PAK ENABLE",
+            MediaUserSetting::Group::Sequence);
+        m_fastPakEnable = outValue.Get<bool>();
+
         ReadUserSetting(
             m_userSettingPtr,
             outValue,
@@ -120,29 +127,19 @@ namespace encode
 
         allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(sizeof(CodechalVdencHevcPakInfo), CODECHAL_PAGE_SIZE);
         allocParamsForBufferLinear.pBufName = "VDENC BRC PakInfo";
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
         m_basicFeature->m_recycleBuf->RegisterResource(PakInfo, allocParamsForBufferLinear, 6);
 
         // Allocate Frame Statistics Streamout Data Destination Buffer. DW98-100 in HCP PipeBufAddr command
         HevcBasicFeature *hevcBasicFeature = dynamic_cast<HevcBasicFeature *>(m_basicFeature);
         ENCODE_CHK_NULL_RETURN(hevcBasicFeature);
 
-        //Each tile has 9 cache size bytes of data, Align to page is HuC requirement
-        uint32_t size = MOS_ALIGN_CEIL(HevcBasicFeature::m_sizeOfHcpPakFrameStats * hevcBasicFeature->m_maxTileNumber, CODECHAL_PAGE_SIZE);
-
-        allocParamsForBufferLinear.dwBytes = size;
-        allocParamsForBufferLinear.pBufName = "FrameStatStreamOutBuffer";
-        m_basicFeature->m_recycleBuf->RegisterResource(FrameStatStreamOutBuffer, allocParamsForBufferLinear, 1);
-
         // BRC history buffer
         allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(m_brcHistoryBufSize, CODECHAL_PAGE_SIZE);
         allocParamsForBufferLinear.pBufName = "VDENC BRC History Buffer";
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
         m_basicFeature->m_recycleBuf->RegisterResource(VdencBRCHistoryBuffer, allocParamsForBufferLinear, 1);
 
-        // PAK stream-out buffer
-        allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(m_vdencBRCStatsBufferSize * hevcBasicFeature->m_maxTileNumber, CODECHAL_PAGE_SIZE);
-        allocParamsForBufferLinear.pBufName = "vdencStats";
-        m_basicFeature->m_recycleBuf->RegisterResource(VdencStatsBuffer, allocParamsForBufferLinear, 1);
-
         for (auto j = 0; j < CODECHAL_ENCODE_RECYCLED_BUFFER_NUM; j++)
         {
             // VDENC uses second level batch buffer
@@ -164,20 +161,24 @@ namespace encode
         uint32_t maxLcu = picWidthInMinLCU * picHeightInMinLCU;
         allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(maxLcu * CODECHAL_CACHELINE_SIZE, CODECHAL_PAGE_SIZE);
         allocParamsForBufferLinear.pBufName = "LcuBaseAddressBuffer";
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
         m_basicFeature->m_recycleBuf->RegisterResource(LcuBaseAddressBuffer, allocParamsForBufferLinear, 1);
 
         // VDENC BRC PAK MMIO buffer
         allocParamsForBufferLinear.dwBytes = sizeof(VdencBrcPakMmio);
         allocParamsForBufferLinear.pBufName = "VDENC BRC PAK MMIO Buffer";
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
         m_basicFeature->m_recycleBuf->RegisterResource(VdencBrcPakMmioBuffer, allocParamsForBufferLinear, 1);
 
         // Debug buffer
         allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(m_brcDebugBufSize, CODECHAL_PAGE_SIZE);
         allocParamsForBufferLinear.pBufName = "VDENC BRC Debug Buffer";
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
         m_basicFeature->m_recycleBuf->RegisterResource(VdencBrcDebugBuffer, allocParamsForBufferLinear, 1);
 
         allocParamsForBufferLinear.dwBytes  = HEVC_BRC_PAK_STATISTCS_SIZE;
         allocParamsForBufferLinear.pBufName = "BRC PAK Statistics Buffer";
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
         m_basicFeature->m_recycleBuf->RegisterResource(BrcPakStatisticBuffer, allocParamsForBufferLinear, CODECHAL_ENCODE_RECYCLED_BUFFER_NUM);
 
         for (auto i = 0; i < CODECHAL_ENCODE_RECYCLED_BUFFER_NUM; i++)
@@ -223,7 +224,7 @@ namespace encode
             allocParamsForBufferLinear.Format   = Format_Buffer;
             allocParamsForBufferLinear.dwBytes  = MOS_ALIGN_CEIL(num_tiles * CODECHAL_CACHELINE_SIZE, CODECHAL_PAGE_SIZE);
             allocParamsForBufferLinear.pBufName = "BRC Data Buffer";
-
+            allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
             auto resource = m_allocator->AllocateResource(allocParamsForBufferLinear, true);
             ENCODE_CHK_NULL_RETURN(resource);
             m_resBrcDataBuffer = *resource;
@@ -240,27 +241,6 @@ namespace encode
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS HEVCEncodeBRC::SetRegionsForUpdate(MHW_VDBOX_HUC_VIRTUAL_ADDR_PARAMS& params, uint32_t currRecycledBufIdx)
-    {
-        ENCODE_FUNC_CALL();
-        ENCODE_CHK_NULL_RETURN(m_basicFeature);
-
-        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-
-        // Add Virtual addr
-        MOS_ZeroMemory(&params, sizeof(MHW_VDBOX_HUC_VIRTUAL_ADDR_PARAMS));
-        params.regionParams[0].presRegion = m_basicFeature->m_recycleBuf->GetBuffer(VdencBRCHistoryBuffer, 0);  // Region 0 - History Buffer (Input/Output)
-        params.regionParams[0].isWritable = true;
-        
-        params.regionParams[5].presRegion = &m_vdenc2ndLevelBatchBuffer[currRecycledBufIdx].OsResource;         // Region 5 - Output SLB Buffer (Output)
-        params.regionParams[5].isWritable = true;
-
-        // region 15 always in clear
-        params.regionParams[15].presRegion = m_basicFeature->m_recycleBuf->GetBuffer(VdencBrcDebugBuffer, 0);   // Region 15 - Debug Buffer (Output)
-        params.regionParams[15].isWritable = true;
-        return MOS_STATUS_SUCCESS;
-    }
-
     MOS_STATUS HEVCEncodeBRC::SetDmemForUpdate(void* params)
     {
         ENCODE_FUNC_CALL();
@@ -291,11 +271,21 @@ namespace encode
             hucVdencBrcUpdateDmem->DeltaQPForMvZone2_S8 = brcSettings.deltaQPForMvZone2_S8;
         }
 
-        hucVdencBrcUpdateDmem->ReEncodePositiveQPDeltaThr_S8 = brcSettings.reEncodePositiveQPDeltaThr_S8;
-        hucVdencBrcUpdateDmem->ReEncodeNegativeQPDeltaThr_S8 = brcSettings.reEncodeNegativeQPDeltaThr_S8;
+        if (m_fastPakEnable)
+        {
+            hucVdencBrcUpdateDmem->ReEncodePositiveQPDeltaThr_S8 = brcSettings.reEncodePositiveQPDeltaThr_S8;
+            hucVdencBrcUpdateDmem->ReEncodeNegativeQPDeltaThr_S8 = brcSettings.reEncodeNegativeQPDeltaThr_S8;
+        }
+        else
+        {
+            hucVdencBrcUpdateDmem->ReEncodePositiveQPDeltaThr_S8 = 0;
+            hucVdencBrcUpdateDmem->ReEncodeNegativeQPDeltaThr_S8 = 0;
+        }
         hucVdencBrcUpdateDmem->SceneChgPrevIntraPctThreshold_U8 = brcSettings.sceneChgPrevIntraPctThreshold_U8;
         hucVdencBrcUpdateDmem->SceneChgCurIntraPctThreshold_U8 = brcSettings.sceneChgCurIntraPctThreshold_U8;
 
+        hucVdencBrcUpdateDmem->UPD_Randomaccess = m_basicFeature->m_hevcSeqParams->LowDelayMode == 1 ? 0 : 1;
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -525,7 +515,7 @@ namespace encode
             int8_t DevThreshI0_S8[8] = {};
 
             uint64_t inputbitsperframe = uint64_t(hucVdencBrcInitDmem->MaxRate_U32*100. / (hucVdencBrcInitDmem->FrameRateM_U32 * 100.0 / hucVdencBrcInitDmem->FrameRateD_U32));
-            if (m_brcEnabled && !hucVdencBrcInitDmem->BufSize_U32)
+            if (m_brcEnabled && (m_rcMode != RATECONTROL_ICQ) && !hucVdencBrcInitDmem->BufSize_U32)
             {
                 ENCODE_ASSERTMESSAGE("VBV BufSize should not be 0 for BRC case\n");
                 return MOS_STATUS_INVALID_PARAMETER;
@@ -585,15 +575,6 @@ namespace encode
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS HEVCEncodeBRC::SetHcpPicStateParams(uint32_t currRecycledBufIdx, MHW_VDBOX_HEVC_PIC_STATE &picStateParams)
-    {
-        ENCODE_FUNC_CALL();
-
-        m_vdenc2ndLevelBatchBuffer[currRecycledBufIdx].dwOffset = m_hwInterface->m_vdencBatchBuffer1stGroupSize;
-
-        return MOS_STATUS_SUCCESS;
-    }
-
     MOS_STATUS HEVCEncodeBRC::SetVdencBatchBufferState(
         const uint32_t    currRecycledBufIdx,
         const uint32_t    slcIdx,
@@ -620,16 +601,6 @@ namespace encode
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS HEVCEncodeBRC::SetHcpPipeBufAddrParams(MHW_VDBOX_PIPE_BUF_ADDR_PARAMS& pipeBufAddrParams)
-    {
-        ENCODE_FUNC_CALL();
-        ENCODE_CHK_NULL_RETURN(m_basicFeature);
-
-        pipeBufAddrParams.presLcuBaseAddressBuffer = m_basicFeature->m_recycleBuf->GetBuffer(LcuBaseAddressBuffer, 0);
-        pipeBufAddrParams.presFrameStatStreamOutBuffer = m_basicFeature->m_recycleBuf->GetBuffer(FrameStatStreamOutBuffer, 0);
-        return MOS_STATUS_SUCCESS;
-    }
-
     MOS_STATUS HEVCEncodeBRC::SetSequenceStructs()
     {
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
@@ -679,7 +650,7 @@ namespace encode
         {
             if (m_basicFeature->m_hevcSeqParams->VBVBufferSizeInBit < m_basicFeature->m_hevcSeqParams->InitVBVBufferFullnessInBit)
             {
-                CODECHAL_ENCODE_NORMALMESSAGE(
+                ENCODE_NORMALMESSAGE(
                     "VBVBufferSizeInBit is less than InitVBVBufferFullnessInBit, \
                     min(VBVBufferSizeInBit, InitVBVBufferFullnessInBit) will set to \
                     hucVdencBrcInitDmem->InitBufFull_U32 and hucVdencBrcUpdateDmem->TARGETSIZE_U32(except Low Delay BRC).\n");
@@ -907,7 +878,7 @@ namespace encode
 
     MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, HEVCEncodeBRC)
     {
-        params.frameStatisticsStreamOut = m_hevcVDEncAcqpEnabled || m_vdencBrcEnabled;
+        params.frameStatisticsStreamOut |= m_hevcVDEncAcqpEnabled || m_vdencBrcEnabled;
 
         return MOS_STATUS_SUCCESS;
     }
