@@ -42,7 +42,7 @@ public:
     //!         Pointer to CodechalDebugInterface
     //!
     HevcPipeline(
-        CodechalHwInterface *   hwInterface,
+        CodechalHwInterfaceNext *   hwInterface,
         CodechalDebugInterface *debugInterface);
 
     virtual ~HevcPipeline() {}
@@ -60,9 +60,7 @@ public:
         HucBrcTileRowUpdate,
         HucLaInit,
         HucLaUpdate,
-#ifdef _ENCODE_RESERVED
-        hevcVdencPacketRsvd,
-#endif
+        hevcVdencPacket422,
     };
 
 protected:
@@ -112,7 +110,7 @@ protected:
 #endif
 
 
-MEDIA_CLASS_DEFINE_END(HevcPipeline)
+MEDIA_CLASS_DEFINE_END(encode__HevcPipeline)
 };
 
 }
