@@ -23,6 +23,7 @@
 #define __ENCODE_UTILS_H__
 #include <mutex>
 #include "mos_util_debug.h"
+#include "mos_utilities.h"
 
 #define _SW_BRC _MEDIA_RESERVED && (_DEBUG || _RELEASE_INTERNAL)
 
@@ -63,12 +64,24 @@ enum HuCFunction
 #define ENCODE_CHK_STATUS_RETURN(_stmt)                                               \
     MOS_CHK_STATUS_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt)
 
-#define ENCODE_CHK_COND_RETURN(_stmt, _message)                                               \
-    MOS_CHK_COND_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt, _message)
+#define ENCODE_CHK_STATUS_NO_STATUS_RETURN(_stmt)                                               \
+    MOS_CHK_STATUS_NO_STATUS_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt)
+
+#define ENCODE_CHK_COND_RETURN(_stmt, _message, ...)                                            \
+    MOS_CHK_COND_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt, _message, ##__VA_ARGS__)
 
 #define ENCODE_CHK_STATUS_MESSAGE_RETURN(_stmt, _message, ...)                        \
     MOS_CHK_STATUS_MESSAGE_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt, _message, ##__VA_ARGS__)
 
+#define ENCODE_CHK_NULL_WITH_DESTROY_RETURN_VALUE(_ptr, destroyFunction) \
+    MOS_CHK_COND_WITH_DESTROY_RETURN_VALUE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, (nullptr == _ptr), destroyFunction, MOS_STATUS_NULL_POINTER, "error nullptr!")
+
+#define ENCODE_CHK_STATUS_WITH_DESTROY_RETURN_VALUE(_stmt, destroyFunction)                                                                                     \
+{                                                                                                                                                               \
+    MOS_STATUS sts = (MOS_STATUS)(_stmt);                                                                                                                       \
+    MOS_CHK_COND_WITH_DESTROY_RETURN_VALUE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, (MOS_STATUS_SUCCESS != sts), destroyFunction, sts, "error status!")   \
+}
+
 namespace encode {
 
 class Trace
@@ -129,6 +142,62 @@ protected:
 MEDIA_CLASS_DEFINE_END(encode__Condition)
 };
 
+//!
+//! \brief    Allocate data list with specific type and length 
+//!
+//! \param    [in,out] dataList
+//!           Pointer to a type * pointer. Specify the address of the memory handles 
+//! \param    [in] length
+//!           Specify the number of data members 
+//!
+//! \return   MOS_STATUS
+//!           MOS_STATUS_SUCCESS if success, else fail reason
+//!
+template <class type>
+MOS_STATUS EncodeAllocateDataList(type **dataList, uint32_t length)
+{
+    type *ptr;
+    ptr = (type *)MOS_AllocAndZeroMemory(sizeof(type) * length);
+    if (ptr == nullptr)
+    {
+        ENCODE_ASSERTMESSAGE("No memory to allocate CodecHal data list.");
+        return MOS_STATUS_NO_SPACE;
+    }
+    for (uint32_t i = 0; i < length; i++)
+    {
+        dataList[i] = &(ptr[i]);
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
+//!
+//! \brief    Free data list
+//!
+//! \param    [in,out] dataList
+//!           Pointer to a type * pointer. Specify the address of the memory handles 
+//! \param    [in] length
+//!           Specify the number of data members 
+//!
+//! \return   MOS_STATUS
+//!           MOS_STATUS_SUCCESS if success, else fail reason
+//!
+template <class type>
+MOS_STATUS EncodeFreeDataList(type **dataList, uint32_t length)
+{
+    type* ptr;
+    ptr = dataList[0];
+    if (ptr)
+    {
+        MOS_FreeMemory(ptr);
+    }
+    for (uint32_t i = 0; i < length; i++)
+    {
+        dataList[i] = nullptr;
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 }
 
 #define ENCODE_FUNC_CALL() encode::Trace trace(__FUNCTION__);
