@@ -25,9 +25,12 @@
 //!
 #ifndef __ENCODE_TILE_H__
 #define __ENCODE_TILE_H__
+#include <array>
+
 #include "encode_basic_feature.h"
 #include "encode_pipeline.h"
-#include "codechal_encoder_base.h"
+
+#define __THIRD_LVL_BB_DEFAULT_COUNT 4
 
 namespace encode
 {
@@ -156,7 +159,7 @@ class EncodeTile : public MediaFeature
 public:
     EncodeTile(MediaFeatureManager *featureManager,
         EncodeAllocator *allocator,
-        CodechalHwInterface *hwInterface,
+        CodechalHwInterfaceNext *hwInterface,
         void *constSettings);
 
     virtual ~EncodeTile();
@@ -213,6 +216,13 @@ public:
     virtual MOS_STATUS GetThirdLevelBatchBuffer(
         PMHW_BATCH_BUFFER &thirdLevelBatchBuffer);
 
+    //!
+    //! \brief  Increment the current third Level Batch Buffer from Encode Tile features
+    //! \return MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS IncrementThirdLevelBatchBuffer();
+
     //!
     //! \brief  Begin Patching tile Level Batch Buffer
     //! \param  [in] tileRowPass
@@ -475,10 +485,10 @@ protected:
     //!
     virtual MOS_STATUS AllocateTileStatistics(void *params) = 0;
 
-    EncodeAllocator      *m_allocator         = nullptr;  //!< Allocator used in tile feature
-    EncodeBasicFeature   *m_basicFeature      = nullptr;  //!< EncodeBasicFeature
-    CodechalHwInterface  *m_hwInterface       = nullptr;  //!< Hw interface as utilities
-    MediaFeatureManager  *m_featureManager    = nullptr;  //!< Pointer to feature manager
+    EncodeAllocator          *m_allocator         = nullptr;  //!< Allocator used in tile feature
+    EncodeBasicFeature       *m_basicFeature      = nullptr;  //!< EncodeBasicFeature
+    CodechalHwInterfaceNext  *m_hwInterface       = nullptr;  //!< Hw interface as utilities
+    MediaFeatureManager      *m_featureManager    = nullptr;  //!< Pointer to feature manager
 
     EncodeTileData       *m_tileData          = nullptr;  //!< Pointer to the Tile data array
     uint32_t              m_numTiles          = 1;        //!< Total tile numbers
@@ -496,8 +506,9 @@ protected:
     EncodeTileCodingParams m_curTileCodingParams = {};  //! Current tile coding paramters
 
     // 3rd Level Batch buffer
-    uint32_t         m_thirdLevelBatchSize   = 0;   //!< Size of the 3rd level batch buffer
-    MHW_BATCH_BUFFER m_thirdLevelBatchBuffer = {};  //!< 3rd level batch buffer
+    uint32_t                                                                m_thirdLevelBatchSize   = 0;   //!< Size of the 3rd level batch buffer
+    std::array<MHW_BATCH_BUFFER, __THIRD_LVL_BB_DEFAULT_COUNT>              m_thirdLevelBatchBuffers = { 0 };  //!< 3rd level batch buffer
+    std::array<MHW_BATCH_BUFFER, __THIRD_LVL_BB_DEFAULT_COUNT>::iterator    m_currentThirdLevelBatchBuffer;   
 
     // Tile level batch buffer
     uint32_t          m_tileLevelBatchSize    = 0;    //!< Size of the 2rd level batch buffer for each tile
@@ -514,7 +525,7 @@ protected:
 
     bool              m_enableTileReplay = false;  //!< TileReplay Enable
 
-MEDIA_CLASS_DEFINE_END(EncodeTile)
+MEDIA_CLASS_DEFINE_END(encode__EncodeTile)
 };
 
 }  // namespace encode
