@@ -26,10 +26,16 @@
 #ifndef __MHW_UTILITIES_NEXT_H__
 #define __MHW_UTILITIES_NEXT_H__
 
+#include <memory>
+#include "mos_defs.h"
 #include "mos_os.h"
-#include <math.h>
 #include "mos_util_debug.h"
 #include "mhw_mmio.h"
+#include "mos_os_hw.h"
+#include "mos_os_specific.h"
+#include "mos_resource_defs.h"
+#include "mos_utilities.h"
+struct _MHW_BATCH_BUFFER;
 
 typedef struct _MHW_RCS_SURFACE_PARAMS MHW_RCS_SURFACE_PARAMS, * PMHW_RCS_SURFACE_PARAMS;
 typedef struct _MHW_BATCH_BUFFER MHW_BATCH_BUFFER, * PMHW_BATCH_BUFFER;
@@ -733,8 +739,8 @@ static __inline MOS_STATUS Mhw_AddCommandBB(
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
 
     //---------------------------------------------
-    MHW_CHK_NULL(pBatchBuffer);
-    MHW_CHK_NULL(pBatchBuffer->pData);
+    MHW_CHK_NULL_RETURN(pBatchBuffer);
+    MHW_CHK_NULL_RETURN(pBatchBuffer->pData);
     //---------------------------------------------
 
     pbBatchPtr = pBatchBuffer->pData + pBatchBuffer->iCurrent;
@@ -760,7 +766,6 @@ static __inline MOS_STATUS Mhw_AddCommandBB(
         }
     }
 
-finish:
     return eStatus;
 }
 
@@ -769,14 +774,16 @@ finish:
 //| Return:     MOS_STATUS_SUCCESS if call succeeds
 //*-----------------------------------------------------------------------------
 static __inline MOS_STATUS Mhw_AddCommandCmdOrBB(
-    void* pCmdBuffer,     // [in] Pointer to Command Buffer
-    void* pBatchBuffer,   // [in] Pointer to Batch Buffer
-    const void* pCmd,           // [in] Command Pointer
-    uint32_t   dwCmdSize)       // [in] Size of command in bytes
+    PMOS_INTERFACE pOsInterface, // [in] Pointer to mos interface
+    void* pCmdBuffer,            // [in] Pointer to Command Buffer
+    void* pBatchBuffer,          // [in] Pointer to Batch Buffer
+    const void* pCmd,            // [in] Command Pointer
+    uint32_t   dwCmdSize)        // [in] Size of command in bytes
 {
     if (pCmdBuffer)
     {
-        return ((MOS_STATUS)Mos_AddCommand((PMOS_COMMAND_BUFFER)pCmdBuffer, pCmd, dwCmdSize));
+        MHW_CHK_NULL_RETURN(pOsInterface);
+        return pOsInterface->pfnAddCommand((PMOS_COMMAND_BUFFER)pCmdBuffer, pCmd, dwCmdSize);
     }
     else if (pBatchBuffer)
     {
