@@ -290,7 +290,7 @@ struct _MHW_PAR_T(AVP_INLOOP_FILTER_STATE)
 struct _MHW_PAR_T(AVP_TILE_CODING)
 {
     uint16_t tileId                                  = 0;
-    uint16_t tileNum                                 = 0;  //!< Tile ID in its Tile group
+    uint16_t tgTileNum                                 = 0;  //!< Tile ID in its Tile group
     uint16_t tileGroupId                             = 0;
 
     uint16_t tileColPositionInSb                     = 0;
