@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020, Intel Corporation
+* Copyright (c) 2020-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -33,14 +33,14 @@
 #include "codec_def_common.h"
 #include "codec_def_common_encode.h"
 
-#ifdef IGFX_VDENC_INTERFACE_EXT_SUPPORT
+#if _MEDIA_RESERVED
 #include "mhw_vdbox_vdenc_cmdpar_ext.h"
 #define __MHW_VDBOX_VDENC_WRAPPER(STUFF)
 #define __MHW_VDBOX_VDENC_WRAPPER_EXT(STUFF) STUFF
 #else
 #define __MHW_VDBOX_VDENC_WRAPPER(STUFF) STUFF
 #define __MHW_VDBOX_VDENC_WRAPPER_EXT(STUFF)
-#endif
+#endif  // _MEDIA_RESERVED
 
 namespace mhw
 {
@@ -167,14 +167,21 @@ struct _MHW_PAR_T(VDENC_PIPE_MODE_SELECT)
     uint8_t wirelessSessionId        = 0;
     uint8_t tailPointerReadFrequency = 0;
     uint8_t streamingBufferConfig    = 0;
+    bool    bt2020RGB2YUV            = 0;
+    uint8_t rgbInputStudioRange      = 0;
+    uint8_t convertedYUVStudioRange  = 0;
     uint8_t VdencPipeModeSelectPar0  = 0;
     uint8_t VdencPipeModeSelectPar1  = 0;
-    uint8_t VdencPipeModeSelectPar2  = 0; 
-    uint8_t VdencPipeModeSelectPar3  = 0; 
-    uint8_t VdencPipeModeSelectPar4  = 0; 
-    uint8_t VdencPipeModeSelectPar5  = 0; 
-    uint8_t VdencPipeModeSelectPar6  = 0; 
+    uint8_t VdencPipeModeSelectPar2  = 0;
+    uint8_t VdencPipeModeSelectPar3  = 0;
+    uint8_t VdencPipeModeSelectPar4  = 0;
+    uint8_t VdencPipeModeSelectPar5  = 0;
+    uint8_t VdencPipeModeSelectPar6  = 0;
     uint8_t VdencPipeModeSelectPar7  = 0;
+    uint8_t VdencPipeModeSelectPar8  = 0;
+    bool    VdencPipeModeSelectPar9  = false;
+    uint8_t VdencPipeModeSelectPar10 = 0;
+    uint8_t VdencPipeModeSelectPar11 = 0;
 };
 
 struct _MHW_PAR_T(VDENC_SRC_SURFACE_STATE)
@@ -264,7 +271,8 @@ struct _MHW_PAR_T(VDENC_PIPE_BUF_ADDR_STATE)
     PMOS_RESOURCE     mfdIntraRowStoreScratchBuffer     = nullptr;
     PMOS_RESOURCE     cumulativeCuCountStreamOutBuffer  = nullptr;
     PMOS_RESOURCE     colocatedMvWriteBuffer            = nullptr;
-    __MHW_VDBOX_VDENC_WRAPPER_EXT(VDENC_PIPE_BUF_ADDR_STATE_CMDPAR_EXT);
+    PMOS_RESOURCE     vdencPipeBufAddrStatePar0         = nullptr;
+    PMOS_RESOURCE     vdencPipeBufAddrStatePar1         = nullptr;
 };
 
 struct _MHW_PAR_T(VDENC_WEIGHTSOFFSETS_STATE)
@@ -317,6 +325,7 @@ struct _MHW_PAR_T(VDENC_HEVC_VP9_TILE_SLICE_STATE)
     uint32_t VdencHEVCVP9TileSlicePar19    = 0;
     uint32_t VdencHEVCVP9TileSlicePar22    = 0;
     uint32_t VdencHEVCVP9TileSlicePar23    = 0;
+    uint32_t VdencHEVCVP9TileSlicePar24    = 0;
 };
 
 struct _MHW_PAR_T(VDENC_WALKER_STATE)
@@ -355,107 +364,159 @@ struct _MHW_PAR_T(VDENC_AVC_SLICE_STATE)
 
 struct _MHW_PAR_T(VDENC_AVC_IMG_STATE)
 {
-    __MHW_VDBOX_VDENC_WRAPPER_EXT(VDENC_AVC_IMG_STATE_CMDPAR_EXT);
+    uint8_t  pictureType                            = 0;
+    uint8_t  transform8X8Flag                       = 0;
+    bool     colMVWriteEnable                       = false;
+    uint8_t  subpelMode                             = 3;
+    bool     colMVReadEnable                        = false;
+    uint8_t  bidirectionalWeight                    = 0;
+    uint16_t pictureHeightMinusOne                  = 0;
+    uint16_t pictureWidth                           = 0;
+    uint8_t  fwdRefIdx0ReferencePicture             = 0;
+    uint8_t  bwdRefIdx0ReferencePicture             = 0;
+    uint8_t  fwdRefIdx1ReferencePicture             = 0;
+    uint8_t  fwdRefIdx2ReferencePicture             = 0;
+    uint8_t  numberOfL0ReferencesMinusOne           = 0;
+    uint8_t  numberOfL1ReferencesMinusOne           = 0;
+    uint8_t  intraRefreshMbPos                      = 0;
+    uint8_t  intraRefreshMbSizeMinusOne             = 0;
+    uint8_t  intraRefreshEnableRollingIEnable       = 0;
+    uint8_t  intraRefreshMode                       = 0;
+    uint8_t  qpAdjustmentForRollingI                = 0;
+    uint8_t  roiQpAdjustmentForZone0                = 0;
+    uint8_t  roiQpAdjustmentForZone1                = 0;
+    uint8_t  roiQpAdjustmentForZone2                = 0;
+    uint8_t  roiQpAdjustmentForZone3                = 0;
+    uint8_t  minQp                                  = 0xa;
+    uint8_t  maxQp                                  = 0x33;
+    bool     roiEnable                              = false;
+    bool     mbLevelQpEnable                        = false;
+    bool     mbLevelDeltaQpEnable                   = false;
+    bool     longtermReferenceFrameBwdRef0Indicator = false;
+    uint8_t  qpPrimeY                               = 0;
+    uint8_t  trellisQuantEn                         = 0;
+    uint8_t  pocNumberForCurrentPicture             = 0;
+    uint8_t  pocNumberForFwdRef0                    = 0;
+    uint8_t  pocNumberForFwdRef1                    = 0;
+    uint8_t  pocNumberForFwdRef2                    = 0;
+    uint8_t  pocNumberForBwdRef0                    = 0;
+
+    __MHW_VDBOX_VDENC_WRAPPER(
+        std::vector<std::function<MOS_STATUS(uint32_t *)>> extSettings);
+    __MHW_VDBOX_VDENC_WRAPPER_EXT(
+        VDENC_AVC_IMG_STATE_CMDPAR_EXT);
 };
 
 struct _MHW_PAR_T(VDENC_CMD1)
 {
-    uint16_t vdencCmd1Par0     = 0;
-    uint16_t vdencCmd1Par1     = 0;
-    uint8_t  vdencCmd1Par2[8]  = {};
-    uint8_t  vdencCmd1Par3[12] = {};
-    uint8_t  vdencCmd1Par4[12] = {};
-    uint8_t  vdencCmd1Par5     = 0;
-    uint8_t  vdencCmd1Par6     = 0;
-    uint8_t  vdencCmd1Par7     = 0;
-    uint8_t  vdencCmd1Par8[4]  = {};
-    uint8_t  vdencCmd1Par9[4]  = {};
-    uint8_t  vdencCmd1Par10[4] = {};
-    uint8_t  vdencCmd1Par11[4] = {};
-    uint8_t  vdencCmd1Par12[4] = {};
-    uint8_t  vdencCmd1Par13[4] = {};
-    uint8_t  vdencCmd1Par14[4] = {};
-    uint8_t  vdencCmd1Par15[4] = {};
-    uint8_t  vdencCmd1Par16    = 0;
-    uint8_t  vdencCmd1Par17    = 0;
-    uint8_t  vdencCmd1Par18    = 0;
-    uint8_t  vdencCmd1Par19    = 0;
-    uint8_t  vdencCmd1Par20    = 0;
-    uint8_t  vdencCmd1Par21    = 0;
-    uint8_t  vdencCmd1Par22    = 0;
-    uint8_t  vdencCmd1Par23    = 0;
-    uint8_t  vdencCmd1Par24    = 0;
-    uint8_t  vdencCmd1Par25    = 0;
-    uint8_t  vdencCmd1Par26    = 0;
-    uint8_t  vdencCmd1Par27    = 0;
-    uint8_t  vdencCmd1Par28    = 0;
-    uint8_t  vdencCmd1Par29    = 0;
-    uint8_t  vdencCmd1Par30    = 0;
-    uint8_t  vdencCmd1Par31    = 0;
-    uint8_t  vdencCmd1Par32    = 0;
-    uint8_t  vdencCmd1Par33    = 0;
-    uint8_t  vdencCmd1Par34    = 0;
-    uint8_t  vdencCmd1Par35    = 0;
-    uint8_t  vdencCmd1Par36    = 0;
-    uint8_t  vdencCmd1Par37    = 0;
-    uint8_t  vdencCmd1Par38    = 0;
-    uint8_t  vdencCmd1Par39    = 0;
-    uint8_t  vdencCmd1Par40    = 0;
-    uint8_t  vdencCmd1Par41    = 0;
-    uint8_t  vdencCmd1Par42    = 0;
-    uint8_t  vdencCmd1Par43    = 0;
-    uint8_t  vdencCmd1Par44    = 0;
-    uint8_t  vdencCmd1Par45    = 0;
-    uint8_t  vdencCmd1Par46    = 0;
-    uint8_t  vdencCmd1Par47    = 0;
-    uint8_t  vdencCmd1Par48    = 0;
-    uint8_t  vdencCmd1Par49    = 0;
-    uint8_t  vdencCmd1Par50    = 0;
-    uint8_t  vdencCmd1Par51    = 0;
-    uint8_t  vdencCmd1Par52    = 0;
-    uint8_t  vdencCmd1Par53    = 0;
-    uint8_t  vdencCmd1Par54    = 0;
-    uint8_t  vdencCmd1Par55    = 0;
-    uint8_t  vdencCmd1Par56    = 0;
-    uint8_t  vdencCmd1Par57    = 0;
-    uint8_t  vdencCmd1Par58    = 0;
-    uint8_t  vdencCmd1Par59    = 0;
-    uint8_t  vdencCmd1Par60    = 0;
-    uint8_t  vdencCmd1Par61    = 0;
-    uint8_t  vdencCmd1Par62    = 0;
-    uint8_t  vdencCmd1Par63    = 0;
-    uint8_t  vdencCmd1Par64    = 0;
-    uint8_t  vdencCmd1Par65    = 0;
-    uint8_t  vdencCmd1Par66    = 0;
-    uint8_t  vdencCmd1Par67    = 0;
-    uint8_t  vdencCmd1Par68    = 0;
-    uint8_t  vdencCmd1Par69    = 0;
-    uint8_t  vdencCmd1Par70    = 0;
-    uint8_t  vdencCmd1Par71    = 0;
-    uint8_t  vdencCmd1Par72    = 0;
-    uint8_t  vdencCmd1Par73    = 0;
-    uint8_t  vdencCmd1Par74    = 0;
-    uint8_t  vdencCmd1Par75    = 0;
-    uint8_t  vdencCmd1Par76    = 0;
-    uint8_t  vdencCmd1Par77    = 0;
-    uint8_t  vdencCmd1Par78    = 0;
-    uint8_t  vdencCmd1Par79    = 0;
-    uint8_t  vdencCmd1Par80    = 0;
-    uint8_t  vdencCmd1Par81    = 0;
-    uint8_t  vdencCmd1Par82    = 0;
-    uint8_t  vdencCmd1Par83    = 0;
-    uint8_t  vdencCmd1Par84    = 0;
-    uint8_t  vdencCmd1Par85    = 0;
-    uint8_t  vdencCmd1Par86    = 0;
-    uint8_t  vdencCmd1Par87    = 0;
-    uint8_t  vdencCmd1Par88    = 0;
-    uint8_t  vdencCmd1Par89    = 0;
-    uint8_t  vdencCmd1Par90    = 0;
-    uint8_t  vdencCmd1Par91    = 0;
-    uint8_t  vdencCmd1Par92    = 0;
-    uint8_t  vdencCmd1Par93    = 0;
-    uint8_t  vdencCmd1Par94    = 0;
-    uint8_t  vdencCmd1Par95    = 0;
+    uint16_t vdencCmd1Par0      = 0;
+    uint16_t vdencCmd1Par1      = 0;
+    uint8_t  vdencCmd1Par2[8]   = {};
+    uint8_t  vdencCmd1Par3[12]  = {};
+    uint8_t  vdencCmd1Par4[12]  = {};
+    uint8_t  vdencCmd1Par5      = 0;
+    uint8_t  vdencCmd1Par6      = 0;
+    uint8_t  vdencCmd1Par7      = 0;
+    uint8_t  vdencCmd1Par8[4]   = {};
+    uint8_t  vdencCmd1Par9[4]   = {};
+    uint8_t  vdencCmd1Par10[4]  = {};
+    uint8_t  vdencCmd1Par11[4]  = {};
+    uint8_t  vdencCmd1Par12[4]  = {};
+    uint8_t  vdencCmd1Par13[4]  = {};
+    uint8_t  vdencCmd1Par14[4]  = {};
+    uint8_t  vdencCmd1Par15[4]  = {};
+    uint8_t  vdencCmd1Par16     = 0;
+    uint8_t  vdencCmd1Par17     = 0;
+    uint8_t  vdencCmd1Par18     = 0;
+    uint8_t  vdencCmd1Par19     = 0;
+    uint8_t  vdencCmd1Par20     = 0;
+    uint8_t  vdencCmd1Par21     = 0;
+    uint8_t  vdencCmd1Par22     = 0;
+    uint8_t  vdencCmd1Par23     = 0;
+    uint8_t  vdencCmd1Par24     = 0;
+    uint8_t  vdencCmd1Par25     = 0;
+    uint8_t  vdencCmd1Par26     = 0;
+    uint8_t  vdencCmd1Par27     = 0;
+    uint8_t  vdencCmd1Par28     = 0;
+    uint8_t  vdencCmd1Par29     = 0;
+    uint8_t  vdencCmd1Par30     = 0;
+    uint8_t  vdencCmd1Par31     = 0;
+    uint8_t  vdencCmd1Par32     = 0;
+    uint8_t  vdencCmd1Par33     = 0;
+    uint8_t  vdencCmd1Par34     = 0;
+    uint8_t  vdencCmd1Par35     = 0;
+    uint8_t  vdencCmd1Par36     = 0;
+    uint8_t  vdencCmd1Par37     = 0;
+    uint8_t  vdencCmd1Par38     = 0;
+    uint8_t  vdencCmd1Par39     = 0;
+    uint8_t  vdencCmd1Par40     = 0;
+    uint8_t  vdencCmd1Par41     = 0;
+    uint8_t  vdencCmd1Par42     = 0;
+    uint8_t  vdencCmd1Par43     = 0;
+    uint8_t  vdencCmd1Par44     = 0;
+    uint8_t  vdencCmd1Par45     = 0;
+    uint8_t  vdencCmd1Par46     = 0;
+    uint8_t  vdencCmd1Par47     = 0;
+    uint8_t  vdencCmd1Par48     = 0;
+    uint8_t  vdencCmd1Par49     = 0;
+    uint8_t  vdencCmd1Par50     = 0;
+    uint8_t  vdencCmd1Par51     = 0;
+    uint8_t  vdencCmd1Par52     = 0;
+    uint8_t  vdencCmd1Par53     = 0;
+    uint8_t  vdencCmd1Par54     = 0;
+    uint8_t  vdencCmd1Par55     = 0;
+    uint8_t  vdencCmd1Par56     = 0;
+    uint8_t  vdencCmd1Par57     = 0;
+    uint8_t  vdencCmd1Par58     = 0;
+    uint8_t  vdencCmd1Par59     = 0;
+    uint8_t  vdencCmd1Par60     = 0;
+    uint8_t  vdencCmd1Par61     = 0;
+    uint8_t  vdencCmd1Par62     = 0;
+    uint8_t  vdencCmd1Par63     = 0;
+    uint8_t  vdencCmd1Par64     = 0;
+    uint8_t  vdencCmd1Par65     = 0;
+    uint8_t  vdencCmd1Par66     = 0;
+    uint8_t  vdencCmd1Par67     = 0;
+    uint8_t  vdencCmd1Par68     = 0;
+    uint8_t  vdencCmd1Par69     = 0;
+    uint8_t  vdencCmd1Par70     = 0;
+    uint8_t  vdencCmd1Par71     = 0;
+    uint8_t  vdencCmd1Par72     = 0;
+    uint8_t  vdencCmd1Par73     = 0;
+    uint8_t  vdencCmd1Par74     = 0;
+    uint8_t  vdencCmd1Par75     = 0;
+    uint8_t  vdencCmd1Par76     = 0;
+    uint8_t  vdencCmd1Par77     = 0;
+    uint8_t  vdencCmd1Par78     = 0;
+    uint8_t  vdencCmd1Par79     = 0;
+    uint8_t  vdencCmd1Par80     = 0;
+    uint8_t  vdencCmd1Par81     = 0;
+    uint8_t  vdencCmd1Par82     = 0;
+    uint8_t  vdencCmd1Par83     = 0;
+    uint8_t  vdencCmd1Par84     = 0;
+    uint8_t  vdencCmd1Par85     = 0;
+    uint8_t  vdencCmd1Par86     = 0;
+    uint8_t  vdencCmd1Par87     = 0;
+    uint8_t  vdencCmd1Par88     = 0;
+    uint8_t  vdencCmd1Par89     = 0;
+    uint8_t  vdencCmd1Par90     = 0;
+    uint8_t  vdencCmd1Par91     = 0;
+    uint8_t  vdencCmd1Par92     = 0;
+    uint8_t  vdencCmd1Par93     = 0;
+    uint8_t  vdencCmd1Par94     = 0;
+    uint8_t  vdencCmd1Par95     = 0;
+    uint8_t  vdnecCmd1Par96[4]  = {};
+    uint8_t  vdnecCmd1Par97[4]  = {};
+    uint8_t  vdnecCmd1Par98[4]  = {};
+    uint8_t  vdnecCmd1Par99[4]  = {};
+    uint8_t  vdnecCmd1Par100[2] = {};
+    uint8_t  vdnecCmd1Par101[2] = {};
+    uint8_t  vdnecCmd1Par102[2] = {};
+    uint8_t  vdnecCmd1Par103[2] = {};
+    uint8_t  vdencCmd1Par104[4] = {};
+    uint8_t  vdencCmd1Par105[4] = {};
+    uint8_t  vdencCmd1Par106[4] = {};
+    uint8_t  vdencCmd1Par107    = 0;
 };
 
 struct _MHW_PAR_T(VDENC_CMD2)
@@ -464,7 +525,6 @@ struct _MHW_PAR_T(VDENC_CMD2)
     uint32_t height                           = 0;
     bool     constrainedIntraPred             = false;
     uint8_t  pictureType                      = 0;
-    bool     av1IdentityTransform             = false;
     bool     temporalMvp                      = false;
     bool     collocatedFromL0                 = false;
     uint8_t  longTermReferenceFlagsL0         = 0;
@@ -504,15 +564,48 @@ struct _MHW_PAR_T(VDENC_CMD2)
     uint8_t  qpPrimeYAc                       = 0;
     uint32_t intraRefreshBoundary[3]          = {};
     uint8_t  av1RefId[2][4]                   = {{1, 1, 1, 1}, {1, 1, 1, 1}};
+    uint8_t  subPelMode                       = 3;
 
-    std::vector<std::function<MOS_STATUS(uint32_t*)>> extSettings;
-
+    __MHW_VDBOX_VDENC_WRAPPER(
+        std::vector<std::function<MOS_STATUS(uint32_t *)>> extSettings);
     __MHW_VDBOX_VDENC_WRAPPER_EXT(VDENC_CMD2_CMDPAR_EXT);
 };
 
 struct _MHW_PAR_T(VDENC_CMD3)
 {
-    __MHW_VDBOX_VDENC_WRAPPER_EXT(VDENC_CMD3_CMDPAR_EXT);
+    uint8_t  vdencCmd3Par0[8]  = {};
+    uint8_t  vdencCmd3Par1[12] = {};
+    uint8_t  vdencCmd3Par2[12] = {};
+    uint8_t  vdencCmd3Par3     = 0;
+    uint8_t  vdencCmd3Par4     = 0;
+    uint8_t  vdencCmd3Par5     = 0;
+    uint8_t  vdencCmd3Par6     = 0;
+    uint8_t  vdencCmd3Par7     = 0;
+    uint8_t  vdencCmd3Par8     = 0;
+    uint8_t  vdencCmd3Par9     = 0;
+    uint8_t  vdencCmd3Par10    = 0;
+    uint8_t  vdencCmd3Par11    = 0;
+    uint8_t  vdencCmd3Par12    = 0;
+    uint8_t  vdencCmd3Par13    = 0;
+    uint8_t  vdencCmd3Par14    = 0;
+    uint8_t  vdencCmd3Par15    = 0;
+    uint8_t  vdencCmd3Par16    = 0;
+    uint8_t  vdencCmd3Par17    = 0;
+    uint8_t  vdencCmd3Par18    = 0;
+    uint8_t  vdencCmd3Par19    = 0;
+    uint8_t  vdencCmd3Par20    = 0;
+    uint8_t  vdencCmd3Par21    = 0;
+    uint8_t  vdencCmd3Par22    = 0;
+    uint8_t  vdencCmd3Par23    = 0;
+    uint8_t  vdencCmd3Par24    = 0;
+    uint8_t  vdencCmd3Par25    = 0;
+    uint8_t  vdencCmd3Par26    = 0;
+    uint8_t  vdencCmd3Par27    = 0;
+    uint8_t  vdencCmd3Par28    = 0;
+    uint8_t  vdencCmd3Par29    = 0;
+    uint8_t  vdencCmd3Par30    = 0;
+    uint16_t vdencCmd3Par31    = 0;
+    uint16_t vdencCmd3Par32    = 0;
 };
 }  // namespace vdenc
 }  // namespace vdbox
