@@ -25,7 +25,8 @@
 //!
 
 #include "mos_context_specific_next.h"
-#include "mediamemdecomp.h"
+#include "mos_os_mock_adaptor.h"
+#include "mos_oca_rtlog_mgr.h"
 
 class OsContextNext* OsContextNext::GetOsContextObject()
 {
@@ -44,6 +45,8 @@ void OsContextNext::CleanUp()
 #endif
     MOS_Delete(m_mosMediaCopy);
 
+    MosOcaRTLogMgr::UnRegisterContext(this);
+
     if (m_gpuContextMgr != nullptr)
     {
         m_gpuContextMgr->CleanUp();
@@ -60,3 +63,15 @@ void OsContextNext::CleanUp()
 
     Destroy();
 }
+
+MOS_STATUS OsContextNext::NullHwInit(MOS_CONTEXT_HANDLE osContext)
+{
+    MOS_OS_FUNCTION_ENTER;
+    return MosMockAdaptor::Init(osContext, this);
+}
+
+MOS_STATUS OsContextNext::NullHwDestroy()
+{
+    MOS_OS_FUNCTION_ENTER;
+    return MosMockAdaptor::Destroy();
+}
