@@ -62,6 +62,7 @@ typedef enum
     MOS_SUBCOMP_CODEC              = 2,
     MOS_SUBCOMP_VP                 = 3,
     MOS_SUBCOMP_CP                 = 4,
+    MOS_SUBCOMP_EXT                = 5,
     MOS_SUBCOMP_COUNT
 } MOS_SELF_SUBCOMP_ID;
 
@@ -251,6 +252,7 @@ typedef struct _MOS_MESSAGE_PARAMS
     uint32_t                    bEnableMaps;                                    //!< Dump mapped memory regions to trace file
     uint32_t                    bDisableAssert;                                 //!< Disable assert
     uint32_t                    bEnableFlush;                                   //!< Enable flush
+    uint32_t                    bEnableMemoryFootPrint;                        //!< Disable Memory Foot Print
     MOS_COMPONENT_DEBUG_PARAMS  components[MOS_COMPONENT_COUNT];
     char                        g_MosMsgBuffer[MOS_MAX_MSG_BUF_SIZE];           //!< Array for debug message
 } MOS_MESSAGE_PARAMS;
@@ -302,6 +304,13 @@ public:
     //!
     static void MosHLTFlush();
 
+    //!
+    //! \brief    Disable Memory Foot Print
+    //! \details  Disable Memory Foot Print
+    //! \return   bool
+    //!
+    static bool EnableMemoryFootPrint();
+
     //!
     //! \brief    Form a string that will prefix MOS's log file name
     //! \details  Form a string that will prefix MOS's log file name
@@ -593,6 +602,8 @@ MEDIA_CLASS_DEFINE_END(MosUtilDebug)
 // flush hlt message before workload submission
 #define MOS_FLUSH_HLT_MESSAGE MosUtilDebug::MosHLTFlush();
 
+#define MOS_IS_MEMORY_FOOT_PRINT_ENABLED() MosUtilDebug::EnableMemoryFootPrint()
+
 
 //!
 //! \def MOS_DEBUGMESSAGE(_compID, _subCompID, _message, ...)
@@ -753,89 +764,90 @@ MEDIA_CLASS_DEFINE_END(MosUtilDebug)
 
 #define MT_LOG(id, lvl)                                                     \
     {                                                                       \
-        int32_t head[] = {id, lvl};                                         \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 0, head, sizeof(head), nullptr, 0); \
+        int32_t _head[] = {id, lvl};                                         \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 0, _head, sizeof(_head), nullptr, 0); \
     }
 
 #define MT_LOG1(id, lvl, p1, v1)                                                      \
     {                                                                                 \
-        int32_t   head[] = {id, lvl};                                                 \
-        MT_PARAM param[] = {p1, v1};                                                  \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 1, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                 \
+        MT_PARAM  _param[] = {p1, v1};                                                  \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 1, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG2(id, lvl, p1, v1, p2, v2)                                              \
     {                                                                                 \
-        int32_t   head[] = {id, lvl};                                                 \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}};                                      \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 2, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                 \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}};                                      \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 2, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG3(id, lvl, p1, v1, p2, v2, p3, v3)                                      \
     {                                                                                 \
-        int32_t   head[] = {id, lvl};                                                 \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}};                            \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 3, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                 \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}};                            \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 3, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG4(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4)                              \
     {                                                                                 \
-        int32_t   head[] = {id, lvl};                                                 \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}};                  \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 4, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                 \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}};                  \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 4, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG5(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5)                                   \
     {                                                                                              \
-        int32_t   head[] = {id, lvl};                                                              \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}};                     \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 5, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                              \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}};                     \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 5, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG6(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6)                           \
     {                                                                                              \
-        int32_t   head[] = {id, lvl};                                                              \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}};           \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 6, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                              \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}};           \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 6, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG7(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6, p7, v7)                   \
     {                                                                                              \
-        int32_t   head[] = {id, lvl};                                                              \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}, {p7, v7}}; \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 7, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                              \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}, {p7, v7}}; \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 7, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_ERR(id)                                                          \
     {                                                                       \
-        int32_t head[] = {id};                                              \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 0, head, sizeof(head), nullptr, 0); \
+        int32_t _head[] = {id};                                              \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 0, _head, sizeof(_head), nullptr, 0); \
     }
 
 #define MT_ERR1(id, p1, v1)                                                           \
     {                                                                                 \
-        int32_t   head[] = {id};                                                      \
-        MT_PARAM param[] = {p1, v1};                                                  \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 1, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id};                                                      \
+        MT_PARAM  _param[] = {p1, v1};                                                  \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 1, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_ERR2(id, p1, v1, p2, v2)                                                   \
     {                                                                                 \
-        int32_t   head[] = {id};                                                      \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}};                                      \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 2, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id};                                                      \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}};                                      \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 2, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_ERR3(id, p1, v1, p2, v2, p3, v3)                                           \
     {                                                                                 \
-        int32_t   head[] = {id};                                                      \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}};                            \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 3, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id};                                                      \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}};                            \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 3, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #else // !MOS_MESSAGES_ENABLED
 
 #define MOS_FLUSH_HLT_MESSAGE
+#define MOS_IS_MEMORY_FOOT_PRINT_ENABLED() 0
 
 //!
 //! \brief   The two methods below are used only for debug or release internal drivers
@@ -995,11 +1007,11 @@ MEDIA_CLASS_DEFINE_END(MosUtilDebug)
 //!
 #define MOS_CHK_STATUS_NO_STATUS_RETURN(_compID, _subCompID, _stmt)                         \
 {                                                                                           \
-    eStatus = (MOS_STATUS)(_stmt);                                                          \
-    if (eStatus != MOS_STATUS_SUCCESS)                                                      \
+    MOS_STATUS stmtStatus = (MOS_STATUS)(_stmt);                                                          \
+    if (stmtStatus != MOS_STATUS_SUCCESS)                                                      \
     {                                                                                       \
-        MT_ERR3(MT_ERR_MOS_STATUS_CHECK, MT_COMPONENT, _compID, MT_SUB_COMPONENT, _subCompID, MT_ERROR_CODE, eStatus); \
-        MOS_ASSERTMESSAGE(_compID, _subCompID, "MOS returned error, eStatus = 0x%x", eStatus);\
+        MT_ERR3(MT_ERR_MOS_STATUS_CHECK, MT_COMPONENT, _compID, MT_SUB_COMPONENT, _subCompID, MT_ERROR_CODE, stmtStatus); \
+        MOS_ASSERTMESSAGE(_compID, _subCompID, "MOS returned error, eStatus = 0x%x", stmtStatus);\
         return;                                                                             \
     }                                                                                       \
 }
@@ -1362,12 +1374,12 @@ public:
         m_subCompID(subCompID),
         m_name(name)
     {
-        MOS_VERBOSEMESSAGE(m_compID, m_subCompID, "Enter Function: %s\r\n", m_name);
+        MOS_VERBOSEMESSAGE(m_compID, m_subCompID, "Enter Function:%s\r\n", m_name);
     }
 
     virtual ~FunctionTrace()
     {
-        MOS_VERBOSEMESSAGE(m_compID, m_subCompID, "Exit Function: %s\r\n", m_name);
+        MOS_VERBOSEMESSAGE(m_compID, m_subCompID, "Exit Function:%s\r\n", m_name);
     }
 
 protected:
