@@ -41,54 +41,55 @@ static const char *attrDumpBufferInBinary    = "DumpBufferInBinary";
 static const char *attrDumpToThreadFolder    = "DumpToThreadFolder";
 static const char *attrDumpCmdBufInBinary    = "DumpCmdBufInBinary";
 static const char *attrEnableFastDump        = "EnableFastDump";
-static const char *attrFastDumpAllowDataLoss = "FastDumpAllowDataLoss";
-static const char *attrFastDumpInformOnError = "FastDumpInformOnError";
 
 //Codec Attr 
-static const char *attrPicParams              = "PicParams";
-static const char *attrSubsetsParams          = "SubsetsParams";
-static const char *attrFeiPicParams           = "FeiPicParams";
-static const char *attrMvcExtPicParams        = "MvcExtPicParams";
-static const char *attrSegmentParams          = "SegmentParams";
-static const char *attrSlcParams              = "SlcParams";
-static const char *attrMbParams               = "MbParams";
-static const char *attrIqParams               = "IqParams";
-static const char *attrSeqParams              = "SeqParams";
-static const char *attrVuiParams              = "VuiParams";
-static const char *attrBitstream              = "Bitstream";
-static const char *attrStreamOut              = "StreamOut";
-static const char *attrStreamIn               = "StreamIn";
-static const char *attrResidualDifference     = "ResidualDifference";
-static const char *attrDeblocking             = "Deblocking";
-static const char *attrMvData                 = "MvData";
-static const char *attrVc1Bitplane            = "Vc1Bitplane";
-static const char *attrCoefProb               = "CoefProb";
-static const char *attrSegId                  = "SegId";
-static const char *attrHucRegions             = "HucRegions";
-static const char *attrHuCDmem                = "HucDmem";
-static const char *attrCmdBufferMfx           = "CmdBufferMfx";
-static const char *attr2ndLvlBatchMfx         = "2ndLvlBatchMfx";
-static const char *attrSurfaceInfo            = "SurfaceInfo";
-static const char *attrDecodeOutputSurface    = "DecodeOutputSurface";
-static const char *attrDecodeCompSurface      = "DumpCompressedSurface";
-static const char *attrDecodeAuxSurface       = "DumpAuxsurface";
-static const char *attrDecodeBltOutput        = "DumpBltOutput";
-static const char *attrSfcOutputSurface       = "SfcOutputSurface";
-static const char *attrSfcBuffers             = "SfcBuffers";
-static const char *attrReferenceSurfaces      = "ReferenceSurfaces";
-static const char *attrEncodeRawInputSurface  = "EncodeRawInputSurface";
-static const char *attrReconstructedSurface   = "ReconstructedSurface";
-static const char *attrPakInput               = "PakInput";
-static const char *attrPakOutput              = "PakOutput";
-static const char *attrUpsamlingInput         = "UpsamplingInput";
-static const char *attrResidualSurface        = "ResidualSurface";
-static const char *attrStCoeff                = "StCoeff";
-static const char *attrCoeffPredCs            = "CoeffPredCs";
-static const char *attrMbRecord               = "MbRecord";
-static const char *attrOverwriteCommands      = "OverwriteCommands";
-static const char *attrHuffmanTbl             = "HuffmanTbl";
-static const char *attrScanParams             = "ScanParams";
-static const char *attrDriverUltDump          = "DriverUltDump";
+static const char *attrPicParams               = "PicParams";
+static const char *attrSubsetsParams           = "SubsetsParams";
+static const char *attrFeiPicParams            = "FeiPicParams";
+static const char *attrMvcExtPicParams         = "MvcExtPicParams";
+static const char *attrSegmentParams           = "SegmentParams";
+static const char *attrSlcParams               = "SlcParams";
+static const char *attrMbParams                = "MbParams";
+static const char *attrIqParams                = "IqParams";
+static const char *attrSeqParams               = "SeqParams";
+static const char *attrVuiParams               = "VuiParams";
+static const char *attrDecodeBitstream         = "DecodeBitstream";             // Decode Bitstream
+static const char *attrBitstream               = "Bitstream";                   // Encode Bitstream
+static const char *attrStreamOut               = "StreamOut";
+static const char *attrStreamIn                = "StreamIn";
+static const char *attrResidualDifference      = "ResidualDifference";
+static const char *attrDeblocking              = "Deblocking";
+static const char *attrMvData                  = "MvData";
+static const char *attrVc1Bitplane             = "Vc1Bitplane";
+static const char *attrCoefProb                = "CoefProb";
+static const char *attrSegId                   = "SegId";
+static const char *attrHucRegions              = "HucRegions";
+static const char *attrHuCDmem                 = "HucDmem";
+static const char *attrCmdBufferMfx            = "CmdBufferMfx";
+static const char *attr2ndLvlBatchMfx          = "2ndLvlBatchMfx";
+static const char *attrSurfaceInfo             = "SurfaceInfo";
+static const char *attrDelayForDumpOutput      = "DelayForDumpOutput";
+static const char *attrDecodeOutputSurface     = "DecodeOutputSurface";
+static const char *attrDecodeCompSurface       = "DumpCompressedSurface";
+static const char *attrDecodeAuxSurface        = "DumpAuxsurface";
+static const char *attrDecodeBltOutput         = "DumpBltOutput";
+static const char *attrSfcOutputSurface        = "SfcOutputSurface";
+static const char *attrSfcBuffers              = "SfcBuffers";
+static const char *attrDecodeReferenceSurfaces = "DecodeReferenceSurfaces";     // Decode Reference Surfaces
+static const char *attrReferenceSurfaces       = "ReferenceSurfaces";           // Encode Reference Surfaces
+static const char *attrEncodeRawInputSurface   = "EncodeRawInputSurface";
+static const char *attrReconstructedSurface    = "ReconstructedSurface";
+static const char *attrPakInput                = "PakInput";
+static const char *attrPakOutput               = "PakOutput";
+static const char *attrUpsamlingInput          = "UpsamplingInput";
+static const char *attrResidualSurface         = "ResidualSurface";
+static const char *attrStCoeff                 = "StCoeff";
+static const char *attrCoeffPredCs             = "CoeffPredCs";
+static const char *attrMbRecord                = "MbRecord";
+static const char *attrOverwriteCommands       = "OverwriteCommands";
+static const char *attrHuffmanTbl              = "HuffmanTbl";
+static const char *attrScanParams              = "ScanParams";
+static const char *attrDriverUltDump           = "DriverUltDump";
 
 static const char *attrDumpEncodePar          = "DumpEncodePar";
 static const char *attrForceCmdDumpLvl        = "ForceCmdDumpLvl";
