@@ -51,6 +51,9 @@
 #define SCALABILITY_ASSERT(_expr) \
     MOS_ASSERT(MOS_COMPONENT_SCALABILITY, 0, _expr)
 
+#define SCALABILITY_COND_CHECK(_expr, _message, ...) \
+    MOS_CHK_COND_RETURN(MOS_COMPONENT_SCALABILITY, 0, _expr, _message, ##__VA_ARGS__)
+
 enum ScalabilityComponentType
 {
     scalabilityEncoder = 0,
@@ -68,7 +71,6 @@ enum ScalabilitySyncType
 
 struct ScalabilityPars : public ContextRequirement
 {
-    bool    enableMdf      = false;
     bool    enableVE       = false;
     bool    forceMultiPipe = false;
 
@@ -83,6 +85,7 @@ struct ScalabilityPars : public ContextRequirement
     bool    enableTileReplay = false;
     uint32_t raMode = 0;
     uint32_t protectMode = 0;
+    bool     allowSwArbitarySplit = false;
 };
 
 class ScalabilityTrace
