@@ -164,8 +164,12 @@ MOS_STATUS VpAllocator::DestroySurface(MOS_SURFACE *surface, MOS_GFXRES_FREE_FLA
 {
     VP_FUNC_CALL();
     VP_PUBLIC_CHK_NULL_RETURN(m_allocator);
-
-    return m_allocator->DestroySurface(surface, flags);
+    MOS_GFXRES_FREE_FLAGS resFreeFlags = {0};
+    if (IsSyncFreeNeededForMMCSurface(surface))
+    {
+        resFreeFlags.SynchronousDestroy = 1;
+    }
+    return m_allocator->DestroySurface(surface, resFreeFlags);
 }
 
 VP_SURFACE* VpAllocator::AllocateVpSurface(MOS_ALLOC_GFXRES_PARAMS &param, bool zeroOnAllocate, VPHAL_CSPACE ColorSpace, uint32_t ChromaSiting)
@@ -481,6 +485,29 @@ MOS_STATUS VpAllocator::DestroyVpSurface(VP_SURFACE* &surface, bool deferredDest
 
     if (surface->isResourceOwner)
     {
+#if !EMUL
+    MT_LOG5(MT_VP_HAL_DESTROY_SURF, MT_NORMAL,
+        MT_VP_HAL_SURF_ALLOC_PARAM_PTR, *(int64_t *)(&surface),
+        MT_VP_HAL_SURF_ALLOC_PARAM_MOS_SURF_PTR, *(int64_t *)(&surface->osSurface),
+        MT_VP_HAL_SURF_ALLOC_PARAM_IS_RES_OWNER, surface->isResourceOwner,
+        MT_VP_HAL_SURF_ALLOC_PARAM_HANDLE, static_cast<int64_t>(surface->GetAllocationHandle(m_osInterface)),
+        MT_VP_HAL_SURF_ALLOC_PARAM_SIZE, static_cast<int64_t>(surface->osSurface->OsResource.pGmmResInfo ? surface->osSurface->OsResource.pGmmResInfo->GetSizeAllocation() : 0));
+    VP_PUBLIC_NORMALMESSAGE(
+        "VP_HAL_DESTROY_SURF. "
+        "VP_HAL_Surface: %p, "
+        "VP_HAL_OsSurface: %p, "
+        "VP_HAL_isResourceOwner: %d, "
+        "VP_HAL_Surface_Handle: 0x%llx, "
+        "VP_HAL_Surface_Size: 0x%llx",
+        surface,
+        surface->osSurface,
+        surface->isResourceOwner ? 1 : 0,
+        surface->GetAllocationHandle(m_osInterface),
+        surface->osSurface->OsResource.pGmmResInfo ? surface->osSurface->OsResource.pGmmResInfo->GetSizeAllocation() : 0);
+
+        int64_t currentSize = static_cast<int64_t>(surface->osSurface->OsResource.pGmmResInfo ? surface->osSurface->OsResource.pGmmResInfo->GetSizeAllocation() : 0);
+        m_totalSize         = m_totalSize - currentSize;
+#endif 
         status = DestroySurface(surface->osSurface, flags);
     }
     else
@@ -588,6 +615,9 @@ MOS_STATUS VpAllocator::GetSurfaceInfo(VPHAL_SURFACE *surface, VPHAL_GET_SURFACE
     surface->dwWidth         = resDetails.dwWidth;
     surface->dwHeight        = resDetails.dwHeight;
     surface->dwPitch         = resDetails.dwPitch;
+    surface->dwYPitch        = resDetails.dwYPitch;
+    surface->dwUPitch        = resDetails.dwUPitch;
+    surface->dwVPitch        = resDetails.dwVPitch;
     surface->dwSlicePitch    = resDetails.dwSlicePitch;
     surface->dwDepth         = resDetails.dwDepth;
     surface->TileType        = resDetails.TileType;
@@ -863,13 +893,55 @@ MOS_STATUS VpAllocator::ReAllocateSurface(
 
     if (!surfInfoCheck(surface))
     {
-        VP_PUBLIC_ASSERTMESSAGE("Incorrect surface parameters.");
+        VP_PUBLIC_ASSERTMESSAGE("Allocated surface is not matched with allocating parameter.");
+        VP_PUBLIC_ASSERTMESSAGE("Allocated surface : format %d, compressible %d, compressionMode %d, tileType %d, bufferWidth %d, bufferHeight %d, width %d, height %d",
+            surface->osSurface->Format,
+            surface->osSurface->bCompressible,
+            surface->osSurface->CompressionMode,
+            surface->osSurface->TileType,
+            surface->bufferWidth,
+            surface->bufferHeight,
+            surface->osSurface->dwWidth,
+            surface->osSurface->dwHeight);
+        VP_PUBLIC_ASSERTMESSAGE("Parameter to allocate : format %d, compressible %d, compressionMode %d, tileType %d, width %d, height %d",
+            format,
+            compressible,
+            compressionMode,
+            defaultTileType,
+            width,
+            height);
     }
 
     MT_LOG7(MT_VP_HAL_REALLOC_SURF, MT_NORMAL, MT_VP_HAL_INTER_SURF_TYPE, surfaceName ? *((int64_t*)surfaceName) : 0,
         MT_SURF_WIDTH, width, MT_SURF_HEIGHT, height, MT_SURF_MOS_FORMAT, format, MT_SURF_TILE_MODE, surface->osSurface->TileModeGMM,
         MT_SURF_COMP_ABLE, surface->osSurface->bCompressible, MT_SURF_COMP_MODE, surface->osSurface->CompressionMode);
 
+#if !EMUL
+    MT_LOG6(MT_VP_HAL_REALLOC_SURF, MT_NORMAL,
+        MT_VP_HAL_SURF_ALLOC_PARAM_PTR, *(int64_t *)(&surface),
+        MT_VP_HAL_SURF_ALLOC_PARAM_MOS_SURF_PTR, *(int64_t *)(&surface->osSurface),
+        MT_VP_HAL_SURF_ALLOC_PARAM_IS_RES_OWNER, surface->isResourceOwner,
+        MT_VP_HAL_SURF_ALLOC_PARAM_HANDLE, static_cast<int64_t>(surface->GetAllocationHandle(m_osInterface)),
+        MT_VP_HAL_SURF_ALLOC_PARAM_SIZE, static_cast<int64_t>(surface->osSurface->OsResource.pGmmResInfo ? surface->osSurface->OsResource.pGmmResInfo->GetSizeAllocation() : 0),
+        MT_VP_HAL_SURF_ALLOC_PARAM_NAME, surfaceName ? *((int64_t *)surfaceName) : 0);
+    VP_PUBLIC_NORMALMESSAGE(
+        "VP_HAL_REALLOC_SURF. "
+        "VP_HAL_Surface: %p, "
+        "VP_HAL_OsSurface: %p, "
+        "VP_HAL_isResourceOwner: %d, "
+        "VP_HAL_Surface_Handle: 0x%llx, "
+        "VP_HAL_Surface_Size: 0x%llx, "
+        "VP_HAL_Surface_Name: %s",
+        surface,
+        surface->osSurface,
+        surface->isResourceOwner ? 1 : 0,
+        surface->GetAllocationHandle(m_osInterface),
+        surface->osSurface->OsResource.pGmmResInfo ? surface->osSurface->OsResource.pGmmResInfo->GetSizeAllocation() : 0,
+        surfaceName ? surfaceName : "");
+    int64_t currentSize  = static_cast<int64_t>(surface->osSurface->OsResource.pGmmResInfo ? surface->osSurface->OsResource.pGmmResInfo->GetSizeAllocation() : 0);
+    m_totalSize          = m_totalSize + currentSize;
+    m_peakSize           = m_peakSize > m_totalSize ? m_peakSize : m_totalSize;
+#endif
     allocated = true;
     return MOS_STATUS_SUCCESS;
 }
@@ -1363,7 +1435,7 @@ MOS_STATUS VpAllocator::SetMmcFlags(MOS_SURFACE &osSurface)
 
         osSurface.bCompressible   = true;
         osSurface.bIsCompressed   = true;
-        m_mmc->GetSurfaceMmcFormat(&osSurface, &mmcFormat);
+        VP_PUBLIC_CHK_STATUS_RETURN(m_mmc->GetSurfaceMmcFormat(&osSurface, &mmcFormat));
         osSurface.CompressionFormat = mmcFormat;
     }
     else
