@@ -186,7 +186,8 @@ enum SurfaceType
     SurfaceTypeRenderInput,
     SurfaceTypeRenderOutput,
     SurfaceTypeRenderSRInput, //Super Resolution related Surface and Buffer index Reserved
-    SurfaceTypeRenderSRBuffer = SurfaceTypeRenderSRInput + 0x100,
+    SurfaceTypeRenderSRPreCSCInput,
+    SurfaceTypeRenderSRBuffer = SurfaceTypeRenderSRPreCSCInput + 0x100,
     SurfaceTypeRenderSRMax = SurfaceTypeRenderSRBuffer + 0x100,
     SurfaceTypeAggregatedHistogram,
     SurfaceTypeFrameHistogram,
@@ -1011,6 +1012,7 @@ struct FeatureParamCsc : public FeatureParam
     {
         VPHAL_CSPACE    colorSpace      = CSpace_None;
         uint32_t        chromaSiting    = 0;
+        MOS_TILE_MODE_GMM tileMode      = MOS_TILE_4_GMM;
         bool operator == (const struct CSC_PARAMS &b)
         {
             return colorSpace == b.colorSpace && chromaSiting == b.chromaSiting;
@@ -1329,10 +1331,18 @@ public:
     virtual MOS_STATUS Update(VP_SURFACE* inputSurf, VP_SURFACE* outputSurf, SwFilterSubPipe &pipe);
     virtual MOS_STATUS SetResourceAssignmentHint(RESOURCE_ASSIGNMENT_HINT &hint)
     {
+        MT_LOG1(MT_VP_FEATURE_GRAPH_SWFILTERSTD, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_ENABLE, m_Params.bEnableSTD);
+        VP_PUBLIC_NORMALMESSAGE("STD Output Enable: %d", m_Params.bEnableSTD);
         if (m_Params.bEnableSTD)
         {
+            // isSkinScoreDumpNeededForSTDonly for STD output to internal surface and copy to STDParam.
+            // isSkinScoreOutputNeededForSTDOnly for STD output to output surface directly. It set internal
+            // SkinScore surface to VeboxCurrentOutput and external output surface to VeboxSkinScore to
+            // achieve it, instead of setting Output STD Decisions to 1.
             hint.isSkinScoreDumpNeededForSTDonly = !m_Params.STDParam.bOutputSkinScore;
             hint.isSkinScoreOutputNeededForSTDOnly = m_Params.STDParam.bOutputSkinScore;
+            MT_LOG2(MT_VP_FEATURE_GRAPH_SWFILTERSTD, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_TO_STDPARAM, hint.isSkinScoreDumpNeededForSTDonly, MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_TO_OUTPUT_SURFACE, hint.isSkinScoreOutputNeededForSTDOnly);
+            VP_PUBLIC_NORMALMESSAGE("STD Output isSkinScoreDumpNeededForSTDonly: %d, isSkinScoreOutputNeededForSTDOnly: %d", hint.isSkinScoreDumpNeededForSTDonly, hint.isSkinScoreOutputNeededForSTDOnly);
         }
 
         return MOS_STATUS_SUCCESS;
@@ -1661,7 +1671,7 @@ public:
     virtual MOS_STATUS       AddFeatureGraphRTLog()
     {
         MT_LOG4(MT_VP_FEATURE_GRAPH_SWFILTERALPHA, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_CALCULATINGALPHA, m_Params.calculatingAlpha, MT_VP_FEATURE_GRAPH_FILTER_ALPHAMODE,
-                m_Params.compAlpha ? m_Params.compAlpha->AlphaMode : -1, MT_VP_FEATURE_GRAPH_FILTER_FALPHA, m_Params.compAlpha ? (int64_t) m_Params.compAlpha->fAlpha : -1,
+                m_Params.compAlpha ? m_Params.compAlpha->AlphaMode : -1, MT_VP_FEATURE_GRAPH_FILTER_FALPHA, m_Params.compAlpha ? (int64_t) m_Params.compAlpha->fAlpha*1000 : -1,
                 MT_VP_FEATURE_GRAPH_FILTER_FEATURETYPE, GetFeatureType());
         VP_PUBLIC_NORMALMESSAGE("Feature Graph: SwFilterAlpha: calculatingAlpha %d, AlphaMode %d, fAlpha %f, FeatureType %d", m_Params.calculatingAlpha, m_Params.compAlpha ? m_Params.compAlpha->AlphaMode : -1,
                                 m_Params.compAlpha ? m_Params.compAlpha->fAlpha : -1, GetFeatureType());
