@@ -329,6 +329,7 @@ using VEBOX_CSC_PARAMS      = _VEBOX_CSC_PARAMS;
 using PVEBOX_CSC_PARAMS     = VEBOX_CSC_PARAMS *;
 
 using KERNEL_ARGS = std::vector<KRN_ARG>;
+using KERNEL_BTIS = std::map<uint32_t,uint32_t>;
 
 struct _VEBOX_UPDATE_PARAMS
 {
@@ -351,6 +352,7 @@ struct _RENDER_HDR_3DLUT_CAL_PARAMS
     uint32_t                        threadWidth;
     uint32_t                        threadHeight;
     KERNEL_ARGS                     kernelArgs;
+    void                            Init();
 };
 
 using RENDER_HDR_3DLUT_CAL_PARAMS  = _RENDER_HDR_3DLUT_CAL_PARAMS;
@@ -535,6 +537,7 @@ struct _RENDER_HDR_PARAMS
    bool                             coeffAllocated     = false;
    bool                             OETF1DLUTAllocated = false;
    bool                             Cri3DLUTAllocated  = false;
+   PVPHAL_BLENDING_PARAMS           pBlendingParams    = nullptr;              //!< Blending parameters
 };
 using RENDER_HDR_PARAMS  = _RENDER_HDR_PARAMS;
 using PRENDER_HDR_PARAMS = RENDER_HDR_PARAMS *;
