@@ -141,6 +141,15 @@ VpCmdPacket *PacketFactory::CreateRenderPacket()
     VpCmdPacket *p = m_vpPlatformInterface ? m_vpPlatformInterface->CreateRenderPacket(m_pTask, m_pHwInterface, m_pAllocator, m_pMmc, m_kernelSet) : nullptr;
     if (p)
     {
+        MOS_STATUS status = MOS_STATUS_SUCCESS;
+        
+        status = p->Init();
+        
+        if (MOS_STATUS_SUCCESS != status)
+        {
+            VP_PUBLIC_ASSERTMESSAGE("Render CMD Packet Init Fail");
+        }
+
         p->SetPacketSharedContext(m_packetSharedContext);
     }
     return p;
@@ -211,7 +220,6 @@ MOS_STATUS PacketPipe::SetOutputPipeMode(EngineType engineType)
     default:
         m_outputPipeMode = VPHAL_OUTPUT_PIPE_MODE_INVALID;
         VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
-        break;
     }
 
     return MOS_STATUS_SUCCESS;
@@ -259,6 +267,8 @@ MOS_STATUS PacketPipe::Execute(MediaStatusReport *statusReport, MediaScalability
 {
     VP_FUNC_CALL();
 
+    VP_PUBLIC_NORMALMESSAGE("PacketPipe %p in execute.", this);
+
     // PrePare Packet in case any packet resources shared
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
     for (std::vector<VpCmdPacket*>::reverse_iterator it = m_Pipe.rbegin(); it != m_Pipe.rend(); ++it)
@@ -276,6 +286,15 @@ MOS_STATUS PacketPipe::Execute(MediaStatusReport *statusReport, MediaScalability
         prop.immediateSubmit = true;
         prop.stateProperty.statusReport = statusReport;
 
+        bool isSkip = false;
+        // Checking if extra processing is needed.
+        isSkip      = pPacket->ExtraProcessing();
+        if (isSkip)
+        {
+            VP_PUBLIC_NORMALMESSAGE("Skip this packet.");
+            continue;
+        }
+
         MediaTask *pTask = pPacket->GetActiveTask();
         VP_PUBLIC_CHK_NULL_RETURN(pTask);
 
@@ -286,27 +305,26 @@ MOS_STATUS PacketPipe::Execute(MediaStatusReport *statusReport, MediaScalability
         VP_PUBLIC_CHK_STATUS_RETURN(pTask->AddPacket(&prop));
         if (prop.immediateSubmit)
         {
+            VP_PUBLIC_NORMALMESSAGE("Execute Packet %p.", pPacket);
             VP_PUBLIC_CHK_STATUS_RETURN(pTask->Submit(true, scalability, nullptr));
         }
 
-#if (_DEBUG || _RELEASE_INTERNAL)
+#if USE_MEDIA_DEBUG_TOOL
         for (auto& handle : pPacket->GetSurfSetting().surfGroup)
         {
             if(handle.first && handle.second)
             {
                 VP_SURFACE_DUMP(m_PacketFactory.m_debugInterface,
-                handle.second,
-                0,
-                handle.first,
-                VPHAL_DUMP_TYPE_POST_COMP);
+                    handle.second,
+                    0,
+                    handle.first,
+                    VPHAL_DUMP_TYPE_POST_COMP,
+                    VPHAL_SURF_DUMP_DDI_VP_BLT);
             }
         }
 #endif
     }
 
-#if (_DEBUG || _RELEASE_INTERNAL)
-finish:
-#endif
     return eStatus;
 }
 
