@@ -37,10 +37,6 @@
 #include "hal_oca_interface_next.h"
 #include "renderhal_platform_interface.h"
 
-#define ENLARGE_KERNEL_COUNT RENDERHAL_KERNEL_COUNT * 3
-#define ENLARGE_KERNEL_HEAP RENDERHAL_KERNEL_HEAP * 3
-#define ENLARGE_CURBE_SIZE RENDERHAL_CURBE_SIZE * 16
-
 namespace vp
 {
 static inline RENDERHAL_SURFACE_TYPE InitRenderHalSurfType(VPHAL_SURFACE_TYPE vpSurfType)
@@ -80,6 +76,7 @@ VpRenderCmdPacket::VpRenderCmdPacket(MediaTask *task, PVP_MHWINTERFACE hwInterfa
     {
         bool computeContextEnabled = m_hwInterface->m_userFeatureControl->IsComputeContextEnabled();
         m_PacketId = computeContextEnabled ? VP_PIPELINE_PACKET_COMPUTE : VP_PIPELINE_PACKET_RENDER;
+        m_vpUserFeatureControl     = m_hwInterface->m_userFeatureControl;
     }
     else
     {
@@ -96,13 +93,15 @@ VpRenderCmdPacket::~VpRenderCmdPacket()
             MOS_FreeMemAndSetNull(samplerstate.second.Avs.pMhwSamplerAvsTableParam);
         }
     }
+
     MOS_Delete(m_surfMemCacheCtl);
-    MOS_Delete(m_enlargedStateHeapSetting);
 }
 
 MOS_STATUS VpRenderCmdPacket::Init()
 {
-    return RenderCmdPacket::Init();
+    VP_RENDER_CHK_STATUS_RETURN(RenderCmdPacket::Init());
+
+    return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS VpRenderCmdPacket::LoadKernel()
@@ -192,14 +191,14 @@ MOS_STATUS VpRenderCmdPacket::Prepare()
         *m_surfMemCacheCtl,
         m_packetSharedContext));
 
-    if (m_submissionMode == MULTI_KERNELS_WITH_MULTI_MEDIA_STATES)
+    if (m_submissionMode == MULTI_KERNELS_MULTI_MEDIA_STATES || m_submissionMode == SINGLE_KERNEL_ONLY)
     {
         m_kernelRenderData.clear();
 
-        if (m_bindingtableMode == MULTI_KERNELS_WITH_MULTI_BINDINGTABLES)
+        if (m_submissionMode == MULTI_KERNELS_MULTI_MEDIA_STATES)
         {
             bool bAllocated = false;
-            VP_RENDER_CHK_STATUS_RETURN(m_renderHal->pfnReAllocateStateHeapsforAdvFeature(m_renderHal, bAllocated));
+            VP_RENDER_CHK_STATUS_RETURN(m_renderHal->pfnReAllocateStateHeapsforAdvFeatureWithSshEnlarged(m_renderHal, bAllocated));
 
             if (bAllocated && m_renderHal->pStateHeap)
             {
@@ -232,7 +231,7 @@ MOS_STATUS VpRenderCmdPacket::Prepare()
             // reset render Data for current kernel
             MOS_ZeroMemory(&m_renderData, sizeof(KERNEL_PACKET_RENDER_DATA));
 
-            if (m_bindingtableMode == MULTI_KERNELS_WITH_MULTI_BINDINGTABLES)
+            if (m_submissionMode != SINGLE_KERNEL_ONLY)
             {
                 m_isMultiBindingTables = true;
             }
@@ -266,39 +265,35 @@ MOS_STATUS VpRenderCmdPacket::Prepare()
             m_kernelRenderData.insert(std::make_pair(it->first, m_renderData));
         }
     }
-    else if (m_submissionMode == MULTI_KERNELS_WITH_ONE_MEDIA_STATE)
+    else if (m_submissionMode == MULTI_KERNELS_SINGLE_MEDIA_STATE)
     {
-        if (m_bindingtableMode == MULTI_KERNELS_WITH_MULTI_BINDINGTABLES)
+        bool bAllocated = false;
+
+        VP_RENDER_CHK_STATUS_RETURN(m_renderHal->pfnReAllocateStateHeapsforAdvFeatureWithAllHeapsEnlarged(m_renderHal, bAllocated));
+        if (bAllocated && m_renderHal->pStateHeap)
         {
-            bool bAllocated = false;
-            if (m_enlargedStateHeapSetting == nullptr)
-            {
-                m_enlargedStateHeapSetting                 = MOS_New(RENDERHAL_ENLARGE_PARAMS);
-                m_enlargedStateHeapSetting->iBindingTables = RENDERHAL_SSH_BINDING_TABLES_MAX;
-                m_enlargedStateHeapSetting->iSurfaceStates = RENDERHAL_SSH_SURFACE_STATES_MAX;
-                m_enlargedStateHeapSetting->iKernelCount   = ENLARGE_KERNEL_COUNT;
-                m_enlargedStateHeapSetting->iKernelHeapSize = ENLARGE_KERNEL_HEAP;
-                m_enlargedStateHeapSetting->iCurbeSize      = ENLARGE_CURBE_SIZE;
-            }
-
-            VP_RENDER_CHK_STATUS_RETURN(m_renderHal->pfnReAllocateStateHeapsforAdvFeatureWithSetting(m_renderHal, m_enlargedStateHeapSetting, bAllocated));
-            if (bAllocated && m_renderHal->pStateHeap)
-            {
-                MHW_STATE_BASE_ADDR_PARAMS *pStateBaseParams = &m_renderHal->StateBaseAddressParams;
-                pStateBaseParams->presGeneralState           = &m_renderHal->pStateHeap->GshOsResource;
-                pStateBaseParams->dwGeneralStateSize         = m_renderHal->pStateHeap->dwSizeGSH;
-                pStateBaseParams->presDynamicState           = &m_renderHal->pStateHeap->GshOsResource;
-                pStateBaseParams->dwDynamicStateSize         = m_renderHal->pStateHeap->dwSizeGSH;
-                pStateBaseParams->bDynamicStateRenderTarget  = false;
-                pStateBaseParams->presIndirectObjectBuffer   = &m_renderHal->pStateHeap->GshOsResource;
-                pStateBaseParams->dwIndirectObjectBufferSize = m_renderHal->pStateHeap->dwSizeGSH;
-                pStateBaseParams->presInstructionBuffer      = &m_renderHal->pStateHeap->IshOsResource;
-                pStateBaseParams->dwInstructionBufferSize    = m_renderHal->pStateHeap->dwSizeISH;
-            }
-
+            MHW_STATE_BASE_ADDR_PARAMS *pStateBaseParams = &m_renderHal->StateBaseAddressParams;
+            pStateBaseParams->presGeneralState           = &m_renderHal->pStateHeap->GshOsResource;
+            pStateBaseParams->dwGeneralStateSize         = m_renderHal->pStateHeap->dwSizeGSH;
+            pStateBaseParams->presDynamicState           = &m_renderHal->pStateHeap->GshOsResource;
+            pStateBaseParams->dwDynamicStateSize         = m_renderHal->pStateHeap->dwSizeGSH;
+            pStateBaseParams->bDynamicStateRenderTarget  = false;
+            pStateBaseParams->presIndirectObjectBuffer   = &m_renderHal->pStateHeap->GshOsResource;
+            pStateBaseParams->dwIndirectObjectBufferSize = m_renderHal->pStateHeap->dwSizeGSH;
+            pStateBaseParams->presInstructionBuffer      = &m_renderHal->pStateHeap->IshOsResource;
+            pStateBaseParams->dwInstructionBufferSize    = m_renderHal->pStateHeap->dwSizeISH;
+            uint32_t heapMocs                            = m_renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(MOS_HW_RESOURCE_USAGE_VP_INPUT_PICTURE_RENDER,
+                                                             m_renderHal->pOsInterface->pfnGetGmmClientContext(m_renderHal->pOsInterface)).DwordValue;
+            pStateBaseParams->mocs4SurfaceState         = heapMocs;
+            pStateBaseParams->mocs4GeneralState         = heapMocs;
+            pStateBaseParams->mocs4DynamicState         = heapMocs;
+            pStateBaseParams->mocs4InstructionCache     = heapMocs;
+            pStateBaseParams->mocs4IndirectObjectBuffer = heapMocs;
+            pStateBaseParams->mocs4StatelessDataport    = heapMocs;
         }
+
         MOS_ZeroMemory(&m_renderData, sizeof(KERNEL_PACKET_RENDER_DATA));
-        m_isMultiBindingTables = m_bindingtableMode == MULTI_KERNELS_WITH_MULTI_BINDINGTABLES ? true : false;
+        m_isMultiBindingTables       = true;
         m_isMultiKernelOneMediaState = true;
         VP_RENDER_CHK_STATUS_RETURN(RenderEngineSetup());
 
@@ -408,20 +403,19 @@ MOS_STATUS VpRenderCmdPacket::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8_t
         VP_RENDER_ASSERTMESSAGE("No Kernel Object Creation");
         return MOS_STATUS_NULL_POINTER;
     }
-    if (m_submissionMode == MULTI_KERNELS_WITH_MULTI_MEDIA_STATES   &&
-        m_bindingtableMode == MULTI_KERNELS_WITH_MULTI_BINDINGTABLES)
+    if (m_submissionMode == MULTI_KERNELS_MULTI_MEDIA_STATES)
     {
         VP_RENDER_CHK_STATUS_RETURN(SetupMediaWalker());
 
         VP_RENDER_CHK_STATUS_RETURN(SubmitWithMultiKernel(commandBuffer, packetPhase));
     }
-    else if (m_submissionMode == MULTI_KERNELS_WITH_MULTI_MEDIA_STATES)
+    else if (m_submissionMode == SINGLE_KERNEL_ONLY)
     {
         VP_RENDER_CHK_STATUS_RETURN(SetupMediaWalker());
 
         VP_RENDER_CHK_STATUS_RETURN(RenderCmdPacket::Submit(commandBuffer, packetPhase));
     }
-    else if (m_submissionMode == MULTI_KERNELS_WITH_ONE_MEDIA_STATE)
+    else if (m_submissionMode == MULTI_KERNELS_SINGLE_MEDIA_STATE)
     {
         VP_RENDER_CHK_STATUS_RETURN(SubmitWithMultiKernel(commandBuffer, packetPhase));
     }
@@ -737,16 +731,25 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
 
             if (kernelSurfaceParam->surfaceOverwriteParams.bindedKernel && !kernelSurfaceParam->surfaceOverwriteParams.bufferResource)
             {
+                auto bindingMap = m_kernel->GetSurfaceBindingIndex(type);
+                if (bindingMap.empty())
+                {
+                    VP_RENDER_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+                }
                 VP_RENDER_CHK_STATUS_RETURN(SetSurfaceForHwAccess(
                     &renderHalSurface.OsSurface,
                     &renderHalSurface,
                     &renderSurfaceParams,
-                    kernelSurfaceParam->surfaceOverwriteParams.bindIndex,
+                    bindingMap,
                     bWrite,
+                    kernelSurfaceParam->iCapcityOfSurfaceEntry,
                     kernelSurfaceParam->surfaceEntries,
                     kernelSurfaceParam->sizeOfSurfaceEntries));
-
-                index = kernelSurfaceParam->surfaceOverwriteParams.bindIndex;
+                for (uint32_t const& bti : bindingMap)
+                {
+                    VP_RENDER_NORMALMESSAGE("Using Binded Index Surface. KernelID %d, SurfType %d, bti %d", m_kernel->GetKernelId(), type, bti);
+                }
+                
             }
             else
             {
@@ -754,12 +757,21 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                      kernelSurfaceParam->surfaceOverwriteParams.bufferResource        &&
                      kernelSurfaceParam->surfaceOverwriteParams.bindedKernel))
                 {
-                    index = SetBufferForHwAccess(
+                    auto bindingMap = m_kernel->GetSurfaceBindingIndex(type);
+                    if (bindingMap.empty())
+                    {
+                        VP_RENDER_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+                    }
+                    VP_RENDER_CHK_STATUS_RETURN(SetBufferForHwAccess(
                         &renderHalSurface.OsSurface,
                         &renderHalSurface,
                         &renderSurfaceParams,
-                        kernelSurfaceParam->surfaceOverwriteParams.bindIndex,
-                        bWrite);
+                        bindingMap,
+                        bWrite));
+                    for (uint32_t const &bti : bindingMap)
+                    {
+                        VP_RENDER_NORMALMESSAGE("Using Binded Index Buffer. KernelID %d, SurfType %d, bti %d", m_kernel->GetKernelId(), type, bti);
+                    }
                 }
                 else if ((kernelSurfaceParam->surfaceOverwriteParams.updatedSurfaceParams &&
                      kernelSurfaceParam->surfaceOverwriteParams.bufferResource            &&
@@ -773,18 +785,20 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderHalSurface,
                         &renderSurfaceParams,
                         bWrite);
+                    VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCurbeBindingIndex(type, index));
+                    VP_RENDER_NORMALMESSAGE("Using UnBinded Index Buffer. KernelID %d, SurfType %d, bti %d", m_kernel->GetKernelId(), type, index);
                 }
                 else
                 {
-                    VP_RENDER_NORMALMESSAGE("If 1D buffer overwrite to 2D for use, it will go SetSurfaceForHwAccess()");
                     index = SetSurfaceForHwAccess(
                         &renderHalSurface.OsSurface,
                         &renderHalSurface,
                         &renderSurfaceParams,
                         bWrite);
+                    VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCurbeBindingIndex(type, index));
+                    VP_RENDER_NORMALMESSAGE("Using UnBinded Index Surface. KernelID %d, SurfType %d, bti %d. If 1D buffer overwrite to 2D for use, it will go SetSurfaceForHwAccess()", m_kernel->GetKernelId(), type, index);
                 }
             }
-            VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCurbeBindingIndex(type, index));
         }
         VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCompParams());
     }
@@ -854,13 +868,14 @@ bool VpRenderCmdPacket::IsRenderUncompressedWriteNeeded(PVP_SURFACE VpSurface)
     }
 
     byteInpixel = VpSurface->osSurface->OsResource.pGmmResInfo->GetBitsPerPixel() >> 3;
-#endif // !EMUL
 
     if (byteInpixel == 0)
     {
         VP_RENDER_NORMALMESSAGE("surface format is not a valid format for Render");
         return false;
     }
+#endif // !EMUL
+
     uint32_t writeAlignInWidth  = 32 / byteInpixel;
     uint32_t writeAlignInHeight = 8;
     
@@ -994,6 +1009,11 @@ void VpRenderCmdPacket::OcaDumpDbgInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEX
     }
     // Add vphal param to log.
     HalOcaInterfaceNext::DumpVphalParam(cmdBuffer, (MOS_CONTEXT_HANDLE)&mosContext, m_renderHal->pVphalOcaDumper);
+
+    if (m_vpUserFeatureControl)
+    {
+        HalOcaInterfaceNext::DumpVpUserFeautreControlInfo(cmdBuffer, &mosContext, m_vpUserFeatureControl->GetOcaFeautreControlInfo());
+    }
 }
 
 MOS_STATUS VpRenderCmdPacket::SetMediaFrameTracking(RENDERHAL_GENERIC_PROLOG_PARAMS &genericPrologParams)
@@ -1697,6 +1717,10 @@ MOS_STATUS VpRenderCmdPacket::SubmitWithMultiKernel(MOS_COMMAND_BUFFER *commandB
         RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pRenderHalPltInterface->AddMediaStateFlush(m_renderHal, commandBuffer, &FlushParam));
     }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    RENDER_PACKET_CHK_STATUS_RETURN(StallBatchBuffer(commandBuffer));
+#endif
+
     HalOcaInterfaceNext::On1stLevelBBEnd(*commandBuffer, *pOsInterface);
 
     if (pBatchBuffer)
@@ -1792,7 +1816,7 @@ MOS_STATUS VpRenderCmdPacket::SendMediaStates(
     MHW_MI_LOAD_REGISTER_IMM_PARAMS loadRegisterImmParams = {};
     PMHW_MI_MMIOREGISTERS           pMmioRegisters        = nullptr;
     MOS_OCA_BUFFER_HANDLE           hOcaBuf               = 0;
-
+    bool                            flushL1               = false;
     //---------------------------------------
     MHW_RENDERHAL_CHK_NULL(pRenderHal);
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pStateHeap);
@@ -1887,6 +1911,11 @@ MOS_STATUS VpRenderCmdPacket::SendMediaStates(
             pipeCtlParams.dwFlushMode             = MHW_FLUSH_CUSTOM;
             pipeCtlParams.bInvalidateTextureCache = true;
             pipeCtlParams.bFlushRenderTargetCache = true;
+            if (flushL1)
+            {   //Flush L1 cache after consumer walker when there is a producer-consumer relationship walker.
+                pipeCtlParams.bUnTypedDataPortCacheFlush = true;
+                pipeCtlParams.bHdcPipelineFlush          = true;
+            }
             MHW_RENDERHAL_CHK_STATUS(pRenderHal->pRenderHalPltInterface->AddMiPipeControl(pRenderHal,
                 pCmdBuffer,
                 &pipeCtlParams));
@@ -1910,14 +1939,14 @@ MOS_STATUS VpRenderCmdPacket::SendMediaStates(
 
             MHW_RENDERHAL_CHK_STATUS(PrepareComputeWalkerParams(it->second.walkerParam, m_gpgpuWalkerParams));
 
-            if (m_submissionMode == MULTI_KERNELS_WITH_MULTI_MEDIA_STATES && m_bindingtableMode == MULTI_KERNELS_WITH_MULTI_BINDINGTABLES)
+            if (m_submissionMode == MULTI_KERNELS_MULTI_MEDIA_STATES)
             {
                 pRenderHal->pStateHeap->pCurMediaState = it->second.mediaState;
                 MHW_RENDERHAL_CHK_NULL(pRenderHal->pStateHeap->pCurMediaState);
                 pRenderHal->iKernelAllocationID        = it->second.kernelAllocationID;
                 pRenderHal->pStateHeap->pCurMediaState->bBusy = true;
             }
-            else if (m_submissionMode == MULTI_KERNELS_WITH_ONE_MEDIA_STATE)
+            else if (m_submissionMode == MULTI_KERNELS_SINGLE_MEDIA_STATE)
             {
                 pRenderHal->iKernelAllocationID = it->second.kernelAllocationID;
             }
@@ -1927,7 +1956,8 @@ MOS_STATUS VpRenderCmdPacket::SendMediaStates(
                 pCmdBuffer,
                 &m_gpgpuWalkerParams));
 
-             PrintWalkerParas(m_mediaWalkerParams);
+            flushL1 = it->second.walkerParam.bFlushL1;
+            PrintWalkerParas(m_mediaWalkerParams);
         }
         else
         {
@@ -1964,9 +1994,8 @@ MOS_STATUS VpRenderCmdPacket::SetFcParams(PRENDER_FC_PARAMS params)
     KERNEL_PARAMS kernelParams = {};
     kernelParams.kernelId      = params->kernelId;
     m_renderKernelParams.push_back(kernelParams);
-    m_bindingtableMode = MULTI_KERNELS_WITH_ONE_BINDINGTABLE;
     m_isMultiBindingTables = false;
-    m_submissionMode       = MULTI_KERNELS_WITH_MULTI_MEDIA_STATES;
+    m_submissionMode       = SINGLE_KERNEL_ONLY;
     return MOS_STATUS_SUCCESS;
 }
 
