@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -131,6 +131,12 @@ void VpFeatureReport::SetConfigValues(
     configValues->dwCurrentCompositionMode = m_features.compositionMode;
     configValues->dwCurrentScdMode         = m_features.diScdMode;
 
+    // Report Vebox Scalability
+    configValues->dwCurrentVeboxScalability = m_features.VeboxScalability;
+
+    // Report VP Apogeios
+    configValues->dwCurrentVPApogeios       = m_features.VPApogeios;
+
     VP_PUBLIC_NORMALMESSAGE(
         "VP Feature Report: \
         OutputPipeMode %d, \
