@@ -28,6 +28,10 @@
 #ifndef __VP_PIPELINE_ADAPTER_BASE_H__
 #define __VP_PIPELINE_ADAPTER_BASE_H__
 #include "vp_base.h"
+#include "mhw_vebox_itf.h"
+#include "vp_utils.h"
+#include "mhw_sfc_itf.h"
+#include "mhw_render_itf.h"
 
 //!
 //! \brief Deinterlace Mode enum
@@ -70,7 +74,8 @@ public:
     //!
     VpPipelineAdapterBase(
         vp::VpPlatformInterface &vpPlatformInterface,
-        MOS_STATUS &eStatus);
+        MOS_STATUS &eStatus,
+        bool       clearViewMode = false);
 
     virtual MOS_STATUS GetVpMhwInterface(
         VP_MHWINTERFACE &vpMhwinterface);
@@ -116,7 +121,7 @@ public:
     virtual MOS_STATUS GetStatusReportEntryLength(
         uint32_t                         *puiLength);
 
-    virtual VpFeatureReport *GetRenderFeatureReport() = 0;
+    virtual VphalFeatureReport *GetRenderFeatureReport() = 0;
 
     //!
     //! \brief    VpPipelineAdapterBase Destuctor
@@ -145,44 +150,6 @@ public:
         return m_vprenderHal;
     }
 
-    void SetMhwVeboxInterface(MhwVeboxInterface *veboxInterface)
-    {
-        MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
-        if (veboxInterface == nullptr)
-        {
-            return;
-        }
-
-        if (m_veboxInterface != nullptr)
-        {
-            eStatus = m_veboxInterface->DestroyHeap();
-            MOS_Delete(m_veboxInterface);
-            m_veboxInterface = nullptr;
-            if (MOS_FAILED(eStatus))
-            {
-                VP_PUBLIC_ASSERTMESSAGE("Failed to destroy Vebox Interface, eStatus:%d.\n", eStatus);
-            }
-        }
-
-        m_veboxInterface = veboxInterface;
-    }
-
-    void SetMhwSfcInterface(MhwSfcInterface *sfcInterface)
-    {
-        if (sfcInterface == nullptr)
-        {
-            return;
-        }
-
-        if (m_sfcInterface != nullptr)
-        {
-            MOS_Delete(m_sfcInterface);
-            m_sfcInterface = nullptr;
-        }
-
-        m_sfcInterface = sfcInterface;
-    }
-
     void SetMhwVeboxItf(std::shared_ptr<mhw::vebox::Itf> veboxItf)
     {
         MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
@@ -258,9 +225,7 @@ protected:
     // States
     PMOS_INTERFACE       m_osInterface   = nullptr;
     PRENDERHAL_INTERFACE m_vprenderHal   = nullptr;
-    PMHW_VEBOX_INTERFACE m_veboxInterface = nullptr;
     MhwCpInterface *     m_cpInterface    = nullptr;
-    PMHW_SFC_INTERFACE   m_sfcInterface   = nullptr;
     std::shared_ptr<mhw::vebox::Itf>  m_veboxItf  = nullptr;
     std::shared_ptr<mhw::sfc::Itf>    m_sfcItf    = nullptr;
     std::shared_ptr<mhw::mi::Itf>     m_miItf     = nullptr;
@@ -271,7 +236,9 @@ protected:
     vp::VpPlatformInterface &m_vpPlatformInterface;  //!< vp platform interface. Should be destroyed during deconstruction.
     MediaUserSettingSharedPtr m_userSettingPtr = nullptr;  //!< usersettingInstance
 
-MEDIA_CLASS_DEFINE_END(VpPipelineAdapterBase)
+    // Perf Optimize for ClearVideoView DDI
+    bool m_clearVideoViewMode = false;
+    MEDIA_CLASS_DEFINE_END(VpPipelineAdapterBase)
 };
 
 #endif  // __VP_PIPELINE_ADAPTER_BASE_H__
