@@ -794,6 +794,7 @@ VAStatus DdiDecodeFunctions::MapBufferInternal(
                 *pbuf = (void *)((uint8_t*)(bufMgr->Codec_Param.Codec_Param_VP9.pVASliceParaBufVP9) + buf->uiOffset);
                 break;
             case CODECHAL_DECODE_MODE_AV1VLD:
+            case CODECHAL_DECODE_MODE_RESERVED0:
                 *pbuf = (void *)((uint8_t*)(bufMgr->pCodecSlcParamReserved) + buf->uiOffset);
                 break;
             default:
@@ -1046,46 +1047,57 @@ VAStatus DdiDecodeFunctions::StatusReport(
     if (surface->curStatusReportQueryState == DDI_MEDIA_STATUS_REPORT_QUERY_STATE_PENDING) // TODO: Use soltlet class
     {
         uint32_t uNumCompletedReport = decoder->GetCompletedReport();
-        DDI_CODEC_CHK_CONDITION((uNumCompletedReport == 0), "No report available at all", VA_STATUS_ERROR_OPERATION_FAILED);
-
-        for (uint32_t i = 0; i < uNumCompletedReport; i++)
+        if (uNumCompletedReport != 0)
         {
-            DecodeStatusReportData tempNewReport;
-            MOS_ZeroMemory(&tempNewReport, sizeof(CodechalDecodeStatusReport));
-            MOS_STATUS eStatus = decoder->GetStatusReport(&tempNewReport, 1);
-            DDI_CODEC_CHK_CONDITION(MOS_STATUS_SUCCESS != eStatus, "Get status report fail", VA_STATUS_ERROR_OPERATION_FAILED);
+            DDI_CODEC_CHK_CONDITION((uNumCompletedReport == 0), "No report available at all", VA_STATUS_ERROR_OPERATION_FAILED);
 
-            MOS_LINUX_BO *bo = tempNewReport.currDecodedPicRes.bo;
-
-            if ((tempNewReport.codecStatus == CODECHAL_STATUS_SUCCESSFUL) || (tempNewReport.codecStatus == CODECHAL_STATUS_ERROR) || (tempNewReport.codecStatus == CODECHAL_STATUS_INCOMPLETE))
+            for (uint32_t i = 0; i < uNumCompletedReport; i++)
             {
-                PDDI_MEDIA_SURFACE_HEAP_ELEMENT mediaSurfaceHeapElmt = (PDDI_MEDIA_SURFACE_HEAP_ELEMENT)mediaCtx->pSurfaceHeap->pHeapBase;
+                DecodeStatusReportData tempNewReport;
+                MOS_ZeroMemory(&tempNewReport, sizeof(CodechalDecodeStatusReport));
+                MOS_STATUS eStatus = decoder->GetStatusReport(&tempNewReport, 1);
+                DDI_CODEC_CHK_CONDITION(MOS_STATUS_SUCCESS != eStatus, "Get status report fail", VA_STATUS_ERROR_OPERATION_FAILED);
 
-                uint32_t j = 0;
-                for (j = 0; j < mediaCtx->pSurfaceHeap->uiAllocatedHeapElements; j++, mediaSurfaceHeapElmt++)
+                MOS_LINUX_BO *bo = tempNewReport.currDecodedPicRes.bo;
+
+                if ((tempNewReport.codecStatus == CODECHAL_STATUS_SUCCESSFUL)   ||
+                    (tempNewReport.codecStatus == CODECHAL_STATUS_ERROR)        ||
+                    (tempNewReport.codecStatus == CODECHAL_STATUS_RESET)        ||
+                    (tempNewReport.codecStatus == CODECHAL_STATUS_INCOMPLETE))
                 {
-                    if (mediaSurfaceHeapElmt != nullptr &&
-                        mediaSurfaceHeapElmt->pSurface != nullptr &&
-                        bo == mediaSurfaceHeapElmt->pSurface->bo)
+                    PDDI_MEDIA_SURFACE_HEAP_ELEMENT mediaSurfaceHeapElmt = (PDDI_MEDIA_SURFACE_HEAP_ELEMENT)mediaCtx->pSurfaceHeap->pHeapBase;
+
+                    uint32_t j = 0;
+                    for (j = 0; j < mediaCtx->pSurfaceHeap->uiAllocatedHeapElements && mediaSurfaceHeapElmt != nullptr; j++, mediaSurfaceHeapElmt++)
                     {
-                        mediaSurfaceHeapElmt->pSurface->curStatusReport.decode.status = (uint32_t)tempNewReport.codecStatus;
-                        mediaSurfaceHeapElmt->pSurface->curStatusReport.decode.errMbNum = (uint32_t)tempNewReport.numMbsAffected;
-                        mediaSurfaceHeapElmt->pSurface->curStatusReport.decode.crcValue = (uint32_t)tempNewReport.frameCrc;
-                        mediaSurfaceHeapElmt->pSurface->curStatusReportQueryState = DDI_MEDIA_STATUS_REPORT_QUERY_STATE_COMPLETED;
-                        break;
+                        if (mediaSurfaceHeapElmt->pSurface != nullptr && bo == mediaSurfaceHeapElmt->pSurface->bo)
+                        {
+                            mediaSurfaceHeapElmt->pSurface->curStatusReport.decode.status = (uint32_t)tempNewReport.codecStatus;
+                            mediaSurfaceHeapElmt->pSurface->curStatusReport.decode.errMbNum = (uint32_t)tempNewReport.numMbsAffected;
+                            mediaSurfaceHeapElmt->pSurface->curStatusReport.decode.crcValue = (uint32_t)tempNewReport.frameCrc;
+                            mediaSurfaceHeapElmt->pSurface->curStatusReportQueryState = DDI_MEDIA_STATUS_REPORT_QUERY_STATE_COMPLETED;
+                            break;
+                        }
+                    }
+
+                    if (j == mediaCtx->pSurfaceHeap->uiAllocatedHeapElements)
+                    {
+                        return VA_STATUS_ERROR_OPERATION_FAILED;
                     }
                 }
-
-                if (j == mediaCtx->pSurfaceHeap->uiAllocatedHeapElements)
+                else
                 {
+                    // return failed if queried INCOMPLETE or UNAVAILABLE report.
                     return VA_STATUS_ERROR_OPERATION_FAILED;
                 }
             }
-            else
-            {
-                // return failed if queried INCOMPLETE or UNAVAILABLE report.
-                return VA_STATUS_ERROR_OPERATION_FAILED;
-            }
+        }
+        // The surface is not busy in HW, but uNumCompletedReport is 0, treat as engine reset 
+        else
+        {
+            surface->curStatusReport.decode.status = CODECHAL_STATUS_INCOMPLETE;
+            surface->curStatusReportQueryState = DDI_MEDIA_STATUS_REPORT_QUERY_STATE_COMPLETED;
+            DDI_ASSERTMESSAGE("No report available at all! Engine reset may have occured.");
         }
     }
 
@@ -1106,7 +1118,9 @@ VAStatus DdiDecodeFunctions::StatusReport(
         {
             return VA_STATUS_ERROR_DECODING_ERROR;
         }
-        else if (surface->curStatusReport.decode.status == CODECHAL_STATUS_INCOMPLETE || surface->curStatusReport.decode.status == CODECHAL_STATUS_UNAVAILABLE)
+        else if (surface->curStatusReport.decode.status == CODECHAL_STATUS_INCOMPLETE   ||
+                 surface->curStatusReport.decode.status == CODECHAL_STATUS_RESET        ||
+                 surface->curStatusReport.decode.status == CODECHAL_STATUS_UNAVAILABLE)
         {
             return mediaCtx->bMediaResetEnable ? VA_STATUS_SUCCESS : VA_STATUS_ERROR_HW_BUSY;
         }
@@ -1148,18 +1162,38 @@ VAStatus DdiDecodeFunctions::QuerySurfaceError(
     MosUtilities::MosLockMutex(&mediaCtx->SurfaceMutex);
     if (surface->curStatusReportQueryState == DDI_MEDIA_STATUS_REPORT_QUERY_STATE_COMPLETED)
     {
-        if (errorStatus != -1 && surface->curCtxType == DDI_MEDIA_CONTEXT_TYPE_DECODER &&
-            surface->curStatusReport.decode.status == CODECHAL_STATUS_ERROR)
+        if (errorStatus != -1 && surface->curCtxType == DDI_MEDIA_CONTEXT_TYPE_DECODER)
         {
-            surfaceErrors[1].status            = -1;
-            surfaceErrors[0].status            = 2;
-            surfaceErrors[0].start_mb          = 0;
-            surfaceErrors[0].end_mb            = 0;
-            surfaceErrors[0].num_mb            = surface->curStatusReport.decode.errMbNum;
-            surfaceErrors[0].decode_error_type = VADecodeMBError;
-            *errorInfo = surfaceErrors;
-            MosUtilities::MosUnlockMutex(&mediaCtx->SurfaceMutex);
-            return VA_STATUS_SUCCESS;
+            if(surface->curStatusReport.decode.status == CODECHAL_STATUS_ERROR  ||
+               surface->curStatusReport.decode.status == CODECHAL_STATUS_RESET)
+            {
+                surfaceErrors[1].status            = -1;
+                surfaceErrors[0].status            = 1;
+                surfaceErrors[0].start_mb          = 0;
+                surfaceErrors[0].end_mb            = 0;
+                surfaceErrors[0].num_mb            = surface->curStatusReport.decode.errMbNum;
+#if VA_CHECK_VERSION(1, 20, 0)
+                surfaceErrors[0].decode_error_type = (surface->curStatusReport.decode.status == CODECHAL_STATUS_RESET) ? VADecodeReset : VADecodeMBError;
+#else
+                surfaceErrors[0].decode_error_type = VADecodeMBError;
+#endif
+                *errorInfo = surfaceErrors;
+                MosUtilities::MosUnlockMutex(&mediaCtx->SurfaceMutex);
+                return VA_STATUS_SUCCESS;
+            }
+#if VA_CHECK_VERSION(1, 20, 0)
+            else if (surface->curStatusReport.decode.status == CODECHAL_STATUS_INCOMPLETE  ||
+                     surface->curStatusReport.decode.status == CODECHAL_STATUS_UNAVAILABLE)
+            {
+                MOS_ZeroMemory(&surfaceErrors[0], sizeof(VASurfaceDecodeMBErrors));
+                surfaceErrors[1].status            = -1;
+                surfaceErrors[0].status            = 1;
+                surfaceErrors[0].decode_error_type = VADecodeReset;
+                *errorInfo                         = surfaceErrors;
+                MosUtilities::MosUnlockMutex(&mediaCtx->SurfaceMutex);
+                return VA_STATUS_SUCCESS;
+            }
+#endif
         }
 
         if (errorStatus == -1 && surface->curCtxType == DDI_MEDIA_CONTEXT_TYPE_DECODER)
@@ -1216,7 +1250,7 @@ int32_t DdiDecodeFunctions::GetDisplayInfo(VADriverContextP ctx)
     vsinfo.yres = 0;
 
     fd = open("/dev/graphics/fb0",O_RDONLY);
-    if (fd > 0)
+    if (fd >= 0)
     {
         if (ioctl(fd, FBIOGET_VSCREENINFO, &vsinfo) < 0)
         {
