@@ -35,13 +35,13 @@
 //!
 //! \brief  Definion for bitset value
 //!
-static const VAConfigAttribValEncROI HEVCCommon_VAEntrypointEncSliceLP_encROI
+static const VAConfigAttribValEncROI HEVCCommon_VAEntrypointEncSlice_encROI
 {
     {CODECHAL_ENCODE_HEVC_MAX_NUM_ROI,0,1,0}
 };
 
 //! \brief  Definition for ConfigDataList
-static ConfigDataList configDataList_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ConfigDataList configDataList_VAProfileHEVCMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VA_RC_CQP, 0},
   {VA_RC_CBR, 0},
@@ -66,7 +66,7 @@ static ConfigDataList configDataList_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe
 #endif
 };
 
-static ConfigDataList configDataList_VAProfileHEVCMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ConfigDataList configDataList_VAProfileHEVCMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VA_RC_CQP, 0},
   {VA_RC_CBR, 0},
@@ -92,7 +92,7 @@ static ConfigDataList configDataList_VAProfileHEVCMain10_VAEntrypointEncSliceLP_
   {VA_RC_VBR | VA_RC_MB, 0}
 };
 
-static ConfigDataList configDataList_VAProfileHEVCMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ConfigDataList configDataList_VAProfileHEVCMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VA_RC_CQP, 0},
   {VA_RC_CBR, 0},
@@ -117,7 +117,7 @@ static ConfigDataList configDataList_VAProfileHEVCMain444_VAEntrypointEncSliceLP
 #endif
 };
 
-static ConfigDataList configDataList_VAProfileHEVCMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ConfigDataList configDataList_VAProfileHEVCMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VA_RC_CQP, 0},
   {VA_RC_CBR, 0},
@@ -142,30 +142,70 @@ static ConfigDataList configDataList_VAProfileHEVCMain444_10_VAEntrypointEncSlic
 #endif
 };
 
-static ConfigDataList configDataList_VAProfileHEVCSccMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ConfigDataList configDataList_VAProfileHEVCSccMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VA_RC_CQP, 0},
 };
 
-static ConfigDataList configDataList_VAProfileHEVCSccMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ConfigDataList configDataList_VAProfileHEVCSccMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VA_RC_CQP, 0},
 };
 
-static ConfigDataList configDataList_VAProfileHEVCSccMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ConfigDataList configDataList_VAProfileHEVCSccMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VA_RC_CQP, 0},
 };
 
-static ConfigDataList configDataList_VAProfileHEVCSccMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ConfigDataList configDataList_VAProfileHEVCSccMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VA_RC_CQP, 0},
 };
 
+#if VA_CHECK_VERSION(1, 12, 0)
+static VAConfigAttribValEncHEVCFeatures vaConfigAttribValEncHEVCFeatures =
+{
+  {
+    .separate_colour_planes = VA_FEATURE_NOT_SUPPORTED,
+    .scaling_lists = VA_FEATURE_SUPPORTED,
+    .amp = VA_FEATURE_REQUIRED,
+    .sao = VA_FEATURE_SUPPORTED,
+    .pcm = VA_FEATURE_NOT_SUPPORTED,
+    .temporal_mvp = VA_FEATURE_SUPPORTED,
+    .strong_intra_smoothing = VA_FEATURE_NOT_SUPPORTED,
+    .dependent_slices = VA_FEATURE_NOT_SUPPORTED,
+    .sign_data_hiding = VA_FEATURE_NOT_SUPPORTED,
+    .constrained_intra_pred = VA_FEATURE_NOT_SUPPORTED,
+    .transform_skip = VA_FEATURE_SUPPORTED,
+    .cu_qp_delta = VA_FEATURE_REQUIRED,
+    .weighted_prediction = VA_FEATURE_SUPPORTED,
+    .transquant_bypass = VA_FEATURE_NOT_SUPPORTED,
+    .deblocking_filter_disable = VA_FEATURE_NOT_SUPPORTED
+  }
+};
+
+static VAConfigAttribValEncHEVCBlockSizes vaConfigAttribValEncHEVCBlockSizes =
+{
+  {
+    .log2_max_coding_tree_block_size_minus3     = 3,
+    .log2_min_coding_tree_block_size_minus3     = 3,
+    .log2_min_luma_coding_block_size_minus3     = 0,
+    .log2_max_luma_transform_block_size_minus2  = 3,
+    .log2_min_luma_transform_block_size_minus2  = 0,
+    .max_max_transform_hierarchy_depth_inter    = 2,
+    .min_max_transform_hierarchy_depth_inter    = 0,
+    .max_max_transform_hierarchy_depth_intra    = 2,
+    .min_max_transform_hierarchy_depth_intra    = 0,
+    .log2_max_pcm_coding_block_size_minus3      = 0,
+    .log2_min_pcm_coding_block_size_minus3      = 0
+  }
+};
+#endif
+
 //!
 //! \brief  Definion for AttribList
 //!
-static const AttribList attribList_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0
+static const AttribList attribList_VAProfileHEVCMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0
 {
    {VAConfigAttribRTFormat, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_RGB32_10BPP},
    {VAConfigAttribRateControl, VA_RC_CQP | VA_RC_CBR | VA_RC_VBR | VA_RC_QVBR | VA_RC_MB | VA_RC_VCM | VA_RC_TCBRC | VA_RC_ICQ},
@@ -182,7 +222,7 @@ static const AttribList attribList_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe_L
    {VAConfigAttribMaxPictureHeight, CODEC_12K_MAX_PIC_HEIGHT},
    {VAConfigAttribEncQualityRange, NUM_TARGET_USAGE_MODES - 1},
    {VAConfigAttribEncIntraRefresh, VA_ENC_INTRA_REFRESH_ROLLING_COLUMN | VA_ENC_INTRA_REFRESH_ROLLING_ROW},
-   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSliceLP_encROI.value},
+   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSlice_encROI.value},
    {VAConfigAttribProcessingRate, VA_PROCESSING_RATE_ENCODE},
    {VAConfigAttribEncDirtyRect, 16},
    {VAConfigAttribEncTileSupport, 1},
@@ -200,9 +240,13 @@ static const AttribList attribList_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe_L
    {VAConfigAttribCustomRoundingControl, 1},
    {VAConfigAttribMaxFrameSize, 3},
    {VAConfigAttribPredictionDirection, 7},
+#if VA_CHECK_VERSION(1, 12, 0)
+   {VAConfigAttribEncHEVCFeatures, vaConfigAttribValEncHEVCFeatures.value},
+   {VAConfigAttribEncHEVCBlockSizes, vaConfigAttribValEncHEVCBlockSizes.value},
+#endif
 };
 
-static const AttribList attribList_VAProfileHEVCMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0
+static const AttribList attribList_VAProfileHEVCMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0
 {
    {VAConfigAttribRTFormat, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_RGB32_10BPP},
    {VAConfigAttribRateControl, VA_RC_CQP | VA_RC_CBR | VA_RC_VBR | VA_RC_QVBR | VA_RC_MB | VA_RC_VCM | VA_RC_TCBRC | VA_RC_ICQ},
@@ -219,7 +263,7 @@ static const AttribList attribList_VAProfileHEVCMain10_VAEntrypointEncSliceLP_Xe
    {VAConfigAttribMaxPictureHeight, CODEC_12K_MAX_PIC_HEIGHT},
    {VAConfigAttribEncQualityRange, NUM_TARGET_USAGE_MODES - 1},
    {VAConfigAttribEncIntraRefresh, VA_ENC_INTRA_REFRESH_ROLLING_COLUMN | VA_ENC_INTRA_REFRESH_ROLLING_ROW},
-   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSliceLP_encROI.value},
+   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSlice_encROI.value},
    {VAConfigAttribProcessingRate, VA_PROCESSING_RATE_ENCODE},
    {VAConfigAttribEncDirtyRect, 16},
    {VAConfigAttribEncTileSupport, 1},
@@ -237,9 +281,13 @@ static const AttribList attribList_VAProfileHEVCMain10_VAEntrypointEncSliceLP_Xe
    {VAConfigAttribCustomRoundingControl, 1},
    {VAConfigAttribMaxFrameSize, 3},
    {VAConfigAttribPredictionDirection, 7},
+#if VA_CHECK_VERSION(1, 12, 0)
+   {VAConfigAttribEncHEVCFeatures, vaConfigAttribValEncHEVCFeatures.value},
+   {VAConfigAttribEncHEVCBlockSizes, vaConfigAttribValEncHEVCBlockSizes.value},
+#endif
 };
 
-static const AttribList attribList_VAProfileHEVCMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0
+static const AttribList attribList_VAProfileHEVCMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0
 {
    {VAConfigAttribRTFormat, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_RGB32_10BPP},
    {VAConfigAttribRateControl, VA_RC_CQP | VA_RC_CBR | VA_RC_VBR | VA_RC_QVBR | VA_RC_MB | VA_RC_VCM | VA_RC_TCBRC | VA_RC_ICQ},
@@ -256,7 +304,7 @@ static const AttribList attribList_VAProfileHEVCMain444_VAEntrypointEncSliceLP_X
    {VAConfigAttribMaxPictureHeight, CODEC_12K_MAX_PIC_HEIGHT},
    {VAConfigAttribEncQualityRange, NUM_TARGET_USAGE_MODES - 1},
    {VAConfigAttribEncIntraRefresh, VA_ENC_INTRA_REFRESH_ROLLING_COLUMN | VA_ENC_INTRA_REFRESH_ROLLING_ROW},
-   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSliceLP_encROI.value},
+   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSlice_encROI.value},
    {VAConfigAttribProcessingRate, VA_PROCESSING_RATE_ENCODE},
    {VAConfigAttribEncDirtyRect, 16},
    {VAConfigAttribEncTileSupport, 1},
@@ -274,9 +322,13 @@ static const AttribList attribList_VAProfileHEVCMain444_VAEntrypointEncSliceLP_X
    {VAConfigAttribCustomRoundingControl, 1},
    {VAConfigAttribMaxFrameSize, 3},
    {VAConfigAttribPredictionDirection, 7},
+#if VA_CHECK_VERSION(1, 12, 0)
+   {VAConfigAttribEncHEVCFeatures, vaConfigAttribValEncHEVCFeatures.value},
+   {VAConfigAttribEncHEVCBlockSizes, vaConfigAttribValEncHEVCBlockSizes.value},
+#endif
 };
 
-static const AttribList attribList_VAProfileHEVCMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0
+static const AttribList attribList_VAProfileHEVCMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0
 {
    {VAConfigAttribRTFormat, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_RGB32_10BPP},
    {VAConfigAttribRateControl, VA_RC_CQP | VA_RC_CBR | VA_RC_VBR | VA_RC_QVBR | VA_RC_MB | VA_RC_VCM | VA_RC_TCBRC | VA_RC_ICQ},
@@ -293,7 +345,7 @@ static const AttribList attribList_VAProfileHEVCMain444_10_VAEntrypointEncSliceL
    {VAConfigAttribMaxPictureHeight, CODEC_12K_MAX_PIC_HEIGHT},
    {VAConfigAttribEncQualityRange, NUM_TARGET_USAGE_MODES - 1},
    {VAConfigAttribEncIntraRefresh, VA_ENC_INTRA_REFRESH_ROLLING_COLUMN | VA_ENC_INTRA_REFRESH_ROLLING_ROW},
-   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSliceLP_encROI.value},
+   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSlice_encROI.value},
    {VAConfigAttribProcessingRate, VA_PROCESSING_RATE_ENCODE},
    {VAConfigAttribEncDirtyRect, 16},
    {VAConfigAttribEncTileSupport, 1},
@@ -311,9 +363,13 @@ static const AttribList attribList_VAProfileHEVCMain444_10_VAEntrypointEncSliceL
    {VAConfigAttribCustomRoundingControl, 1},
    {VAConfigAttribMaxFrameSize, 3},
    {VAConfigAttribPredictionDirection, 7},
+#if VA_CHECK_VERSION(1, 12, 0)
+   {VAConfigAttribEncHEVCFeatures, vaConfigAttribValEncHEVCFeatures.value},
+   {VAConfigAttribEncHEVCBlockSizes, vaConfigAttribValEncHEVCBlockSizes.value},
+#endif
 };
 
-static const AttribList attribList_VAProfileHEVCSccMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0
+static const AttribList attribList_VAProfileHEVCSccMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0
 {
    {VAConfigAttribRTFormat, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_RGB32_10BPP},
    // Correct values
@@ -333,7 +389,7 @@ static const AttribList attribList_VAProfileHEVCSccMain_VAEntrypointEncSliceLP_X
    {VAConfigAttribMaxPictureHeight, CODEC_12K_MAX_PIC_HEIGHT},
    {VAConfigAttribEncQualityRange, NUM_TARGET_USAGE_MODES - 1},
    {VAConfigAttribEncIntraRefresh, VA_ENC_INTRA_REFRESH_ROLLING_COLUMN | VA_ENC_INTRA_REFRESH_ROLLING_ROW},
-   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSliceLP_encROI.value},
+   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSlice_encROI.value},
    {VAConfigAttribProcessingRate, VA_PROCESSING_RATE_ENCODE},
    {VAConfigAttribEncDirtyRect, 16},
    {VAConfigAttribEncTileSupport, 1},
@@ -351,9 +407,13 @@ static const AttribList attribList_VAProfileHEVCSccMain_VAEntrypointEncSliceLP_X
    {VAConfigAttribCustomRoundingControl, 1},
    {VAConfigAttribMaxFrameSize, 3},
    {VAConfigAttribPredictionDirection, 7},
+#if VA_CHECK_VERSION(1, 12, 0)
+   {VAConfigAttribEncHEVCFeatures, vaConfigAttribValEncHEVCFeatures.value},
+   {VAConfigAttribEncHEVCBlockSizes, vaConfigAttribValEncHEVCBlockSizes.value},
+#endif
 };
 
-static const AttribList attribList_VAProfileHEVCSccMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0
+static const AttribList attribList_VAProfileHEVCSccMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0
 {
    {VAConfigAttribRTFormat, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_RGB32_10BPP},
    // Correct values
@@ -373,7 +433,7 @@ static const AttribList attribList_VAProfileHEVCSccMain10_VAEntrypointEncSliceLP
    {VAConfigAttribMaxPictureHeight, CODEC_12K_MAX_PIC_HEIGHT},
    {VAConfigAttribEncQualityRange, NUM_TARGET_USAGE_MODES - 1},
    {VAConfigAttribEncIntraRefresh, VA_ENC_INTRA_REFRESH_ROLLING_COLUMN | VA_ENC_INTRA_REFRESH_ROLLING_ROW},
-   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSliceLP_encROI.value},
+   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSlice_encROI.value},
    {VAConfigAttribProcessingRate, VA_PROCESSING_RATE_ENCODE},
    {VAConfigAttribEncDirtyRect, 16},
    {VAConfigAttribEncTileSupport, 1},
@@ -391,9 +451,13 @@ static const AttribList attribList_VAProfileHEVCSccMain10_VAEntrypointEncSliceLP
    {VAConfigAttribCustomRoundingControl, 1},
    {VAConfigAttribMaxFrameSize, 3},
    {VAConfigAttribPredictionDirection, 7},
+#if VA_CHECK_VERSION(1, 12, 0)
+   {VAConfigAttribEncHEVCFeatures, vaConfigAttribValEncHEVCFeatures.value},
+   {VAConfigAttribEncHEVCBlockSizes, vaConfigAttribValEncHEVCBlockSizes.value},
+#endif
 };
 
-static const AttribList attribList_VAProfileHEVCSccMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0
+static const AttribList attribList_VAProfileHEVCSccMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0
 {
    {VAConfigAttribRTFormat, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_RGB32_10BPP},
    // Correct values
@@ -413,7 +477,7 @@ static const AttribList attribList_VAProfileHEVCSccMain444_VAEntrypointEncSliceL
    {VAConfigAttribMaxPictureHeight, CODEC_12K_MAX_PIC_HEIGHT},
    {VAConfigAttribEncQualityRange, NUM_TARGET_USAGE_MODES - 1},
    {VAConfigAttribEncIntraRefresh, VA_ENC_INTRA_REFRESH_ROLLING_COLUMN | VA_ENC_INTRA_REFRESH_ROLLING_ROW},
-   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSliceLP_encROI.value},
+   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSlice_encROI.value},
    {VAConfigAttribProcessingRate, VA_PROCESSING_RATE_ENCODE},
    {VAConfigAttribEncDirtyRect, 16},
    {VAConfigAttribEncTileSupport, 1},
@@ -431,9 +495,13 @@ static const AttribList attribList_VAProfileHEVCSccMain444_VAEntrypointEncSliceL
    {VAConfigAttribCustomRoundingControl, 1},
    {VAConfigAttribMaxFrameSize, 3},
    {VAConfigAttribPredictionDirection, 7},
+#if VA_CHECK_VERSION(1, 12, 0)
+   {VAConfigAttribEncHEVCFeatures, vaConfigAttribValEncHEVCFeatures.value},
+   {VAConfigAttribEncHEVCBlockSizes, vaConfigAttribValEncHEVCBlockSizes.value},
+#endif
 };
 
-static const AttribList attribList_VAProfileHEVCSccMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0
+static const AttribList attribList_VAProfileHEVCSccMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0
 {
    {VAConfigAttribRTFormat, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_RGB32_10BPP},
    // Correct values
@@ -453,7 +521,7 @@ static const AttribList attribList_VAProfileHEVCSccMain444_10_VAEntrypointEncSli
    {VAConfigAttribMaxPictureHeight, CODEC_12K_MAX_PIC_HEIGHT},
    {VAConfigAttribEncQualityRange, NUM_TARGET_USAGE_MODES - 1},
    {VAConfigAttribEncIntraRefresh, VA_ENC_INTRA_REFRESH_ROLLING_COLUMN | VA_ENC_INTRA_REFRESH_ROLLING_ROW},
-   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSliceLP_encROI.value},
+   {VAConfigAttribEncROI, HEVCCommon_VAEntrypointEncSlice_encROI.value},
    {VAConfigAttribProcessingRate, VA_PROCESSING_RATE_ENCODE},
    {VAConfigAttribEncDirtyRect, 16},
    {VAConfigAttribEncTileSupport, 1},
@@ -471,10 +539,14 @@ static const AttribList attribList_VAProfileHEVCSccMain444_10_VAEntrypointEncSli
    {VAConfigAttribCustomRoundingControl, 1},
    {VAConfigAttribMaxFrameSize, 3},
    {VAConfigAttribPredictionDirection, 7},
+#if VA_CHECK_VERSION(1, 12, 0)
+   {VAConfigAttribEncHEVCFeatures, vaConfigAttribValEncHEVCFeatures.value},
+   {VAConfigAttribEncHEVCBlockSizes, vaConfigAttribValEncHEVCBlockSizes.value},
+#endif
 };
 
 //!
-static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VASurfaceAttribPixelFormat, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_FOURCC_NV12}}},
   {VASurfaceAttribMaxWidth, VA_SURFACE_ATTRIB_GETTABLE, {VAGenericValueTypeInteger, {CODEC_16K_MAX_PIC_WIDTH}}},
@@ -484,7 +556,7 @@ static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain_VAEntrypoint
   {VASurfaceAttribMemoryType, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_SURFACE_ATTRIB_MEM_TYPE_VA | VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2}}},
 };
 
-static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VASurfaceAttribPixelFormat, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_FOURCC_P010}}},
   {VASurfaceAttribMaxWidth, VA_SURFACE_ATTRIB_GETTABLE, {VAGenericValueTypeInteger, {CODEC_16K_MAX_PIC_WIDTH}}},
@@ -494,7 +566,7 @@ static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain10_VAEntrypoi
   {VASurfaceAttribMemoryType, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_SURFACE_ATTRIB_MEM_TYPE_VA | VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2}}},
 };
 
-static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VASurfaceAttribPixelFormat, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_FOURCC_AYUV}}},
   #if VA_CHECK_VERSION(1, 13, 0)
@@ -507,7 +579,7 @@ static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain444_VAEntrypo
   {VASurfaceAttribMemoryType, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_SURFACE_ATTRIB_MEM_TYPE_VA | VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2}}},
 };
 
-static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VASurfaceAttribPixelFormat, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_FOURCC_Y410}}},
   {VASurfaceAttribMaxWidth, VA_SURFACE_ATTRIB_GETTABLE, {VAGenericValueTypeInteger, {CODEC_16K_MAX_PIC_WIDTH}}},
@@ -517,7 +589,7 @@ static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCMain444_10_VAEntr
   {VASurfaceAttribMemoryType, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_SURFACE_ATTRIB_MEM_TYPE_VA | VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2}}},
 };
 
-static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VASurfaceAttribPixelFormat, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_FOURCC_NV12}}},
   {VASurfaceAttribMaxWidth, VA_SURFACE_ATTRIB_GETTABLE, {VAGenericValueTypeInteger, {CODEC_16K_MAX_PIC_WIDTH}}},
@@ -527,7 +599,7 @@ static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain_VAEntrypo
   {VASurfaceAttribMemoryType, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_SURFACE_ATTRIB_MEM_TYPE_VA | VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2}}},
 };
 
-static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VASurfaceAttribPixelFormat, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_FOURCC_P010}}},
   {VASurfaceAttribMaxWidth, VA_SURFACE_ATTRIB_GETTABLE, {VAGenericValueTypeInteger, {CODEC_16K_MAX_PIC_WIDTH}}},
@@ -537,7 +609,7 @@ static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain10_VAEntry
   {VASurfaceAttribMemoryType, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_SURFACE_ATTRIB_MEM_TYPE_VA | VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2}}},
 };
 
-static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VASurfaceAttribPixelFormat, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_FOURCC_AYUV}}},
   #if VA_CHECK_VERSION(1, 13, 0)
@@ -550,7 +622,7 @@ static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain444_VAEntr
   {VASurfaceAttribMemoryType, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_SURFACE_ATTRIB_MEM_TYPE_VA | VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2}}},
 };
 
-static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0 =
+static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0 =
 {
   {VASurfaceAttribPixelFormat, VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE, {VAGenericValueTypeInteger, {VA_FOURCC_Y410}}},
   {VASurfaceAttribMaxWidth, VA_SURFACE_ATTRIB_GETTABLE, {VAGenericValueTypeInteger, {CODEC_16K_MAX_PIC_WIDTH}}},
@@ -565,58 +637,58 @@ static ProfileSurfaceAttribInfo surfaceAttribInfo_VAProfileHEVCSccMain444_10_VAE
 //!
 static const EntrypointData entrypointMap_VAProfileHEVCMain_Data_Xe_Lpm_plus_r0
 {
-    &attribList_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &configDataList_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &surfaceAttribInfo_VAProfileHEVCMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
+    &attribList_VAProfileHEVCMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &configDataList_VAProfileHEVCMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &surfaceAttribInfo_VAProfileHEVCMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
 };
 
 static const EntrypointData entrypointMap_VAProfileHEVCMain10_Data_Xe_Lpm_plus_r0
 {
-    &attribList_VAProfileHEVCMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &configDataList_VAProfileHEVCMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &surfaceAttribInfo_VAProfileHEVCMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
+    &attribList_VAProfileHEVCMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &configDataList_VAProfileHEVCMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &surfaceAttribInfo_VAProfileHEVCMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
 };
 
 static const EntrypointData entrypointMap_VAProfileHEVCMain444_Data_Xe_Lpm_plus_r0
 {
-    &attribList_VAProfileHEVCMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &configDataList_VAProfileHEVCMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &surfaceAttribInfo_VAProfileHEVCMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
+    &attribList_VAProfileHEVCMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &configDataList_VAProfileHEVCMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &surfaceAttribInfo_VAProfileHEVCMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
 };
 
 static const EntrypointData entrypointMap_VAProfileHEVCMain444_10_Data_Xe_Lpm_plus_r0
 {
-    &attribList_VAProfileHEVCMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &configDataList_VAProfileHEVCMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &surfaceAttribInfo_VAProfileHEVCMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
+    &attribList_VAProfileHEVCMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &configDataList_VAProfileHEVCMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &surfaceAttribInfo_VAProfileHEVCMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
 };
 
 static const EntrypointData entrypointMap_VAProfileHEVCSccMain_Data_Xe_Lpm_plus_r0
 {
-    &attribList_VAProfileHEVCSccMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &configDataList_VAProfileHEVCSccMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &surfaceAttribInfo_VAProfileHEVCSccMain_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
+    &attribList_VAProfileHEVCSccMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &configDataList_VAProfileHEVCSccMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &surfaceAttribInfo_VAProfileHEVCSccMain_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
 };
 
 static const EntrypointData entrypointMap_VAProfileHEVCSccMain10_Data_Xe_Lpm_plus_r0
 {
-    &attribList_VAProfileHEVCSccMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &configDataList_VAProfileHEVCSccMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &surfaceAttribInfo_VAProfileHEVCSccMain10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
+    &attribList_VAProfileHEVCSccMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &configDataList_VAProfileHEVCSccMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &surfaceAttribInfo_VAProfileHEVCSccMain10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
 };
 
 static const EntrypointData entrypointMap_VAProfileHEVCSccMain444_Data_Xe_Lpm_plus_r0
 {
-    &attribList_VAProfileHEVCSccMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &configDataList_VAProfileHEVCSccMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &surfaceAttribInfo_VAProfileHEVCSccMain444_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
+    &attribList_VAProfileHEVCSccMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &configDataList_VAProfileHEVCSccMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &surfaceAttribInfo_VAProfileHEVCSccMain444_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
 };
 
 static const EntrypointData entrypointMap_VAProfileHEVCSccMain444_10_Data_Xe_Lpm_plus_r0
 {
-    &attribList_VAProfileHEVCSccMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &configDataList_VAProfileHEVCSccMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
-    &surfaceAttribInfo_VAProfileHEVCSccMain444_10_VAEntrypointEncSliceLP_Xe_Lpm_plus_r0,
+    &attribList_VAProfileHEVCSccMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &configDataList_VAProfileHEVCSccMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
+    &surfaceAttribInfo_VAProfileHEVCSccMain444_10_VAEntrypointEncSlice_Xe_Lpm_plus_r0,
 };
 
 #endif // __CAPSTABLE_DATA_HEVC_ENCODE_XE_LPM_PLUS_R0_SPECIFIC_H__
